
USE $(DBNAME)
 GO
CREATE SCHEMA AUTHORIZATION $(RIASSET)
GO


CREATE TABLE $(RIASSET).ACTION_TYPE(
	ACTION_TYPE_ID INT  NOT NULL,
	REFERENCE_ID NVARCHAR(50),
	EXTERNAL_ID NVARCHAR(100),
	NAME NVARCHAR(255) DEFAULT 'Action Name Missing' NOT NULL,
	EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,                    
    EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,             
    SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,              
    URL NVARCHAR(2048),                                        
    REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
    ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_ROLE (
	ASSET_ROLE_ID INT  NOT NULL,
	REFERENCE_ID NVARCHAR(50),
	EXTERNAL_ID NVARCHAR(100),
	NAME NVARCHAR(255) DEFAULT 'Asset Role Name Missing' NOT NULL,
	PROJECT_ID INT  DEFAULT -1 NOT NULL,
	EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,                    
    EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,             
    SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,              
    URL NVARCHAR(2048),                                        
    REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
    ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_ROLE_RESOURCE_LOOKUP (
	ASSET_ROLE_ID INT  NOT NULL,
	RESOURCE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_ROLE_TEAM_LOOKUP (
	ASSET_ROLE_ID INT  NOT NULL,
	TEAM_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_ROLE_ASSIGNMENT_HISTORY (
	HISTORY_ID INT  NOT NULL,
	REFERENCE_ID NVARCHAR(50),
	EXTERNAL_ID NVARCHAR(100),
    ASSET_ROLE_ID INT  DEFAULT -1 NOT NULL,
    PROJECT_ID INT  DEFAULT -1 NOT NULL,
    TEAM_ID INT  DEFAULT -1 NOT NULL,
    ASSIGNEE_ID INT  DEFAULT -1 NOT NULL,
    ASSIGNER_ID INT  DEFAULT -1 NOT NULL,
    ACTION_TYPE_ID INT  DEFAULT -1 NOT NULL,
    ASSIGNMENT_DATE DATETIME,
	EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,                    
    EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,             
    SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,              
    URL NVARCHAR(2048),                                        
    REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
    ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ENTITLEMENT (
	ENTITLEMENT_ID INT  NOT NULL,
	REFERENCE_ID NVARCHAR(50),
	EXTERNAL_ID NVARCHAR(100),
	NAME NVARCHAR(255) DEFAULT 'Entitlement Name Missing' NOT NULL,
	EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,                    
    EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,             
    SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,              
    URL NVARCHAR(2048),                                        
    REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
    ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ENTITLEMENT_HISTORY (
	HISTORY_ID INT  NOT NULL,
	REFERENCE_ID NVARCHAR(50),
	EXTERNAL_ID NVARCHAR(100),
    ASSET_ROLE_ID INT  DEFAULT -1 NOT NULL,
    ACTION_TYPE_ID INT  DEFAULT -1 NOT NULL,
    CHANGE_DATE DATETIME,
    RESOURCE_ID INT  DEFAULT -1 NOT NULL,
	EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,                    
    EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,             
    SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,              
    URL NVARCHAR(2048),                                        
    REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
    ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) ON VNF_32K 
GO



CREATE TABLE $(RIASSET).ENTITLEMENT_HISTORY_LOOKUP (
	HISTORY_ID INT  NOT NULL,
  	ENTITLEMENT_ID INT  NOT NULL,
  	ENTITLEMENT_TYPE NVARCHAR(255) NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_ROLE_ENTITLEMENT_LOOKUP(
	ASSET_ROLE_ID INT  NOT NULL,
	ENTITLEMENT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_LOOKUP(
	PRED_ASSET_ID INT  NOT NULL,
	SUCC_ASSET_ID INT  NOT NULL,
	LINK_TYPE NVARCHAR(255)
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_TYPE (
	ASSET_TYPE_ID INT  NOT NULL,
	REFERENCE_ID NVARCHAR(80),
	EXTERNAL_ID NVARCHAR(100),
	NAME NVARCHAR(255) DEFAULT 'Asset Type Name Missing' NOT NULL,
	EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,                    
    EXTERNAL_KEY2 NCHAR(80) DEFAULT '-1' NOT NULL,             
    SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,              
    URL NVARCHAR(2048),                                        
    REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
    ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET (
	ASSET_ID INT  NOT NULL,
	REFERENCE_ID NVARCHAR(80),
	EXTERNAL_ID NVARCHAR(100),
	NAME NVARCHAR(255) DEFAULT 'Asset Name Missing' NOT NULL,
	PROJECT_ID INT  DEFAULT -1 NOT NULL,
	VERSION NVARCHAR(255),
	ASSET_TYPE_ID INT  DEFAULT -1 NOT NULL,
	ASSET_STATE NVARCHAR(255),
	LAST_MODIFIED DATETIME,
	EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,                    
    EXTERNAL_KEY2 NCHAR(80) DEFAULT '-1' NOT NULL,             
    SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,              
    URL NVARCHAR(2048),                                        
    REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
    ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_RESOURCE_LOOKUP(
		ASSET_ID INT  NOT NULL,
		OWNER_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_HISTORY (
	HISTORY_ID INT  NOT NULL,
	REFERENCE_ID NVARCHAR(50),
	EXTERNAL_ID NVARCHAR(100),
    ASSET_ID INT  NOT NULL,
    ACTION_TYPE_ID INT  DEFAULT -1 NOT NULL,
    RESOURCE_ID INT  DEFAULT -1 NOT NULL,
    ACTION_DATE DATETIME,
	EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,                    
    EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,             
    SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,              
    URL NVARCHAR(2048),                                        
    REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
    ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) ON VNF_32K 
GO

		                          
CREATE TABLE $(RIASSET).LICENSE_HISTORY (
	HISTORY_ID INT  NOT NULL,
	REFERENCE_ID NVARCHAR(50),
	EXTERNAL_ID NVARCHAR(100),
    ASSET_ID INT  DEFAULT -1 NOT NULL,
    ACTION_TYPE_ID INT  DEFAULT -1 NOT NULL,
    USAGE_DATE DATETIME,
    RESOURCE_ID INT  DEFAULT -1 NOT NULL,
	EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,                    
    EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,             
    SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,              
    URL NVARCHAR(2048),                                        
    REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
    ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_REQUEST_LOOKUP(
	ASSET_ID INT  NOT NULL,
	REQUEST_ID INT  NOT NULL,
	LINK_TYPE NVARCHAR(255)
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_TESTCASE_LOOKUP(
	ASSET_ID INT  NOT NULL,
	TESTCASE_ID INT  NOT NULL,
	LINK_TYPE NVARCHAR(255)
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_TESTPLAN_LOOKUP(
	ASSET_ID INT  NOT NULL,
	TESTPLAN_ID INT  NOT NULL,
	LINK_TYPE NVARCHAR(255)
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_REQUIREMENT_LOOKUP(
	ASSET_ID INT  NOT NULL,
	REQUIREMENT_ID INT  NOT NULL,
	LINK_TYPE NVARCHAR(255)
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_CATEGORY (
		ASSET_CATEGORY_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Asset Category Name Missing' NOT NULL,
		FULL_PATH NVARCHAR (2048),
		ROOT_FLAG INT  DEFAULT 0 NOT NULL,
		LEAF_FLAG INT  DEFAULT 0 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_CAT_HIERARCHY (
		PARENT_CATEGORY_ID INT  NOT NULL,
		CHILD_CATEGORY_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_ATTRIBUTE (
		ASSET_ATTRIBUTE_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Asset Attribute Name Missing' NOT NULL,
		ASSET_ID INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO



CREATE TABLE $(RIASSET).ASSET_ATTRIBUTE_VALUE (
		ASSET_ATTRIBUTE_VALUE_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Asset Attribute Value Name Missing' NOT NULL,
		ASSET_ATTRIBUTE_ID INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(RIASSET).ASSET_CAT_ASSET_LOOKUP (
		ASSET_CATEGORY_ID INT  NOT NULL,
		ASSET_ID INT  NOT NULL,
		FULL_PATH NVARCHAR(2048) NOT NULL
) ON VNF_32K 
GO


-- INDEXES

CREATE INDEX ACTTYPE_IDX3 ON $(RIASSET).ACTION_TYPE (EXTERNAL_KEY2)  ON VNF_IDX		
GO
CREATE INDEX ASSETTP_IDX3 ON $(RIASSET).ASSET_TYPE (EXTERNAL_KEY2)  ON VNF_IDX		
GO
CREATE INDEX ASSET_IDX3 ON $(RIASSET).ASSET (EXTERNAL_KEY2)  ON VNF_IDX		
GO
CREATE INDEX ASSETHIST_IDX3 ON $(RIASSET).ASSET_HISTORY (EXTERNAL_KEY2)  ON VNF_IDX		
GO
CREATE INDEX ASSETROLE_IDX3 ON $(RIASSET).ASSET_ROLE (EXTERNAL_KEY2)  ON VNF_IDX		
GO
CREATE INDEX ASSETRLASSIH_IDX3 ON $(RIASSET).ASSET_ROLE_ASSIGNMENT_HISTORY (EXTERNAL_KEY2)  ON VNF_IDX		
GO
CREATE INDEX ENTITLEMENT_IDX3 ON $(RIASSET).ENTITLEMENT (EXTERNAL_KEY2)  ON VNF_IDX		
GO
CREATE INDEX ENTITHST_IDX3 ON $(RIASSET).ENTITLEMENT_HISTORY (EXTERNAL_KEY2)  ON VNF_IDX		
GO
CREATE INDEX LICENSEH_IDX3 ON $(RIASSET).LICENSE_HISTORY (EXTERNAL_KEY2)  ON VNF_IDX		
GO
CREATE INDEX ASSTCAT_IDX3 ON $(RIASSET).ASSET_CATEGORY        (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX ASSTATTR_IDX3 ON $(RIASSET).ASSET_ATTRIBUTE       (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX ASSTATRVAL_IDX3 ON $(RIASSET).ASSET_ATTRIBUTE_VALUE (EXTERNAL_KEY2)  ON VNF_IDX
GO


CREATE INDEX ACTTYPE_IDX4 ON $(RIASSET).ACTION_TYPE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSETTP_IDX4 ON $(RIASSET).ASSET_TYPE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSET_IDX4 ON $(RIASSET).ASSET (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSETHIST_IDX4 ON $(RIASSET).ASSET_HISTORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSETROLE_IDX4 ON $(RIASSET).ASSET_ROLE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSETRLASSIH_IDX4 ON $(RIASSET).ASSET_ROLE_ASSIGNMENT_HISTORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ENTITLEMENT_IDX4 ON $(RIASSET).ENTITLEMENT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ENTITHST_IDX4 ON $(RIASSET).ENTITLEMENT_HISTORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX LICENSEH_IDX4 ON $(RIASSET).LICENSE_HISTORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSTCAT_IDX4 ON $(RIASSET).ASSET_CATEGORY        (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ASSTATTR_IDX4 ON $(RIASSET).ASSET_ATTRIBUTE       (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ASSTATRVAL_IDX4 ON $(RIASSET).ASSET_ATTRIBUTE_VALUE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX ACTTYPE_IDX5 ON $(RIASSET).ACTION_TYPE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSETTP_IDX5 ON $(RIASSET).ASSET_TYPE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSET_IDX5 ON $(RIASSET).ASSET (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSETHIST_IDX5 ON $(RIASSET).ASSET_HISTORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSETROLE_IDX5 ON $(RIASSET).ASSET_ROLE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSETRLASSIH_IDX5 ON $(RIASSET).ASSET_ROLE_ASSIGNMENT_HISTORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ENTITLEMENT_IDX5 ON $(RIASSET).ENTITLEMENT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ENTITHST_IDX5 ON $(RIASSET).ENTITLEMENT_HISTORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX LICENSEH_IDX5 ON $(RIASSET).LICENSE_HISTORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSTCAT_IDX5 ON $(RIASSET).ASSET_CATEGORY        (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ASSTATTR_IDX5 ON $(RIASSET).ASSET_ATTRIBUTE       (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ASSTATRVAL_IDX5 ON $(RIASSET).ASSET_ATTRIBUTE_VALUE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX ACTTYPE_IDX2 ON $(RIASSET).ACTION_TYPE (EXTERNAL_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSETTP_IDX2 ON $(RIASSET).ASSET_TYPE (EXTERNAL_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSET_IDX2 ON $(RIASSET).ASSET (EXTERNAL_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSETHIST_IDX2 ON $(RIASSET).ASSET_HISTORY (EXTERNAL_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSETROLE_IDX2 ON $(RIASSET).ASSET_ROLE (EXTERNAL_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSETRLASSIH_IDX2 ON $(RIASSET).ASSET_ROLE_ASSIGNMENT_HISTORY (EXTERNAL_ID)  ON VNF_IDX		
GO
CREATE INDEX ENTITLEMENT_IDX2 ON $(RIASSET).ENTITLEMENT (EXTERNAL_ID)  ON VNF_IDX		
GO
CREATE INDEX ENTITHST_IDX2 ON $(RIASSET).ENTITLEMENT_HISTORY (EXTERNAL_ID)  ON VNF_IDX		
GO
CREATE INDEX LICENSEH_IDX2 ON $(RIASSET).LICENSE_HISTORY (EXTERNAL_ID)  ON VNF_IDX		
GO
CREATE INDEX ASSTCAT_IDX2 ON $(RIASSET).ASSET_CATEGORY        (EXTERNAL_ID)  ON VNF_IDX
GO
CREATE INDEX ASSTATTR_IDX2 ON $(RIASSET).ASSET_ATTRIBUTE       (EXTERNAL_ID)  ON VNF_IDX
GO
CREATE INDEX ASSTATRVAL_IDX2 ON $(RIASSET).ASSET_ATTRIBUTE_VALUE (EXTERNAL_ID)  ON VNF_IDX
GO



ALTER TABLE $(RIASSET).ACTION_TYPE ADD CONSTRAINT ACTIONTP_PK PRIMARY KEY (ACTION_TYPE_ID) ON  VNF_IDX		
GO

ALTER TABLE $(RIASSET).ASSET_TYPE ADD CONSTRAINT ASSETTP_PK PRIMARY KEY (ASSET_TYPE_ID)  ON  VNF_IDX		
GO

ALTER TABLE $(RIASSET).ASSET ADD CONSTRAINT ASSET_PK PRIMARY KEY (ASSET_ID)           ON  VNF_IDX		
GO
                                         
ALTER TABLE $(RIASSET).ASSET_ROLE ADD CONSTRAINT ASSETROLE_PK PRIMARY KEY (ASSET_ROLE_ID)       ON  VNF_IDX		
GO
                              
ALTER TABLE $(RIASSET).ASSET_ROLE_ASSIGNMENT_HISTORY ADD CONSTRAINT ASSETRLASSIH_PK PRIMARY KEY (HISTORY_ID)  ON  VNF_IDX		
GO

ALTER TABLE $(RIASSET).ENTITLEMENT ADD CONSTRAINT ENTITLEMENT_PK PRIMARY KEY (ENTITLEMENT_ID)                           ON  VNF_IDX		
GO
       
ALTER TABLE $(RIASSET).ENTITLEMENT_HISTORY ADD CONSTRAINT ENTITLEHIST_PK PRIMARY KEY (HISTORY_ID)             ON  VNF_IDX		
GO
                     
ALTER TABLE $(RIASSET).LICENSE_HISTORY ADD CONSTRAINT LICENSEHIST_PK PRIMARY KEY (HISTORY_ID)       ON  VNF_IDX		
GO

ALTER TABLE $(RIASSET).ASSET_ROLE_ENTITLEMENT_LOOKUP ADD CONSTRAINT ASSERLENTLK_PK PRIMARY KEY (ASSET_ROLE_ID,ENTITLEMENT_ID)  ON  VNF_IDX		
GO

ALTER TABLE $(RIASSET).ASSET_LOOKUP ADD CONSTRAINT ASSETLKUP_PK PRIMARY KEY (PRED_ASSET_ID,SUCC_ASSET_ID)                           ON  VNF_IDX		
GO
          
ALTER TABLE $(RIASSET).ASSET_RESOURCE_LOOKUP ADD CONSTRAINT ASSERESLK_PK PRIMARY KEY (ASSET_ID,OWNER_ID)                   ON  VNF_IDX		
GO
          
ALTER TABLE $(RIASSET).ASSET_REQUEST_LOOKUP ADD CONSTRAINT ASSEREQULK_PK PRIMARY KEY (ASSET_ID,REQUEST_ID)            ON  VNF_IDX		
GO
                 
ALTER TABLE $(RIASSET).ASSET_TESTCASE_LOOKUP ADD CONSTRAINT ASSETCASELK_PK PRIMARY KEY (ASSET_ID,TESTCASE_ID)         ON  VNF_IDX		
GO
                 
ALTER TABLE $(RIASSET).ASSET_TESTPLAN_LOOKUP ADD CONSTRAINT ASSETPLANLK_PK PRIMARY KEY (ASSET_ID,TESTPLAN_ID)  ON  VNF_IDX		
GO

ALTER TABLE $(RIASSET).ENTITLEMENT_HISTORY_LOOKUP ADD CONSTRAINT ENTHISTLK_PK PRIMARY KEY (HISTORY_ID,ENTITLEMENT_ID,ENTITLEMENT_TYPE) ON  VNF_IDX		
GO

ALTER TABLE $(RIASSET).ASSET_ROLE_RESOURCE_LOOKUP ADD CONSTRAINT ASSETRLRESLK_PK PRIMARY KEY (ASSET_ROLE_ID,RESOURCE_ID) ON  VNF_IDX		
GO

ALTER TABLE $(RIASSET).ASSET_ROLE_TEAM_LOOKUP ADD CONSTRAINT ASSETRLTEAMLK_PK PRIMARY KEY (ASSET_ROLE_ID,TEAM_ID) ON  VNF_IDX		
GO

ALTER TABLE $(RIASSET).ASSET_HISTORY ADD CONSTRAINT ASSETHIST_PK PRIMARY KEY (HISTORY_ID) ON  VNF_IDX		
GO

ALTER TABLE $(RIASSET).ASSET_CATEGORY ADD CONSTRAINT ASSTCAT_PK PRIMARY KEY (ASSET_CATEGORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(RIASSET).ASSET_CAT_HIERARCHY ADD CONSTRAINT ASTCATCATLK_PK PRIMARY KEY (PARENT_CATEGORY_ID,CHILD_CATEGORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(RIASSET).ASSET_ATTRIBUTE ADD CONSTRAINT ASSTATTR_PK PRIMARY KEY (ASSET_ATTRIBUTE_ID) ON  VNF_IDX
GO

ALTER TABLE $(RIASSET).ASSET_ATTRIBUTE_VALUE ADD CONSTRAINT ASSTATRVAL_PK PRIMARY KEY (ASSET_ATTRIBUTE_VALUE_ID) ON  VNF_IDX
GO

ALTER TABLE $(RIASSET).ASSET_CAT_ASSET_LOOKUP ADD CONSTRAINT ASTCATASSTLK_PK PRIMARY KEY (ASSET_CATEGORY_ID,ASSET_ID) ON  VNF_IDX
GO



--FOREIGN KEY

ALTER TABLE $(RIASSET).ASSET ADD CONSTRAINT ASSET_FK1 FOREIGN KEY (PROJECT_ID) 
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)   
GO

ALTER TABLE $(RIASSET).ASSET ADD CONSTRAINT ASSET_FK2 FOREIGN KEY (ASSET_TYPE_ID) 
REFERENCES $(RIASSET).ASSET_TYPE (ASSET_TYPE_ID)   
GO
	                                                                 
ALTER TABLE $(RIASSET).ASSET_ROLE ADD CONSTRAINT ASSETROLE_FK1 FOREIGN KEY (PROJECT_ID) 
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)  
GO
	                                                    
ALTER TABLE $(RIASSET).ASSET_ROLE_ASSIGNMENT_HISTORY ADD CONSTRAINT ASSETRLASSIH_FK1 FOREIGN KEY (ASSET_ROLE_ID) 
REFERENCES $(RIASSET).ASSET_ROLE (ASSET_ROLE_ID)  
GO
	
ALTER TABLE $(RIASSET).ASSET_ROLE_ASSIGNMENT_HISTORY ADD CONSTRAINT ASSETRLASSIH_FK2 FOREIGN KEY (PROJECT_ID) 
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)    
GO
	       
ALTER TABLE $(RIASSET).ASSET_ROLE_ASSIGNMENT_HISTORY ADD CONSTRAINT ASSETRLASSIH_FK3 FOREIGN KEY (TEAM_ID) 
REFERENCES $(NF_SCHEMA).TEAM (TEAM_ID)           
GO
	         
ALTER TABLE $(RIASSET).ASSET_ROLE_ASSIGNMENT_HISTORY ADD CONSTRAINT ASSETRLASSIH_FK4 FOREIGN KEY (ASSIGNEE_ID) 
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)   
GO
	     
ALTER TABLE $(RIASSET).ASSET_ROLE_ASSIGNMENT_HISTORY ADD CONSTRAINT ASSETRLASSIH_FK5 FOREIGN KEY (ASSIGNER_ID) 
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID) 
GO
	
ALTER TABLE $(RIASSET).ASSET_ROLE_ASSIGNMENT_HISTORY ADD CONSTRAINT ASSETRLASSIH_FK6 FOREIGN KEY (ACTION_TYPE_ID) 
REFERENCES $(RIASSET).ACTION_TYPE (ACTION_TYPE_ID) 		 
GO
	      
ALTER TABLE $(RIASSET).ENTITLEMENT_HISTORY ADD CONSTRAINT ENTITLEHIST_FK1 FOREIGN KEY (ASSET_ROLE_ID) 
REFERENCES $(RIASSET).ASSET_ROLE (ASSET_ROLE_ID)    
GO
	    
ALTER TABLE $(RIASSET).ENTITLEMENT_HISTORY ADD CONSTRAINT ENTITLEHIST_FK2 FOREIGN KEY (RESOURCE_ID) 
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)     
GO
	
ALTER TABLE $(RIASSET).ENTITLEMENT_HISTORY ADD CONSTRAINT ENTITLEHIST_FK3 FOREIGN KEY (ACTION_TYPE_ID) 
REFERENCES $(RIASSET).ACTION_TYPE (ACTION_TYPE_ID)  	  
GO
	                     
ALTER TABLE $(RIASSET).LICENSE_HISTORY ADD CONSTRAINT LICENSEHIST_FK1 FOREIGN KEY (ASSET_ID) 
REFERENCES $(RIASSET).ASSET (ASSET_ID)             
GO
	                                
ALTER TABLE $(RIASSET).LICENSE_HISTORY ADD CONSTRAINT LICENSEHIST_FK2 FOREIGN KEY (RESOURCE_ID) 
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)   
GO
	
ALTER TABLE $(RIASSET).LICENSE_HISTORY ADD CONSTRAINT LICENSEHIST_FK3 FOREIGN KEY (ACTION_TYPE_ID) 
REFERENCES $(RIASSET).ACTION_TYPE (ACTION_TYPE_ID) 	                                 
GO
                 
ALTER TABLE $(RIASSET).ASSET_LOOKUP ADD CONSTRAINT ASSETLKUP_FK1 FOREIGN KEY (PRED_ASSET_ID) 
REFERENCES $(RIASSET).ASSET (ASSET_ID)   
GO
	                                    
ALTER TABLE $(RIASSET).ASSET_LOOKUP ADD CONSTRAINT ASSETLKUP_FK2 FOREIGN KEY (SUCC_ASSET_ID) 
REFERENCES $(RIASSET).ASSET (ASSET_ID) 
GO
	                                      
ALTER TABLE $(RIASSET).ASSET_REQUEST_LOOKUP ADD CONSTRAINT ASSEREQULK_FK1 FOREIGN KEY (ASSET_ID) 
REFERENCES $(RIASSET).ASSET (ASSET_ID)       
GO
	                               
ALTER TABLE $(RIASSET).ASSET_REQUEST_LOOKUP ADD CONSTRAINT ASSEREQULK_FK2 FOREIGN KEY (REQUEST_ID) 
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)    
GO
	                            
ALTER TABLE $(RIASSET).ASSET_RESOURCE_LOOKUP ADD CONSTRAINT ASSERESLK_FK1 FOREIGN KEY (ASSET_ID) 
REFERENCES $(RIASSET).ASSET (ASSET_ID)      
GO
	                              
ALTER TABLE $(RIASSET).ASSET_RESOURCE_LOOKUP ADD CONSTRAINT ASSERESLK_FK2 FOREIGN KEY (OWNER_ID) 
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)   
GO
	                                 
ALTER TABLE $(RIASSET).ASSET_ROLE_ENTITLEMENT_LOOKUP ADD CONSTRAINT ASSERLENTLK_FK1 FOREIGN KEY (ASSET_ROLE_ID) 
REFERENCES $(RIASSET).ASSET_ROLE(ASSET_ROLE_ID)   
GO
	  
ALTER TABLE $(RIASSET).ASSET_ROLE_ENTITLEMENT_LOOKUP ADD CONSTRAINT ASSERLENTLK_FK2 FOREIGN KEY (ENTITLEMENT_ID) 
REFERENCES $(RIASSET).ENTITLEMENT (ENTITLEMENT_ID)  
GO
	
ALTER TABLE $(RIASSET).ASSET_TESTCASE_LOOKUP ADD CONSTRAINT ASSETCASELK_FK1 FOREIGN KEY (ASSET_ID) 
REFERENCES $(RIASSET).ASSET (ASSET_ID)         
GO
	                           
ALTER TABLE $(RIASSET).ASSET_TESTCASE_LOOKUP ADD CONSTRAINT ASSETCASELK_FK2 FOREIGN KEY (TESTCASE_ID) 
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)  
GO
	                         
ALTER TABLE $(RIASSET).ASSET_TESTPLAN_LOOKUP ADD CONSTRAINT ASSETPLANLK_FK1 FOREIGN KEY (ASSET_ID) 
REFERENCES $(RIASSET).ASSET (ASSET_ID)               
GO
	                     
ALTER TABLE $(RIASSET).ASSET_TESTPLAN_LOOKUP ADD CONSTRAINT ASSETPLANLK_FK2 FOREIGN KEY (TESTPLAN_ID) 
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)    
GO
	
ALTER TABLE $(RIASSET).ENTITLEMENT_HISTORY_LOOKUP ADD CONSTRAINT ENTHISTLK_FK1 FOREIGN KEY (HISTORY_ID)
REFERENCES $(RIASSET).ENTITLEMENT_HISTORY (HISTORY_ID)	 
GO
	
ALTER TABLE $(RIASSET).ENTITLEMENT_HISTORY_LOOKUP ADD CONSTRAINT ENTHISTLK_FK2 FOREIGN KEY (ENTITLEMENT_ID)
REFERENCES $(RIASSET).ENTITLEMENT (ENTITLEMENT_ID)	    
GO
	
ALTER TABLE $(RIASSET).ASSET_ROLE_RESOURCE_LOOKUP ADD CONSTRAINT ASSETRLRESLK_FK1 FOREIGN KEY (ASSET_ROLE_ID)
REFERENCES $(RIASSET).ASSET_ROLE (ASSET_ROLE_ID)
GO
	
ALTER TABLE $(RIASSET).ASSET_ROLE_RESOURCE_LOOKUP ADD CONSTRAINT ASSETRLRESLK_FK2 FOREIGN KEY (RESOURCE_ID)
REFERENCES $(NF_SCHEMA).RESOURCE	
GO

ALTER TABLE $(RIASSET).ASSET_ROLE_TEAM_LOOKUP ADD CONSTRAINT ASSETRLTEAMLK_FK1 FOREIGN KEY (ASSET_ROLE_ID)
REFERENCES $(RIASSET).ASSET_ROLE (ASSET_ROLE_ID)	
GO
	
ALTER TABLE $(RIASSET).ASSET_ROLE_TEAM_LOOKUP ADD CONSTRAINT ASSETRLTEAMLK_FK2 FOREIGN KEY (TEAM_ID)
REFERENCES $(NF_SCHEMA).TEAM (TEAM_ID)		
GO
	
ALTER TABLE $(RIASSET).ASSET_HISTORY ADD CONSTRAINT ASSETHIST_FK1 FOREIGN KEY (ASSET_ID)
REFERENCES $(RIASSET).ASSET (ASSET_ID)	    
GO

ALTER TABLE $(RIASSET).ASSET_HISTORY ADD CONSTRAINT ASSETHIST_FK2 FOREIGN KEY (ACTION_TYPE_ID)
REFERENCES $(RIASSET).ACTION_TYPE (ACTION_TYPE_ID)
GO
	
ALTER TABLE $(RIASSET).ASSET_HISTORY ADD CONSTRAINT ASSETHIST_FK3 FOREIGN KEY (RESOURCE_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)		               
GO
                 
ALTER TABLE $(RIASSET).ASSET_ATTRIBUTE_VALUE ADD CONSTRAINT ASSTATRVAL_FK1 FOREIGN KEY (ASSET_ATTRIBUTE_ID)
REFERENCES $(RIASSET).ASSET_ATTRIBUTE (ASSET_ATTRIBUTE_ID)
GO
	
ALTER TABLE $(RIASSET).ASSET_ATTRIBUTE ADD CONSTRAINT ASSTATTR_FK1 FOREIGN KEY (ASSET_ID)
REFERENCES $(RIASSET).ASSET (ASSET_ID)	
GO
	
ALTER TABLE $(RIASSET).ASSET_CAT_HIERARCHY ADD CONSTRAINT ASTCATCATLK_FK1 FOREIGN KEY (PARENT_CATEGORY_ID)
REFERENCES $(RIASSET).ASSET_CATEGORY (ASSET_CATEGORY_ID)
GO

ALTER TABLE $(RIASSET).ASSET_CAT_HIERARCHY ADD CONSTRAINT ASTCATCATLK_FK2 FOREIGN KEY (CHILD_CATEGORY_ID)
REFERENCES $(RIASSET).ASSET_CATEGORY (ASSET_CATEGORY_ID)	
GO
	
ALTER TABLE $(RIASSET).ASSET_CAT_ASSET_LOOKUP ADD CONSTRAINT ASTCATASSTLK_FK1 FOREIGN KEY (ASSET_CATEGORY_ID)
REFERENCES $(RIASSET).ASSET_CATEGORY (ASSET_CATEGORY_ID)
GO

ALTER TABLE $(RIASSET).ASSET_CAT_ASSET_LOOKUP ADD CONSTRAINT ASTCATASSTLK_FK2 FOREIGN KEY (ASSET_ID)
REFERENCES $(RIASSET).ASSET (ASSET_ID)	
GO
                 
--TRIGGERS

CREATE TRIGGER TRG_ASSETLK
    ON $(RIASSET).ASSET

    FOR UPDATE
AS
BEGIN                                                                           

  DELETE FROM $(RIASSET).ASSET_LOOKUP  WHERE  PRED_ASSET_ID IN 
  (SELECT ASSET_ID FROM INSERTED ) OR SUCC_ASSET_ID IN (SELECT ASSET_ID FROM INSERTED )
 END
GO
    
CREATE TRIGGER TRG_ASSREQUELK	                           
    ON $(RIASSET).ASSET     

    FOR UPDATE
AS
BEGIN                                                                           

  DELETE FROM $(RIASSET).ASSET_REQUEST_LOOKUP  WHERE  ASSET_ID IN 
  (SELECT  ASSET_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_ASSRESOULK 
    ON $(RIASSET).ASSET   

    FOR UPDATE
AS
BEGIN                                                                           

  DELETE FROM $(RIASSET).ASSET_RESOURCE_LOOKUP  WHERE  ASSET_ID IN 
  (SELECT  ASSET_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_ASSENTITLK 
    ON $(RIASSET).ASSET_ROLE

    FOR UPDATE
AS
BEGIN                                                                           

  DELETE FROM $(RIASSET).ASSET_ROLE_ENTITLEMENT_LOOKUP  WHERE  ASSET_ROLE_ID IN 
  (SELECT  ASSET_ROLE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_ASSTSTCASELK 
    ON $(RIASSET).ASSET       

    FOR UPDATE
AS
BEGIN                                                                           

  DELETE FROM $(RIASSET).ASSET_TESTCASE_LOOKUP  WHERE  ASSET_ID IN 
  (SELECT  ASSET_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TSTPLNLK 
    ON $(RIASSET).ASSET    

    FOR UPDATE
AS
BEGIN                                                                           

  DELETE FROM $(RIASSET).ASSET_TESTPLAN_LOOKUP  WHERE  ASSET_ID IN 
  (SELECT  ASSET_ID FROM INSERTED )
 END
GO
    
CREATE TRIGGER TRG_ASSRLRESELK 
    ON $(RIASSET).ASSET_ROLE    

    FOR UPDATE
AS
BEGIN                                                                           

  DELETE FROM $(RIASSET).ASSET_ROLE_RESOURCE_LOOKUP  WHERE  ASSET_ROLE_ID IN 
  (SELECT  ASSET_ROLE_ID FROM INSERTED )
 END
GO
      
CREATE TRIGGER TRG_ASSRLTEAMLK 
    ON $(RIASSET).ASSET_ROLE    

    FOR UPDATE
AS
BEGIN                                                                           

  DELETE FROM $(RIASSET).ASSET_ROLE_TEAM_LOOKUP  WHERE  ASSET_ROLE_ID IN 
  (SELECT  ASSET_ROLE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_ASSREQUILK 
    ON $(RIASSET).ASSET  

    FOR UPDATE
AS
BEGIN                                                                           

  DELETE FROM $(RIASSET).ASSET_REQUIREMENT_LOOKUP  WHERE  ASSET_ID IN 
  (SELECT  ASSET_ID FROM INSERTED )
 END
GO
      
CREATE TRIGGER TRG_ASSTCAT 
    ON $(RIASSET).ASSET_CATEGORY

    FOR UPDATE
AS
BEGIN    

  DELETE FROM $(RIASSET).ASSET_CAT_HIERARCHY  WHERE  PARENT_CATEGORY_ID IN 
  (SELECT  ASSET_CATEGORY_ID FROM INSERTED ) OR CHILD_CATEGORY_ID IN ( SELECT  ASSET_CATEGORY_ID FROM INSERTED )
 END
GO
      
CREATE TRIGGER TRG_ASSTCATAST 
    ON $(RIASSET).ASSET

    FOR UPDATE
AS
BEGIN    

  DELETE FROM $(RIASSET).ASSET_CAT_ASSET_LOOKUP  WHERE  ASSET_ID IN 
  (SELECT ASSET_ID FROM INSERTED )
 END
GO
      
   