USE $(DBNAME)
 GO
CREATE SCHEMA AUTHORIZATION $(RISCHK)
GO


CREATE TABLE $(RISCHK).SC_SESSION(
		SESSION_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Session Name Missing' NOT NULL,
		BALLOT_DEFINITION_ID INT  DEFAULT -1 NOT NULL,
 		TEAM_ID INT  DEFAULT -1 NOT NULL,
 		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		STATUS NVARCHAR(255), 
 		SESSION_DATE DATETIME, 
 		BALLOT_COUNT INT  DEFAULT 0 NOT NULL,
 		BALLOT_SUBMITTED INT  DEFAULT 0 NOT NULL,
 		[DESCRIPTION] NVARCHAR(1000),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(RISCHK).SCSESSION_PARTICIPANT_LOOKUP (
		SESSION_ID INT  NOT NULL,
		PARTICIPANT_ID INT  NOT NULL
) ON VNF_32K 
GO





CREATE TABLE $(RISCHK).SCSESSION_COFACILIT_LOOKUP (
		SESSION_ID INT  NOT NULL,
		FACILITATOR_ID INT  NOT NULL
) ON VNF_32K 
GO



CREATE TABLE $(RISCHK).BALLOT_DEFINITION(
		BALLOT_DEFINITION_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Ballot Definition Name Missing' NOT NULL,
    	SCALE_ID INT  DEFAULT -1 NOT NULL,
    	[DESCRIPTION] NVARCHAR(1000),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

    

CREATE TABLE $(RISCHK).BALLOTDEF_BALLOT_TAB_LOOKUP (
		BALLOT_DEFINITION_ID INT  NOT NULL,
		BALLOT_TAB_ID INT  NOT NULL
) ON VNF_32K 
GO

  
 
CREATE TABLE $(RISCHK).BALLOT(
		BALLOT_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Ballot Name Missing' NOT NULL,
		SESSION_ID INT  DEFAULT -1 NOT NULL,
 		STATUS NVARCHAR(25),
		SUBMISSIONTIME DATETIME,
		SUBMITTER_ID INT  DEFAULT -1 NOT NULL,
 		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(RISCHK).ANSWER(
		ANSWER_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Answer Name Missing' NOT NULL,
 		QUESTION_ID INT  DEFAULT -1 NOT NULL,
 		BALLOT_ID INT  DEFAULT -1 NOT NULL,
 		BALLOT_TAB_ID INT  DEFAULT -1 NOT NULL,
 		VALUE NVARCHAR(255),
 		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO



CREATE TABLE $(RISCHK).BALLOT_TAB(
		BALLOT_TAB_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Ballot Tab Name Missing' NOT NULL,
 		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO




CREATE TABLE $(RISCHK).QUESTION(
		QUESTION_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Question Name Missing' NOT NULL,
 		SCALE_ID INT  DEFAULT -1 NOT NULL,
 		[DESCRIPTION] NVARCHAR(1000),
 		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO





CREATE TABLE $(RISCHK).BALLOT_TAB_QUESTION_LOOKUP(
		BALLOT_TAB_ID INT  NOT NULL,
		QUESTION_ID INT  NOT NULL,
		QUESTION_ORDER INT 
) ON VNF_32K 
GO


	

CREATE TABLE $(RISCHK).SC_SCALE(
		SCALE_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Scale Name Missing' NOT NULL,
 		TRUE_VALUE_DISPLAY NVARCHAR(255),
 		FALSE_VALUE_DISPLAY NVARCHAR(255),
 		INT_START_VALUE INT ,
 		INT_END_VALUE INT ,
 		DEC_START_VALUE DECIMAL(18,2),
 		DEC_END_VALUE DECIMAL(18,2),
 		PRECISION_VALUE INT ,
 		TALKTHRESHOLDAVG DOUBLE PRECISION,
 		TALKTHRESHOLDDEV DOUBLE PRECISION,
 		TYPE NVARCHAR(255),
 		LENGTH INT ,
 		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO





CREATE TABLE $(RISCHK).SC_BALLOT_TAB_RESULT (
 		RESULT_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Result Name Missing' NOT NULL,
 		SESSION_ID INT  DEFAULT -1 NOT NULL,
 		BALLOT_TAB_ID INT  DEFAULT -1 NOT NULL,
 		STANDARD_DEV_VALUE DECIMAL (18,2),
 		AVERAGE_VALUE DECIMAL (18,2),
 		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


-- INDEXES

CREATE INDEX ANSWER_IDX3 ON $(RISCHK).ANSWER (EXTERNAL_KEY2)  ON VNF_IDX 
GO
CREATE INDEX BALTAB_IDX3 ON $(RISCHK).BALLOT_TAB (EXTERNAL_KEY2)  ON VNF_IDX 
GO
CREATE INDEX QUESTION_IDX3 ON $(RISCHK).QUESTION (EXTERNAL_KEY2)  ON VNF_IDX 
GO
CREATE INDEX SCRESULT_IDX3 ON $(RISCHK).SC_BALLOT_TAB_RESULT (EXTERNAL_KEY2)  ON VNF_IDX 
GO
CREATE INDEX SCSCALE_IDX3 ON $(RISCHK).SC_SCALE (EXTERNAL_KEY2)  ON VNF_IDX 
GO
CREATE INDEX SCSESSION_IDX3 ON $(RISCHK).SC_SESSION (EXTERNAL_KEY2)  ON VNF_IDX 
GO

CREATE INDEX ANSWER_IDX4 ON $(RISCHK).ANSWER (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX BALTAB_IDX4 ON $(RISCHK).BALLOT_TAB (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX QUESTION_IDX4 ON $(RISCHK).QUESTION (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX SCRESULT_IDX4 ON $(RISCHK).SC_BALLOT_TAB_RESULT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX SCSCALE_IDX4 ON $(RISCHK).SC_SCALE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX SCSESSION_IDX4 ON $(RISCHK).SC_SESSION (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX 
GO
 
CREATE INDEX ANSWER_IDX5 ON $(RISCHK).ANSWER (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX BALTAB_IDX5 ON $(RISCHK).BALLOT_TAB (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX QUESTION_IDX5 ON $(RISCHK).QUESTION (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX SCRESULT_IDX5 ON $(RISCHK).SC_BALLOT_TAB_RESULT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX SCSCALE_IDX5 ON $(RISCHK).SC_SCALE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX SCSESSION_IDX5 ON $(RISCHK).SC_SESSION (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX 
GO
 
CREATE INDEX ANSWER_IDX2 ON $(RISCHK).ANSWER (EXTERNAL_ID)  ON VNF_IDX 
GO
CREATE INDEX BALTAB_IDX2 ON $(RISCHK).BALLOT_TAB (EXTERNAL_ID)  ON VNF_IDX 
GO
CREATE INDEX QUESTION_IDX2 ON $(RISCHK).QUESTION (EXTERNAL_ID)  ON VNF_IDX 
GO
CREATE INDEX SCRESULT_IDX2 ON $(RISCHK).SC_BALLOT_TAB_RESULT (EXTERNAL_ID)  ON VNF_IDX 
GO
CREATE INDEX SCSCALE_IDX2 ON $(RISCHK).SC_SCALE (EXTERNAL_ID)  ON VNF_IDX 
GO
CREATE INDEX SCSESSION_IDX2 ON $(RISCHK).SC_SESSION (EXTERNAL_ID)  ON VNF_IDX 
GO
 
 
-- PRIMARY KEYS

ALTER TABLE $(RISCHK).SC_SESSION ADD CONSTRAINT SCSESS_PK PRIMARY KEY (SESSION_ID) ON  VNF_IDX 
GO

ALTER TABLE $(RISCHK).SCSESSION_PARTICIPANT_LOOKUP ADD CONSTRAINT SCSESSPART_PK PRIMARY KEY (SESSION_ID,PARTICIPANT_ID) ON  VNF_IDX 
GO

ALTER TABLE $(RISCHK).BALLOT_DEFINITION ADD CONSTRAINT BALLOTDEF_PK PRIMARY KEY (BALLOT_DEFINITION_ID)    ON  VNF_IDX 
GO

ALTER TABLE $(RISCHK).BALLOTDEF_BALLOT_TAB_LOOKUP ADD CONSTRAINT BALDEFTAB_PK PRIMARY KEY (BALLOT_DEFINITION_ID,BALLOT_TAB_ID)  ON  VNF_IDX 
GO

ALTER TABLE $(RISCHK).BALLOT ADD CONSTRAINT BALLOT_PK PRIMARY KEY (BALLOT_ID)  ON  VNF_IDX 
GO

ALTER TABLE $(RISCHK).ANSWER ADD CONSTRAINT ANSWER_PK PRIMARY KEY (ANSWER_ID)  ON  VNF_IDX 
GO

ALTER TABLE $(RISCHK).BALLOT_TAB ADD CONSTRAINT BALLOT_TAB_PK PRIMARY KEY (BALLOT_TAB_ID)  ON  VNF_IDX 
GO

ALTER TABLE $(RISCHK).QUESTION ADD CONSTRAINT QUESTION_PK PRIMARY KEY (QUESTION_ID)  ON  VNF_IDX 
GO

ALTER TABLE $(RISCHK).BALLOT_TAB_QUESTION_LOOKUP ADD CONSTRAINT BALTBQUELK_PK PRIMARY KEY (BALLOT_TAB_ID,QUESTION_ID)  ON  VNF_IDX 
GO

ALTER TABLE $(RISCHK).SCSESSION_COFACILIT_LOOKUP ADD CONSTRAINT SCSESSFASC_PK PRIMARY KEY (SESSION_ID,FACILITATOR_ID) 	ON  VNF_IDX 
GO

ALTER TABLE $(RISCHK).SC_SCALE ADD CONSTRAINT SCSCALE_PK PRIMARY KEY (SCALE_ID)  ON  VNF_IDX 
GO

ALTER TABLE $(RISCHK).SC_BALLOT_TAB_RESULT ADD CONSTRAINT SCRESULT_PK PRIMARY KEY (RESULT_ID)  ON  VNF_IDX 
GO

-- FOREIGN KEYS

ALTER TABLE $(RISCHK).SC_SESSION ADD CONSTRAINT SCSESS_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO
		
ALTER TABLE $(RISCHK).SC_SESSION ADD CONSTRAINT SCSESS_FK2 FOREIGN KEY (TEAM_ID)
REFERENCES $(NF_SCHEMA).TEAM (TEAM_ID)		
GO
		
ALTER TABLE $(RISCHK).SC_SESSION ADD CONSTRAINT SCSESS_FK3 FOREIGN KEY (BALLOT_DEFINITION_ID)
REFERENCES $(RISCHK).BALLOT_DEFINITION (BALLOT_DEFINITION_ID)				
GO
		
ALTER TABLE $(RISCHK).SCSESSION_PARTICIPANT_LOOKUP ADD CONSTRAINT SCSESSPART_FK1 FOREIGN KEY (SESSION_ID)
REFERENCES $(RISCHK).SC_SESSION (SESSION_ID)
GO
		
ALTER TABLE $(RISCHK).SCSESSION_PARTICIPANT_LOOKUP ADD CONSTRAINT SCSESSPART_FK2 FOREIGN KEY (PARTICIPANT_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)			
GO

ALTER TABLE $(RISCHK).SCSESSION_COFACILIT_LOOKUP ADD CONSTRAINT SCSESSFASC_FK1 FOREIGN KEY (SESSION_ID)
REFERENCES $(RISCHK).SC_SESSION (SESSION_ID)
GO

ALTER TABLE $(RISCHK).SCSESSION_COFACILIT_LOOKUP ADD CONSTRAINT SCSESSFASC_FK2 FOREIGN KEY (FACILITATOR_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)	
GO
    
ALTER TABLE $(RISCHK).BALLOT_DEFINITION ADD CONSTRAINT BALLOTDEF_FK3 FOREIGN KEY (SCALE_ID)
REFERENCES $(RISCHK).SC_SCALE (SCALE_ID)		     
GO

ALTER TABLE $(RISCHK).BALLOTDEF_BALLOT_TAB_LOOKUP ADD CONSTRAINT BALDEFTAB_FK1 FOREIGN KEY (BALLOT_DEFINITION_ID)
REFERENCES $(RISCHK).BALLOT_DEFINITION(BALLOT_DEFINITION_ID)
GO

ALTER TABLE $(RISCHK).BALLOTDEF_BALLOT_TAB_LOOKUP ADD CONSTRAINT BALDEFTAB_FK2 FOREIGN KEY (BALLOT_TAB_ID)
REFERENCES $(RISCHK).BALLOT_TAB (BALLOT_TAB_ID)
GO

ALTER TABLE $(RISCHK).ANSWER ADD CONSTRAINT ANSWER_FK1 FOREIGN KEY (QUESTION_ID)
REFERENCES $(RISCHK).QUESTION (QUESTION_ID)	
GO
		
ALTER TABLE $(RISCHK).ANSWER ADD CONSTRAINT ANSWER_FK2 FOREIGN KEY (BALLOT_ID)
REFERENCES $(RISCHK).BALLOT (BALLOT_ID)
GO

ALTER TABLE $(RISCHK).ANSWER ADD CONSTRAINT ANSWER_FK3 FOREIGN KEY (BALLOT_TAB_ID)
REFERENCES $(RISCHK).BALLOT_TAB (BALLOT_TAB_ID)		
GO
				
ALTER TABLE $(RISCHK).QUESTION ADD CONSTRAINT QUESTION_FK3 FOREIGN KEY (SCALE_ID)
REFERENCES $(RISCHK).SC_SCALE (SCALE_ID)		
GO
		 
ALTER TABLE $(RISCHK).BALLOT_TAB_QUESTION_LOOKUP ADD CONSTRAINT BALTBQUELK_FK1 FOREIGN KEY (BALLOT_TAB_ID)
REFERENCES $(RISCHK).BALLOT_TAB (BALLOT_TAB_ID)		
GO
		
ALTER TABLE $(RISCHK).BALLOT_TAB_QUESTION_LOOKUP ADD CONSTRAINT BALTBQUELK_FK2 FOREIGN KEY (QUESTION_ID)
REFERENCES $(RISCHK).QUESTION (QUESTION_ID)	
GO
		 		
ALTER TABLE $(RISCHK).SC_BALLOT_TAB_RESULT ADD CONSTRAINT SCRESULT_FK3 FOREIGN KEY (SESSION_ID)
REFERENCES $(RISCHK).SC_SESSION (SESSION_ID)
GO
		
ALTER TABLE $(RISCHK).SC_BALLOT_TAB_RESULT ADD CONSTRAINT SCRESULT_FK4 FOREIGN KEY (BALLOT_TAB_ID)
REFERENCES $(RISCHK).BALLOT_TAB (BALLOT_TAB_ID)			
GO

--TRIGGERS

CREATE TRIGGER TRG_BALDEFBALTAB
    ON $(RISCHK).BALLOT_DEFINITION

    FOR UPDATE
AS
BEGIN                                                                           

  DELETE FROM $(RISCHK).BALLOTDEF_BALLOT_TAB_LOOKUP  WHERE  BALLOT_DEFINITION_ID IN 
  (SELECT  BALLOT_DEFINITION_ID FROM INSERTED )
 END
GO
 
CREATE TRIGGER TRG_BALTABQUES
    ON $(RISCHK).QUESTION

    FOR UPDATE
AS
BEGIN                                                                           

  DELETE FROM $(RISCHK).BALLOT_TAB_QUESTION_LOOKUP  WHERE  QUESTION_ID IN 
  (SELECT  QUESTION_ID FROM INSERTED )
 END
GO
    
CREATE TRIGGER TRG_SESCOFACILI
    ON $(RISCHK).SC_SESSION

    FOR UPDATE
AS
BEGIN                                                                           

  DELETE FROM $(RISCHK).SCSESSION_COFACILIT_LOOKUP  WHERE  SESSION_ID IN 
  (SELECT  SESSION_ID FROM INSERTED )
 END
GO
        
CREATE TRIGGER TRG_SESPARTICI
    ON $(RISCHK).SC_SESSION

    FOR UPDATE
AS
BEGIN                                                                           

  DELETE FROM $(RISCHK).SCSESSION_PARTICIPANT_LOOKUP  WHERE  SESSION_ID IN 
  (SELECT  SESSION_ID FROM INSERTED )
 END
GO
    
