--******************************************************************************************************************************
--* Licensed Materials - Property of IBM                                                                                       *
--* (c) Copyright IBM Corp. 2008, 2009 All Rights Reserved.                                                                    *
--*                                                                                                                            *
--*US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp*
--******************************************************************************************************************************

CREATE FUNCTION REPLACE_SCHEMA (@STATEMENT VARCHAR(4000), @ODS_SCHEMA VARCHAR(20),@DM_SCHEMA VARCHAR(20),@RIBA_SCHEMA VARCHAR(20),@REP_USER VARCHAR(20))
RETURNS NVARCHAR(4000)
AS
BEGIN
		DECLARE @v_text 										VARCHAR(4000);
		DECLARE @v_ods_schema 							VARCHAR(20);
		DECLARE @v_dm_schema 							VARCHAR(20);
		DECLARE @v_riba_schema 							VARCHAR(20);
		DECLARE @v_rep_user								VARCHAR(20);
		
		SET @v_text=@STATEMENT;
		SET @v_ods_schema=@ODS_SCHEMA + '.';
		SET @v_dm_schema=@DM_SCHEMA + '.';
		SET @v_riba_schema=@RIBA_SCHEMA + '.';
		SET @v_rep_user=@REP_USER;
		
		SET @v_text=COALESCE(REPLACE(@v_text,'RIDW.',@v_dm_schema),@v_text);
		SET @v_text=COALESCE(REPLACE(@v_text,'RIBA.',@v_riba_schema),@v_text);
		SET @v_text=COALESCE(REPLACE(@v_text,'RIODS.',@v_ods_schema),@v_text);
		SET @v_text=COALESCE(REPLACE(@v_text,'REPUSER',@v_rep_user),@v_text);
		RETURN @v_text;
END
GO


CREATE PROCEDURE PROCESS_IMPLICIT_CONSTR(@SCHEMA_NAME VARCHAR(20), @TABLE_NAME VARCHAR(100), @COLUMN_NAME VARCHAR(100), @CONSTR_TYPE VARCHAR(20))
AS    
BEGIN    
			DECLARE @v_sqlcode INT; 
            SET @v_sqlcode=0;  	
			DECLARE @v_constr_defval VARCHAR(100) ;		

			BEGIN TRANSACTION Timplicit
			IF (@CONSTR_TYPE = 'D')
					SELECT @v_constr_defval=d.name
			    FROM sys.default_constraints AS d
				JOIN sys.objects AS o ON o.object_id = d.parent_object_id AND o.name=@TABLE_NAME
				JOIN sys.columns AS c ON c.object_id = o.object_id AND c.column_id = d.parent_column_id AND c.name=@COLUMN_NAME
				JOIN sys.schemas AS s ON s.schema_id = o.schema_id AND s.name=@SCHEMA_NAME;
				
			IF (@v_constr_defval IS NOT NULL) 
						EXECUTE ('ALTER TABLE ' + @SCHEMA_NAME + '.' + @TABLE_NAME + ' DROP CONSTRAINT ' + @v_constr_defval);
			COMMIT TRANSACTION Timplicit;
END
GO

CREATE PROCEDURE PROCESS_ALL_CONSTR(@SCHEMA_NAME VARCHAR(20), @TABLE_NAME VARCHAR(100), @COLUMN_NAME VARCHAR(100))
AS    
BEGIN    
			DECLARE @v_sqlcode INT; 
      		SET @v_sqlcode=0;  	
			DECLARE @v_constr_defval VARCHAR(100) ;		

			BEGIN TRANSACTION TallConstr		
			DECLARE implicitCur CURSOR FOR 
 				SELECT c.CONSTRAINT_NAME
				FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE AS c
				WHERE c.TABLE_SCHEMA=@SCHEMA_NAME AND c.TABLE_NAME=@TABLE_NAME and c.COLUMN_NAME=@COLUMN_NAME
				UNION
			    SELECT d.name
			    FROM sys.default_constraints AS d
				JOIN sys.objects AS o ON o.object_id = d.parent_object_id AND o.name=@TABLE_NAME
				JOIN sys.columns AS c ON c.object_id = o.object_id AND c.column_id = d.parent_column_id AND c.name=@COLUMN_NAME
				JOIN sys.schemas AS s ON s.schema_id = o.schema_id AND s.name=@SCHEMA_NAME;
  			OPEN implicitCur;
  			FETCH NEXT FROM implicitCur INTO @v_constr_defval;
  			WHILE @@FETCH_STATUS = 0
  			BEGIN
					IF (@v_constr_defval IS NOT NULL) 
								EXECUTE ('ALTER TABLE ' + @SCHEMA_NAME + '.' + @TABLE_NAME + ' DROP CONSTRAINT ' + @v_constr_defval);	
					FETCH NEXT FROM implicitCur INTO @v_constr_defval;
  	  		END  
  			CLOSE implicitCur;
  			DEALLOCATE implicitCur;
			COMMIT TRANSACTION TallConstr;
END
GO




CREATE PROCEDURE GET_REFERENCE_DEFINE(@SCHEMA_NAME VARCHAR(20), @TABLE_NAME VARCHAR(100), @COLUMN_NAME VARCHAR(100), @TMPREFTAB VARCHAR(100))
AS    
BEGIN    
		DECLARE @v_sqlcode INT; 
		SET @v_sqlcode=0;
		DECLARE @v_refdefine VARCHAR(2048);
		DECLARE @v_constname VARCHAR(100);
		DECLARE @v_schemaname  VARCHAR(100);
		DECLARE @v_tabname  VARCHAR(100);
		DECLARE @v_colname  VARCHAR(100);
		DECLARE @v_deleteaction INT;
		DECLARE @v_updateaction INT;
		DECLARE @v_actstr VARCHAR(2048);
		
		DECLARE refdefCur CURSOR FOR  					
			SELECT object_name(f.constid), s.name, object_name(f.fkeyid), c.name, fk.delete_referential_action, fk.update_referential_action
					FROM sys.sysforeignkeys AS f
							JOIN sys.objects AS o ON f.fkeyid = o.object_id
							JOIN sys.schemas AS s ON s.schema_id = o.schema_id 
							JOIN sys.columns AS c ON c.object_id = o.object_id AND c.column_id = f.fkey
							JOIN sys.foreign_keys AS fk ON fk.object_id = f.constid AND fk.schema_id = s.schema_id
							JOIN sys.objects AS o2 ON f.rkeyid = o2.object_id AND o2.name=@TABLE_NAME
							JOIN sys.schemas AS s2 ON s2.schema_id = o2.schema_id AND s2.name=@SCHEMA_NAME
							JOIN sys.columns AS c2 ON c2.object_id = o2.object_id AND c2.column_id = f.rkey AND c2.name=@COLUMN_NAME;

		OPEN refdefCur;
		FETCH NEXT FROM refdefCur INTO @v_constname, @v_schemaname, @v_tabname, @v_colname, @v_deleteaction, @v_updateaction;
		WHILE @@FETCH_STATUS = 0
		BEGIN
				SET @v_actstr = '';
				IF (@v_updateaction = 1) 
						SET @v_actstr = @v_actstr + ' ON UPDATE CASCADE ';
				IF (@v_deleteaction = 1) 
						SET @v_actstr = @v_actstr + ' ON DELETE CASCADE ';
				SET @v_refdefine='ALTER TABLE '+ @v_schemaname+'.'+@v_tabname+' ADD CONSTRAINT '+ @v_constname +' FOREIGN KEY('+@v_colname+') REFERENCES '+@SCHEMA_NAME+'.'+@TABLE_NAME+'('+@COLUMN_NAME+')'+@v_actstr;
				EXECUTE ('INSERT ' + @TMPREFTAB + ' VALUES(''' + @v_schemaname + ''','''+@v_constname + ''','''+ @v_tabname + ''',''' + @v_refdefine +''')');	
				FETCH NEXT FROM refdefCur INTO @v_constname, @v_schemaname, @v_tabname, @v_colname, @v_deleteaction, @v_updateaction;
		END  
		CLOSE refdefCur;
		DEALLOCATE refdefCur;
				
END
GO


CREATE FUNCTION GET_IDXCOL_LIST (@OBJECT_ID INT, @INDEX_ID INT)
RETURNS NVARCHAR(2048)
AS
BEGIN
	DECLARE	@v_colname			VARCHAR(100);
	DECLARE	@v_colseq			INT;
	DECLARE	@v_maxcolseq		INT;
	DECLARE @v_sqlcode INT; 
	SET @v_sqlcode=0;
	DECLARE	@v_text				VARCHAR(100);

	SET @v_text='';
	DECLARE idxcolCur CURSOR FOR
		SELECT (SELECT c.name FROM sys.columns c WHERE object_id = @OBJECT_ID AND column_id = idxcol.column_id) AS COLNAME, index_column_id, 
				(SELECT MAX(index_column_id) FROM sys.index_columns WHERE object_id = @OBJECT_ID AND index_id = @INDEX_ID) AS MAXCOLSEQ
				FROM sys.index_columns idxcol 
					WHERE object_id = @OBJECT_ID AND index_id = @INDEX_ID
				ORDER BY index_column_id;

	OPEN idxcolCur;
	FETCH NEXT FROM idxcolCur INTO @v_colname, @v_colseq, @v_maxcolseq;
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SET @v_text=@v_text+@v_colname;
		IF (@v_colseq <> @v_maxcolseq) 
				SET @v_text=@v_text+',';
			
		FETCH NEXT FROM idxcolCur INTO @v_colname, @v_colseq, @v_maxcolseq;	
	END
	CLOSE idxcolCur;
	DEALLOCATE idxcolCur;
	RETURN @v_text;
END
GO


CREATE PROCEDURE GET_INDEX_DEFINE(@SCHEMA_NAME VARCHAR(20), @TABLE_NAME VARCHAR(100), @COLUMN_NAME VARCHAR(100), @TMPIDXTAB VARCHAR(100))
AS    
BEGIN    
		DECLARE @v_sqlcode INT; 
		SET @v_sqlcode=0;
		DECLARE @v_idxdefine VARCHAR(2048);
		DECLARE @v_idxname VARCHAR(100);
		DECLARE @v_schemaname  VARCHAR(100);
		DECLARE @v_tabname  VARCHAR(100);
		DECLARE @v_idxcol_list  VARCHAR(1024);
		DECLARE @v_datspace VARCHAR(100);
		DECLARE @v_object_id INT;
		DECLARE @v_index_id INT;
		
		
		DECLARE idxdefCur CURSOR FOR  					
			SELECT i.object_id, i.index_id, i.name, (SELECT name FROM sys.data_spaces WHERE data_space_id=i.data_space_id)
					FROM sys.indexes AS i
							JOIN sys.objects AS o ON i.object_id = o.object_id AND o.name=@TABLE_NAME
							JOIN sys.schemas AS s ON s.schema_id = o.schema_id AND s.name=@SCHEMA_NAME
					WHERE i.is_primary_key != 1 AND EXISTS (SELECT c.object_id FROM sys.index_columns idxcol
										JOIN sys.columns AS c ON c.object_id = o.object_id AND c.object_id = idxcol.object_id AND i.index_id = idxcol.index_id 
										AND c.column_id = idxcol.column_id AND c.name=@COLUMN_NAME)												
					;

		OPEN idxdefCur;
		FETCH NEXT FROM idxdefCur INTO @v_object_id, @v_index_id, @v_idxname, @v_datspace;
		WHILE @@FETCH_STATUS = 0
		BEGIN
				SET @v_idxcol_list=dbo.GET_IDXCOL_LIST (@v_object_id, @v_index_id);
				SET @v_idxdefine='CREATE INDEX '+@v_idxname+' ON ' + @SCHEMA_NAME + '.' + @TABLE_NAME + '(' + @v_idxcol_list + ') ON ' + @v_datspace;
				EXECUTE ('INSERT ' + @TMPIDXTAB + ' VALUES(''' + @SCHEMA_NAME +''','''+ @v_idxname +''',''' + @TABLE_NAME + ''',''' + @v_idxdefine + ''')');
				FETCH NEXT FROM idxdefCur INTO @v_object_id, @v_index_id, @v_idxname, @v_datspace;
		END
		CLOSE idxdefCur;
		DEALLOCATE idxdefCur; 
				
END
GO


CREATE PROCEDURE GET_DEFAULT_CONSTR(@SCHEMA_NAME VARCHAR(20), @TABLE_NAME VARCHAR(100), @COLUMN_NAME VARCHAR(100), @TMPDEFTAB VARCHAR(100))
AS    
BEGIN    
		DECLARE @v_sqlcode INT; 
    SET @v_sqlcode=0;  	
		DECLARE @v_constr_defval VARCHAR(100) ;	
		DECLARE @v_definition VARCHAR(100) ;	
		DECLARE @v_defdefine VARCHAR(2048) ;

		DECLARE DCCur CURSOR FOR 
					SELECT d.name, CASE WHEN c.system_type_id =61 THEN SUBSTRING(d.definition, 2, len(d.definition)-2)
															WHEN c.system_type_id in (231,239) THEN RTRIM(REPLACE(SUBSTRING(d.definition, 2, len(d.definition)-2) ,CHAR(39), CHAR(39)+CHAR(39)))
															ELSE SUBSTRING(d.definition, 3, len(d.definition)-4) END AS definition
			    FROM sys.default_constraints AS d
				JOIN sys.objects AS o ON o.object_id = d.parent_object_id AND o.name=@TABLE_NAME
				JOIN sys.columns AS c ON c.object_id = o.object_id AND c.column_id = d.parent_column_id AND c.name=@COLUMN_NAME
				JOIN sys.schemas AS s ON s.schema_id = o.schema_id AND s.name=@SCHEMA_NAME;
			
		OPEN DCCur;
		FETCH NEXT FROM DCCur INTO @v_constr_defval, @v_definition;
		WHILE @@FETCH_STATUS = 0
		BEGIN
				SET @v_defdefine='ALTER TABLE ' + @SCHEMA_NAME + '.' + @TABLE_NAME + ' ADD CONSTRAINT ' + @v_constr_defval + ' DEFAULT ' + @v_definition + ' FOR ' + @COLUMN_NAME;
				EXECUTE ('INSERT ' + @TMPDEFTAB + ' VALUES(''' + @SCHEMA_NAME + ''',''' + @v_constr_defval + ''',''' + @TABLE_NAME + ''',''' + @v_defdefine + ''')');		
				FETCH NEXT FROM DCCur INTO @v_constr_defval, @v_definition;
		END
		CLOSE DCCur;
		DEALLOCATE DCCur;
END
GO


CREATE PROCEDURE PROCESS_COLUMN_UPDATE(@SCHEMA_NAME VARCHAR(20), @TABLE_NAME VARCHAR(100), @COLUMN_NAME VARCHAR(100), @COLOMN_UPDATE_DDL VARCHAR(100))
AS    
BEGIN    
		DECLARE @v_sqlcode INT; 
		SET @v_sqlcode=0;
		DECLARE @v_sqlstate CHAR(5) ;
		SET @v_sqlstate= '00000';
		
		DECLARE @v_defdefine VARCHAR(2048);
		DECLARE @v_refdefine VARCHAR(2048);
		DECLARE @v_idxdefine VARCHAR(2048);
		DECLARE @v_schemaname  VARCHAR(100);
		DECLARE @v_tabname  VARCHAR(100);
		DECLARE @v_constname VARCHAR(100);
		DECLARE @v_idxname VARCHAR(100);
		DECLARE @v_idxcol_list  VARCHAR(1024);
		DECLARE @v_datspace VARCHAR(100);


		-- DEFINE A CACHE FOR DEFAULT VAULE ON THE COLUMN_NAME
		-- DECLARE @vt_defdefine table(constschema VARCHAR(20), constname VARCHAR(32), tabname VARCHAR(100), defdefine VARCHAR(2048));
		IF object_id('tempdb..#vt_defdefine') IS NOT NULL
				DROP TABLE #vt_defdefine;
		CREATE TABLE #vt_defdefine (constschema VARCHAR(20), constname VARCHAR(32), tabname VARCHAR(100), defdefine VARCHAR(2048));
				
		-- DEFINE A CACHE FOR REFERENCES ON THE COLUMN_NAME
		-- DECLARE @vt_refdefine table(constschema VARCHAR(20), constname VARCHAR(32), tabname VARCHAR(100), refdefine VARCHAR(2048));
		IF object_id('tempdb..#vt_refdefine') IS NOT NULL
				DROP TABLE #vt_refdefine;
		CREATE TABLE #vt_refdefine (constschema VARCHAR(20), constname VARCHAR(32), tabname VARCHAR(100), refdefine VARCHAR(2048));
		
		-- DEFINE A CACHE FOR INDEXES ON THE COLUMN_NAME
		-- DECLARE @vt_idxdefine table(indexschema VARCHAR(20), indexname VARCHAR(32), tabname VARCHAR(100), idxdefine VARCHAR(2048));
		IF object_id('tempdb..#vt_idxdefine') IS NOT NULL
				DROP TABLE #vt_idxdefine;
		CREATE TABLE #vt_idxdefine (indexschema VARCHAR(20), indexname VARCHAR(32), tabname VARCHAR(100), idxdefine VARCHAR(2048));


		-- GET DEFAULT CONSTRAINT DEFINE
		EXEC GET_DEFAULT_CONSTR @SCHEMA_NAME, @TABLE_NAME, @COLUMN_NAME, '#vt_defdefine';
		
		-- GET REFERENCES DEFINE
		EXEC dbo.GET_REFERENCE_DEFINE @SCHEMA_NAME, @TABLE_NAME, @COLUMN_NAME, '#vt_refdefine';
		
		-- GET INDEXES DEFINE
		EXEC dbo.GET_INDEX_DEFINE @SCHEMA_NAME, @TABLE_NAME, @COLUMN_NAME, '#vt_idxdefine';


		-- DROP CONSTRAINTS ON COLUMN
		DECLARE defCur CURSOR FOR SELECT constschema, constname, tabname, defdefine FROM #vt_defdefine; 
		OPEN defCur;
		FETCH NEXT FROM defCur INTO @v_schemaname, @v_constname, @v_tabname, @v_defdefine;
		WHILE @@FETCH_STATUS = 0
		BEGIN
				EXECUTE ('ALTER TABLE ' + @v_schemaname + '.' + @v_tabname + ' DROP CONSTRAINT ' + @v_constname);
				PRINT ('ALTER TABLE ' + @v_schemaname + '.' + @v_tabname + ' DROP CONSTRAINT ' + @v_constname);
				FETCH NEXT FROM defCur INTO @v_schemaname, @v_constname, @v_tabname, @v_defdefine;
		END  
		CLOSE defCur;
		DEALLOCATE defCur;

		-- DROP CONSTRAINTS ON COLUMN
		DECLARE refCur CURSOR FOR SELECT constschema, constname, tabname, refdefine FROM #vt_refdefine; 
		OPEN refCur;
		FETCH NEXT FROM refCur INTO @v_schemaname, @v_constname, @v_tabname, @v_refdefine;
		WHILE @@FETCH_STATUS = 0
		BEGIN
				EXECUTE ('ALTER TABLE ' + @v_schemaname + '.' + @v_tabname + ' DROP CONSTRAINT ' + @v_constname);
				PRINT ('ALTER TABLE ' + @v_schemaname + '.' + @v_tabname + ' DROP CONSTRAINT ' + @v_constname);
				FETCH NEXT FROM refCur INTO @v_schemaname, @v_constname, @v_tabname, @v_refdefine;
		END  
		CLOSE refCur;
		DEALLOCATE refCur;

		-- DROP INDEXES ON COLUMN
		DECLARE idxCur CURSOR FOR SELECT indexschema, indexname, tabname, idxdefine FROM #vt_idxdefine; 
		OPEN idxCur;
		FETCH NEXT FROM idxCur INTO @v_schemaname, @v_idxname, @v_tabname, @v_idxdefine;
		WHILE @@FETCH_STATUS = 0
		BEGIN
				EXECUTE ('DROP INDEX ' + @v_idxname  + ' ON ' + @v_schemaname + '.' + @v_tabname);
				PRINT ('DROP INDEX ' + @v_idxname  + ' ON ' + @v_schemaname + '.' + @v_tabname);
				FETCH NEXT FROM idxCur INTO @v_schemaname, @v_idxname, @v_tabname, @v_idxdefine;
		END
		CLOSE idxCur;
		DEALLOCATE idxCur;
		
		-- EXECUTE UPDATE MIGRATION DDL ON THE COLUMN
		EXECUTE (@COLOMN_UPDATE_DDL);
		SELECT @v_sqlstate=@@ERROR;
		IF (@v_sqlstate <> 0)
					RETURN @v_sqlstate;

		-- REINSTATE DEFAULT CONSTRAINTSON COLUMN
		DECLARE defCur CURSOR FOR SELECT defdefine FROM #vt_defdefine; 
		OPEN defCur;
		FETCH NEXT FROM defCur INTO @v_defdefine;
		WHILE @@FETCH_STATUS = 0
		BEGIN
				EXECUTE (@v_defdefine);
				FETCH NEXT FROM defCur INTO @v_defdefine;
		END  
		CLOSE defCur;
		DEALLOCATE defCur;

		-- REINSTATE REFERENCE CONSTRAINTS ON COLUMN
		DECLARE refCur CURSOR FOR SELECT refdefine FROM #vt_refdefine; 
		OPEN refCur;
		FETCH NEXT FROM refCur INTO @v_refdefine;
		WHILE @@FETCH_STATUS = 0
		BEGIN
				EXECUTE (@v_refdefine);
				FETCH NEXT FROM refCur INTO @v_refdefine;
		END  
		CLOSE refCur;
		DEALLOCATE refCur;

		-- REINSTATE INDEXES ON COLUMN
		DECLARE idxCur CURSOR FOR SELECT idxdefine FROM #vt_idxdefine; 
		OPEN idxCur;
		FETCH NEXT FROM idxCur INTO @v_idxdefine;
		WHILE @@FETCH_STATUS = 0
		BEGIN
				PRINT (@v_idxdefine);
				EXECUTE (@v_idxdefine);
				FETCH NEXT FROM idxCur INTO @v_idxdefine;
		END  
		CLOSE idxCur;
		DEALLOCATE idxCur;
		
		RETURN @v_sqlstate;
END
GO


