--******************************************************************************************************************************
--* Licensed Materials - Property of IBM                                                                                       *
--* (c) Copyright IBM Corp. 2008, 2009 All Rights Reserved.                                                                    *
--*                                                                                                                            *
--*US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp*
--******************************************************************************************************************************

--=============  Create the model for NF schema 

USE $(DBNAME)
 GO
CREATE SCHEMA AUTHORIZATION $(NF_SCHEMA)
GO

CREATE TABLE $(NF_SCHEMA).CUSTOMER (
		CUSTOMER_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Customer Name Missing' NOT NULL,
		CUST_REFID NVARCHAR(100),
		COMPANY_NAME NVARCHAR(255),
		GEO_LOCATION NVARCHAR(255),
		CONTACT_EMAIL NVARCHAR(255),
		CONTACT_PHONE NVARCHAR(255),
		CONTACT_FAX NVARCHAR(255),
		CONTACT_ADDRESS NVARCHAR(255),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ACTIVITY (
		ACTIVITY_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Missing Activity Name' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		ACTIVITY_CLASS_ID INT  DEFAULT -1 NOT NULL,
		TASK_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		PROFILE_ID INT  DEFAULT -1 NOT NULL,
		FAILED_BUILD INT  DEFAULT -1 NOT NULL,
		CREATION_DATE DATETIME,
		VALIDATION_BUILD INT  DEFAULT -1 NOT NULL,
		NOTEST_BUILD INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		FILE_STREAM_ID INT  DEFAULT -1 NOT NULL,
		CHARGECODE_ID INT  DEFAULT -1 NOT NULL,
		ACTIVITY_STATE NVARCHAR(255),
		PRIORITY NVARCHAR(255),
		STATUS NVARCHAR(255),
		RESOLUTION NVARCHAR(255),
		ACTIVITY_TYPE NVARCHAR(255),
		RESOLUTION_CODE NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ACTIVITY_CLASSIFICATION (
		ACTIVITY_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Activity Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_ACTIVITY_LOOKUP(
		REQUEST_ID INT  NOT NULL,
		ACTIVITY_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).COMPONENT (
		COMPONENT_ID INT  NOT NULL,
		COMPONENT_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Component Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PRODUCT_ID INT  DEFAULT -1 NOT NULL,
		PARENT_COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_COMPONENT_LOOKUP (
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		COMPONENT_ID INT  DEFAULT -1 NOT NULL
	) ON VNF_32K 
GO

	
CREATE TABLE $(NF_SCHEMA).COMPONENT_CLASSIFICATION (
		COMPONENT_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Component Class Name Missing' NOT NULL
	) ON VNF_32K 
GO

	
CREATE TABLE $(NF_SCHEMA).BUILD_CLASSIFICATION (
		BUILD_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Component Class Name Missing' NOT NULL
	) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).BUILD (
		BUILD_ID INT  NOT NULL,
		BUILD_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Build Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		BASELINE_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_TYPE_ID INT  DEFAULT -1 NOT NULL,
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		TEAM_ID INT  DEFAULT -1 NOT NULL,
		BUILD_STATE NVARCHAR(255),
		STATUS NVARCHAR(255),
		START_TIME DATETIME,
		END_TIME DATETIME,
		BUILD_TYPE NVARCHAR(255),
		CREATION_DATE DATETIME,
		WAITING_TIME BIGINT,        
		BUILDING_TIME BIGINT,        
		ENGINE NVARCHAR(255),		
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT (
		REQUIREMENT_ID INT  NOT NULL,
		REQUIREMENT_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Requirement Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		PLANNED_ITERATION_ID INT  DEFAULT -1 NOT NULL,
		ACTUAL_ITERATION_ID INT  DEFAULT -1 NOT NULL,
		RELEASE_ID INT  DEFAULT -1 NOT NULL,
		STATUS NVARCHAR(255),
		REQUIREMENT_TYPE NVARCHAR(255),
		REQUIREMENT_STATE NVARCHAR(255),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		DIFFICULTY NVARCHAR(255),
		STABILITY NVARCHAR(255),
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		CREATION_DATE DATETIME,
		PRIORITY NVARCHAR(255),
		CUSTOMER_PRIORITY NVARCHAR(255),
		PLATFORM NVARCHAR(255),
		REVISION_NUMBER NVARCHAR(50),
		REVISION_DATE DATETIME DEFAULT GETDATE() NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).REQUIREMENT_COLLECTION (
		REQUIREMENT_COLLECTION_ID INT NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Requirement Collection Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT DEFAULT -1 NOT NULL,
		RELEASE_ID INT DEFAULT -1 NOT NULL,
		PLANNED_ITERATION_ID INT DEFAULT -1 NOT NULL,
		ACTUAL_ITERATION_ID INT DEFAULT -1 NOT NULL,
		STATUS NVARCHAR(255),
		COLLECTION_ORIGIN NVARCHAR(255),
		COLLECTION_TYPE NVARCHAR(255),
		COLLECTION_IMPACT NVARCHAR(255),
		COLLECTION_TARGET NVARCHAR(255),
		CREATION_DATE DATETIME,
		EXTERNAL_KEY1 INT DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).REQUICOL_REQUIREMENT_LOOKUP (
		REQUIREMENT_COLLECTION_ID INT NOT NULL,
		REQUIREMENT_ID INT NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).REQUICOL_TESTPLAN_LOOKUP (
		REQUIREMENT_COLLECTION_ID INT NOT NULL,
		TESTPLAN_ID INT NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).REQUIREMENT_REVISION_HISTORY (
		REQUIREMENT_REVISION_ID INT  NOT NULL,
		REQUIREMENT_ID INT  NOT NULL,
		REVISION_NUMBER NVARCHAR(50) DEFAULT '0' NOT NULL,
		RESOURCE_ID INT  DEFAULT -1 NOT NULL,
		CHANGE_DATE  DATETIME  DEFAULT GETDATE() NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


	
CREATE TABLE $(NF_SCHEMA).TESTSUITE (
		TESTSUITE_ID INT  NOT NULL,
	    TESTSUITE_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'TestSuite Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		CONFIGURATION_ID INT  DEFAULT -1 NOT NULL,
		ASSETREGISTRY_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		TESTSUITE_STATE NVARCHAR(255),
		LAST_UPDATED DATETIME,
		CREATION_DATE DATETIME,
		DESCRIPTION	NVARCHAR(255),
		ISSEQUENTIAL SMALLINT,
		CREATOR_ID INT  DEFAULT -1 NOT NULL,
		WEIGHT INT ,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECUTION_RESULT (
		EXECUTION_RESULT_ID INT  DEFAULT -1 NOT NULL,
		EXECRES_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Execution Result Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		VERDICT NVARCHAR(255),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		BUILD_ID INT  DEFAULT -1 NOT NULL,
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		TESTTYPE_ID INT  DEFAULT -1 NOT NULL,
		TESTCASE_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		TESTSCRIPT_ID INT  DEFAULT -1 NOT NULL,
		START_DATE DATETIME,
		END_DATE DATETIME,
		POINTS_BLOCKED INT  DEFAULT 0 NOT NULL,
		POINTS_INCONCLUSIVE INT  DEFAULT 0 NOT NULL,
		MACHINE NVARCHAR(255),
		POINTS_ATTEMPTED INT  DEFAULT 0 NOT NULL,
		POINTS_FAILED INT  DEFAULT 0 NOT NULL,
		POINTS_PASSED INT  DEFAULT 0 NOT NULL,
		POINTS_PERMFAILED INT  DEFAULT 0 NOT NULL,
		LAST_UPDATED DATETIME,
		CREATION_DATE DATETIME,
		SUITE_INDEX INT,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CURRENCY (
		CURRENCY_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Currency Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		EXCHANGE_RATE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		VALID_START_DATE DATETIME,
		VALID_FINISH_DATE DATETIME,
		DEFAULT_CURRENCY INT  DEFAULT 0 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).OPERATING_TERRITORY(
		TERRITORY_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Territory Name Missing' NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).COUNTRY (
		COUNTRY_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Country Name Missing' NOT NULL,
		TERRITORY_ID INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROVINCE_STATE (
		PROVINCE_STATE_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Province or State Name Missing' NOT NULL,
		COUNTRY_ID INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CITY (
		CITY_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'City Name Missing' NOT NULL,
		PROVINCE_STATE_ID INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ORGANIZATION (
		ORGANIZATION_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Organization Name Missing' NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).POOL (
		POOL_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Pool Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PARENT_POOL_ID INT  DEFAULT -1 NOT NULL ,
		POOL_TYPE NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).RESOURCE (
		RESOURCE_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Resource Logon Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		FULL_NAME NVARCHAR(110) DEFAULT 'Resource Full Name Missing' NOT NULL,
		FIRST_NAME NVARCHAR(35),
		LAST_NAME NVARCHAR(35),
		MIDDLE_INITIAL NVARCHAR(35),
		RESOURCE_TYPE SMALLINT,
		STANDARD_RATE DECIMAL(18 , 2),
		OVERTIME_RATE DECIMAL(18 , 2),
		POOL_ID INT  DEFAULT -1 NOT NULL,
		CITY_ID INT  DEFAULT -1 NOT NULL,
		ORGANIZATION_ID INT  DEFAULT -1 NOT NULL,
		EFFECTIVE_DATE DATETIME ,
		DISCONTINUE_DATE DATETIME ,
		TIME_PER_DAY INT,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).SKILL (
		SKILL_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Skill Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).RESOURCE_SKILL_LOOKUP (
		RESOURCE_ID INT  NOT NULL,
		SKILL_ID INT  NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).COMPETENCY (
		COMPETENCY_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Competency Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).RESOURCE_COMPETENCY_LOOKUP (
		RESOURCE_ID INT  NOT NULL,
		COMPETENCY_ID INT  NOT NULL
) ON VNF_32K 
GO
CREATE TABLE $(NF_SCHEMA).TASK_BASELINE (
		BASELINE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Baseline Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		TASK_ID INT  DEFAULT -1 NOT NULL,
		BASELINE_DATE DATETIME,
		PLANNED_START DATETIME ,
		PLANNED_FINISH DATETIME ,
		PLANNED_WORK INT ,
		PLANNED_COST DECIMAL(18 , 2),
		PLANNED_DURATION INT ,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(80) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TASK_CLASSIFICATION (
		TASK_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Task Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TASK_CATEGORY (
		TASK_CATEGORY_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Task Category Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		CATEGORY_TYPE NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PRODUCT (
		PRODUCT_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Product Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ASSETREGISTRY (
		ASSETREGISTRY_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'AssetRegistry Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ITERATION (
		ITERATION_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Iteration Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		ASSETREGISTRY_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		PHASE_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT-1 NOT NULL,
		STATUS NVARCHAR(255),
		START_DATE DATETIME,
		END_DATE DATETIME,
		EXPECTED_START_DATE DATETIME,
		EXPECTED_END_DATE DATETIME,
		EXPECTED_TOTAL_POINTS INT  DEFAULT 0 NOT NULL,
		EXPECTED_DEFECTS INT  DEFAULT 0 NOT NULL,
		EXPECTED_VALIDITY_RATE DECIMAL (18,2) DEFAULT 0.00 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ITERATION_DETAIL (
		ITERATION_ID INT  NOT NULL,
		ACTUAL_DURATION INT  DEFAULT 0 NOT NULL,       
		ACTUAL_WORK INT  DEFAULT 0 NOT NULL,
		ACTUAL_WORK_VARIANCE INT  DEFAULT 0 NOT NULL,
		ACTUAL_START_VARIANCE INT  DEFAULT 0 NOT NULL,
		ACTUAL_FINISH_VARIANCE INT  DEFAULT 0 NOT NULL,
		ACTUAL_START DATETIME ,
		ACTUAL_FINISH DATETIME ,
		ACTUAL_COST  DECIMAL(18,2) DEFAULT 0.00 NOT NULL,
		ACTUAL_COST_VARIANCE DECIMAL(18,2) DEFAULT 0.00 NOT NULL,
		BASELINE_DURATION INT   DEFAULT 0 NOT NULL,
		BASELINE_WORK INT  DEFAULT 0 NOT NULL,
		BASELINE_WORK_VARIANCE  INT   DEFAULT 0 NOT NULL,
		BASELINE_FINISH_VARIANCE  INT   DEFAULT 0 NOT NULL,
		BASELINE_START_VARIANCE  INT   DEFAULT 0 NOT NULL,
		BASELINE_COST_VARIANCE DECIMAL(18,2) DEFAULT 0.00 NOT NULL,
		BASELINE_START DATETIME ,
		BASELINE_FINISH DATETIME ,
		PLANNED_COST DECIMAL(18,2) DEFAULT 0.00 NOT NULL,         
		COST_VARIANCE  DECIMAL(18,2) DEFAULT 0.00 NOT NULL,
		PLANNED_DURATION INT   DEFAULT 0 NOT NULL,      
		PLANNED_WORK INT   DEFAULT 0 NOT NULL,
		WORK_VARIANCE INT   DEFAULT 0 NOT NULL,
		START_VARIANCE  INT   DEFAULT 0 NOT NULL,
		FINISH_VARIANCE  INT   DEFAULT 0 NOT NULL,        
		DURATION_VARIANCE INT   DEFAULT 0 NOT NULL,
		PLANNED_START DATETIME ,
		PLANNED_FINISH DATETIME ,
		PERCENT_COMPLETE DECIMAL(5 , 2),
		PERCENT_WORK_COMPLETE DECIMAL(5 , 2)
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ITERATION_BASELINE (
		BASELINE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Iteration Baseline Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		BASELINE_DATE DATETIME,
		PLANNED_START DATETIME ,
		PLANNED_FINISH DATETIME ,
		PLANNED_WORK INT ,
		BASELINE_WORK_COMPLETED INT ,
		PLANNED_COST DECIMAL(18 , 2),
		BASELINE_COST_COMPLETED DECIMAL(18 , 2),
		PLANNED_DURATION INT ,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(80) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO



CREATE TABLE $(NF_SCHEMA).RELEASE (
		RELEASE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Release Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		PRODUCT_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		AVAILABILITY_DATE DATETIME ,
		DECOMISSION_DATE DATETIME ,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROGRAM (
		PROGRAM_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Program Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROGRAM_MANAGER INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

		
CREATE TABLE $(NF_SCHEMA).PROGRAM_DETAIL (
		PROGRAM_ID INT  NOT NULL,
        CURRENCY_ID INT  DEFAULT -1 NOT NULL,
		ACTUAL_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		CURRENT_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_VARIANCE INT  DEFAULT 0,
		ACTUAL_START DATETIME ,
		ACTUAL_FINISH DATETIME ,
		PLANNED_START DATETIME ,
		PLANNED_FINISH DATETIME ,
		ACWP DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BAC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BCWP DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BCWS DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EAC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EV_ETC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EV_FLAG DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_DURATION INT  DEFAULT 0 NOT NULL,
		ACTUAL_WORK INT  DEFAULT 0 NOT NULL,
		ACTUAL_WORK_VARIANCE INT  DEFAULT 0 NOT NULL,
		ACTUAL_START_VARIANCE INT  DEFAULT 0 NOT NULL,
		ACTUAL_FINISH_VARIANCE INT  DEFAULT 0 NOT NULL,
		ACTUAL_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_COST_VARIANCE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BUDGETED_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		COST_VARIANCE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_DURATION INT  DEFAULT 0 NOT NULL,
		PLANNED_WORK INT  DEFAULT 0 NOT NULL,
		WORK_VARIANCE INT  DEFAULT 0 NOT NULL,
		START_VARIANCE INT  DEFAULT 0 NOT NULL,
		FINISH_VARIANCE INT  DEFAULT 0 NOT NULL,
		DURATION_VARIANCE INT  DEFAULT 0 NOT NULL,
		PERCENT_COMPLETE DECIMAL(5 , 2) DEFAULT 0.00 NOT NULL,
		PERCENT_WORK_COMPLETE DECIMAL(5 , 2) DEFAULT 0.00 NOT NULL,
		BUDGETED_REVENUE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_REVENUE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_REVENUE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		NET_PRESENT_VALUE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		INTERNAL_RATE_OF_RETURN DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT (
		PROJECT_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Project Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROGRAM_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_CLASS_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_MANAGER INT  DEFAULT -1 NOT NULL,
		PROJECT_CATEGORY_ID INT  DEFAULT -1 NOT NULL,
		START_DATE DATETIME,
		END_DATE DATETIME,
		SHIP_DATE DATETIME,
		PRIORITY NVARCHAR(255),
		STATUS NVARCHAR(255),
		FEASIBILITY NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TASK (
		TASK_ID INT  NOT NULL,
		TASK_CATEGORY_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Task Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		TASK_CLASS_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		TASK_STATE NVARCHAR(255),
		PRIORITY NVARCHAR(255),
		STATUS NVARCHAR(255),
		RESOLUTION NVARCHAR(255),
		TASK_TYPE NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_HIERARCHY (
		PARENT_PROJECT_ID INT  NOT NULL,
		CHILD_PROJECT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_DETAIL (
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		CURRENCY_ID INT  DEFAULT -1 NOT NULL,
		BASELINE_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BASELINE_START DATETIME ,
		BASELINE_FINISH DATETIME ,
		BASELINE_VARIANCE INT  DEFAULT 0 NOT NULL,
		BASELINE_ESTIMATED_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BASELINE_ESTIMATED_START DATETIME ,
		BASELINE_ESTIMATED_FINISH DATETIME ,
		ACTUAL_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		CURRENT_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_VARIANCE INT  DEFAULT 0,
		ACTUAL_START DATETIME ,
		ACTUAL_FINISH DATETIME ,
		PLANNED_START DATETIME ,
		PLANNED_FINISH DATETIME ,
		ACWP DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BAC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BCWP DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BCWS DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EAC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EV_ETC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EV_FLAG DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_DURATION INT  DEFAULT 0 NOT NULL,
		ACTUAL_WORK INT  DEFAULT 0 NOT NULL,
		ACTUAL_WORK_VARIANCE INT  DEFAULT 0 NOT NULL,
		ACTUAL_START_VARIANCE INT  DEFAULT 0 NOT NULL,
		ACTUAL_FINISH_VARIANCE INT  DEFAULT 0 NOT NULL,
		ACTUAL_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_COST_VARIANCE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BASELINE_DURATION INT  DEFAULT 0 NOT NULL,
		BASELINE_WORK INT  DEFAULT 0 NOT NULL,
		BASELINE_WORK_VARIANCE INT  DEFAULT 0 NOT NULL,
		BASELINE_START_VARIANCE INT  DEFAULT 0 NOT NULL,
		BASELINE_FINISH_VARIANCE INT  DEFAULT 0 NOT NULL,
		BASELINE_COST_VARIANCE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BUDGETED_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		COST_VARIANCE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_DURATION INT  DEFAULT 0 NOT NULL,
		PLANNED_WORK INT  DEFAULT 0 NOT NULL,
		WORK_VARIANCE INT  DEFAULT 0 NOT NULL,
		START_VARIANCE INT  DEFAULT 0 NOT NULL,
		FINISH_VARIANCE INT  DEFAULT 0 NOT NULL,
		DURATION_VARIANCE INT  DEFAULT 0 NOT NULL,
		PERCENT_COMPLETE DECIMAL(5 , 2) DEFAULT 0.00 NOT NULL,
		PERCENT_WORK_COMPLETE DECIMAL(5 , 2) DEFAULT 0.00 NOT NULL,
		BUDGETED_REVENUE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_REVENUE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_REVENUE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		NET_PRESENT_VALUE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		INTERNAL_RATE_OF_RETURN DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL
	) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_ALLOCATION (
		PROJECT_ALLOCATION_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Project Assignment Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		PROFILE_ID INT  DEFAULT -1 NOT NULL,
		PLANNED_START DATETIME ,
		PLANNED_FINISH DATETIME ,
		ACTUAL_START DATETIME ,
		ACTUAL_FINISH DATETIME ,
		PLANNED_WORK INT  DEFAULT 0 NOT NULL,
		ACTUAL_WORK INT  DEFAULT 0 NOT NULL,
		PLANNED_DURATION INT ,
		ACTUAL_DURATION INT ,
		PERCENT_COMPLETE DECIMAL(5 , 2),
		PERCENT_WORK_COMPLETE DECIMAL(5 , 2),
		ALLOTED_WORK INT ,
		UNITS INT ,
		SUNDAY_UNITS INT ,
		MONDAY_UNITS INT ,
		TUESDAY_UNITS INT ,
		WEDNESDAY_UNITS INT ,
		THURSDAY_UNITS INT ,
		FRIDAY_UNITS INT ,
		SATURDAY_UNITS INT ,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

	
CREATE TABLE $(NF_SCHEMA).PROJECT_TYPE (
		PROJECT_TYPE_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Project Type Name Missing' NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		RECORD_TYPE NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (
		PROJECT_WKCFG_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Work Configuartion Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		RECORD_TYPE NVARCHAR(255),
		PROJECT_TYPE_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_WORKCONFIG_HIERARCHY (
		PARENT_WKCFG_ID INT  NOT NULL,
		CHILD_WKCFG_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_CLASSIFICATION (
		PROJECT_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Project Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_CATEGORY (
		PROJECT_CATEGORY_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Project Category Name Missing' NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		CATEGORY_TYPE NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).PHASE (
		PHASE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Project Phase Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		STATUS NVARCHAR(255),
		START_DATE DATETIME,
		END_DATE DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_ROLE (
		PROJECT_ROLE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Project Role Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_ROLE_MEMBER_LOOKUP (
		PROJECT_ROLE_ID INT  NOT NULL,
		RESOURCE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEAM (
		TEAM_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Team Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEAM_ROLE (
		TEAM_ROLE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Team Role Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		TEAM_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TASK_DETAIL (
		TASK_ID INT  DEFAULT -1 NOT NULL,
		PLANNED_START DATETIME ,
		PLANNED_FINISH DATETIME ,
		BASELINE_START DATETIME ,
		BASELINE_FINISH DATETIME ,
		ACTUAL_START DATETIME ,
		ACTUAL_FINISH DATETIME ,
		PLANNED_WORK INT  DEFAULT 0 NOT NULL,
		BASELINE_WORK INT ,
		REGULAR_WORK INT ,
		ACTUAL_WORK INT  DEFAULT 0 NOT NULL,
		REMAINING_WORK INT ,
		PLANNED_DURATION INT ,
		BASELINE_DURATION INT ,
		ACTUAL_DURATION INT ,
		REMAINING_DURATION INT ,
		START_VARIANCE INT ,
		FINISH_VARIANCE INT ,
		DURATION_VARIANCE INT ,
		PLANNED_OVT_WORK INT ,
		ACTUAL_OVT_WORK INT ,
		REMAINING_OVT_WORK INT ,
		PLANNED_COST DECIMAL(18 , 2),
		BASELINE_COST DECIMAL(18 , 2),
		ACTUAL_COST DECIMAL(18 , 2),
		REMAINING_COST DECIMAL(18 , 2),
		PLANNED_OVT_COST DECIMAL(18 , 2),
		ACTUAL_OVT_COST DECIMAL(18 , 2),
		REMAINING_OVT_COST DECIMAL(18 , 2),
		DEADLINE DATETIME ,
		EARLY_START DATETIME ,
		LATE_FINISH DATETIME ,
		EARLY_FINISH DATETIME ,
		LATE_START DATETIME ,
		CONSTRAINT_TYPE INT ,
		CONSTRAINT_DATE DATETIME ,
		PERCENT_COMPLETE DECIMAL(5 , 2),
		PERCENT_WORK_COMPLETE DECIMAL(5 , 2),
		ACWP DOUBLE PRECISION,
		BCWP DOUBLE PRECISION,
		BCWS DOUBLE PRECISION,
		EAC DOUBLE PRECISION,
		VAC DOUBLE PRECISION,
		WBS_CODE NVARCHAR(255),
		ACTUAL_FINISH_VARIANCE INT ,
		BASELINE_FINISH_VARIANCE INT ,
		ACTUAL_WORK_VARIANCE INT ,
		BASELINE_WORK_VARIANCE INT ,
		ACTUAL_START_VARIANCE INT ,
		BASELINE_START_VARIANCE INT ,
		WORK_VARIANCE INT 
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TASK_REQUIREMENT_LOOKUP (
		TASK_ID INT  NOT NULL,
		REQUIREMENT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CONFIGURATION (
		CONFIGURATION_ID INT  NOT NULL,
		CONFIGURATION_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Configuration Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT-1 NOT NULL,
		LAST_UPDATED DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE (
		CONFIGURATION_ATTRIBUTE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Configuration_Attribute Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE_LOOKUP (
		CONFIGURATION_ATTRIBUTE_ID INT  NOT NULL,
		CONFIGURATION_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITE_ITERATION_LOOKUP (
		TESTSUITE_ID INT  NOT NULL,
		ITERATION_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTPLAN (
		TESTPLAN_ID INT  NOT NULL,
		TESTPLAN_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'TestPlan Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		ASSETREGISTRY_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		LAST_UPDATED DATETIME,
		TESTPLAN_STATE NVARCHAR(255),
		CREATION_DATE DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTPLAN_ITERATION_LOOKUP (
		TESTPLAN_ID INT  NOT NULL,
		ITERATION_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTTYPE (
		TESTTYPE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'TestType Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTCASE (
		TESTCASE_ID INT  NOT NULL,
		TESTCASE_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'TestCase Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		TESTCASE_STATE NVARCHAR(255),
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		TESTPLAN_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT-1 NOT NULL,
		IS_BLOCKING INT  DEFAULT 0 NOT NULL,
		REGRESSION_TEST NVARCHAR(255),
		WEIGHT INT  DEFAULT 0,
		LAST_UPDATED DATETIME,
		TESTCASE_FOLDER NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTCASE_TESTSCRIPT_LOOKUP (
		TESTCASE_ID INT  NOT NULL,
		TESTSCRIPT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTCASE_ITERATION_LOOKUP (
		TESTCASE_ID INT  NOT NULL,
		ITERATION_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_TESTCASE_LOOKUP (
		REQUIREMENT_ID INT  NOT NULL,
		TESTCASE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_TESTPLAN_LOOKUP (
		REQUIREMENT_ID INT  NOT NULL,
		TESTPLAN_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_TESTSUITE_LOOKUP (
		REQUIREMENT_ID INT  NOT NULL,
		TESTSUITE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_REQUIREMENT_LOOKUP (
		REQUIREMENT_ID INT  NOT NULL,
		CREQUIREMENT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_HIERARCHY (
		PRED_REQUIREMENT_ID INT  NOT NULL,
		SUCC_REQUIREMENT_ID INT  NOT NULL,
		LINK_TYPE NVARCHAR(255),
		LINK_TYPE_ID INT  DEFAULT -1 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_LINK (
		PRED_REQUEST_ID INT  NOT NULL,
		SUCC_REQUEST_ID INT  NOT NULL,
		LINK_TYPE NVARCHAR(255)
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECUTION_WORKITEM (
		EXECWORKITEM_ID INT  NOT NULL,
		EXECWORKIT_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Execution Work Item Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		CONFIGURATION_ID INT  DEFAULT -1 NOT NULL,
		EXECUTION_WORKITEM_STATE NVARCHAR(255),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		TESTCASE_ID INT  DEFAULT -1 NOT NULL,
		TESTTYPE_ID INT  DEFAULT -1 NOT NULL,
		TESTPLAN_ID INT  DEFAULT -1 NOT NULL,
		TESTSCRIPT_ID INT  DEFAULT -1 NOT NULL,
		CURRENT_RESULT_ID INT  DEFAULT -1 NOT NULL,
		FREQUENCY NVARCHAR(255),
		REGRESSION NVARCHAR(255),
		WEIGHT INT  DEFAULT 0,
		TAGS NVARCHAR(255),
		LAST_UPDATED DATETIME,
		PRIORITY NVARCHAR(255),
		CREATION_DATE DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECWORKITEM_ITERATION_LOOKUP (
		EXECWORKITEM_ID INT  NOT NULL,
		ITERATION_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_EXECWRKITEM_LOOKUP (
		REQUIREMENT_ID INT  NOT NULL,
		EXECWORKITEM_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECWORKITEM_TESTSUITE_LOOKUP (
		EXECWORKITEM_ID INT  NOT NULL,
		TESTSUITE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST (
		REQUEST_ID INT  NOT NULL,
		REQUEST_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Request Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		BUILD_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_CATEGORY_ID INT  DEFAULT -1 NOT NULL,
		PHASE_ID INT  DEFAULT -1 NOT NULL,
		REQUEST_SEVERITY_ID INT  DEFAULT -1 NOT NULL,
		REQUEST_STATE_ID INT  DEFAULT -1 NOT NULL,
		REQUEST_PRIORITY_ID INT  DEFAULT -1 NOT NULL,
		PLATFORM NVARCHAR(255),
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		RELEASE_ID INT  DEFAULT -1 NOT NULL,
		FIXEDINRELEASE_ID INT  DEFAULT -1 NOT NULL,
		SLOC_CHANGE INT  DEFAULT 0,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		REQUEST_CATEGORY_ID INT  DEFAULT -1 NOT NULL,
		TEAM_ID INT  DEFAULT -1 NOT NULL,
		RESOLVER_ID INT  DEFAULT -1 NOT NULL,
		IS_BLOCKING INT  DEFAULT 0 NOT NULL,
		REQUEST_SOURCE NVARCHAR(255),
		CREATION_DATE DATETIME,
		CLOSED_DATE DATETIME,
		SUBMIT_DATE DATETIME,
		RESOLVED_DATE DATETIME,
		ASSIGNED_DATE DATETIME,
		DUPLICATE_DATE DATETIME,
		ACTIVATE_DATE DATETIME,
		REQUEST_STATUS_ID INT  DEFAULT -1 NOT NULL,
		CUSTOMER_PRIORITY NVARCHAR(255),
		REQUEST_RESOLUTION_ID INT  DEFAULT -1 NOT NULL,
		REQUEST_TYPE_ID INT  DEFAULT -1 NOT NULL,
		PLANNED_WORK INT ,
		ACTUAL_WORK INT ,
		COMMENT_COUNT INT ,                             
		SUBSCRIBER_COUNT INT ,
		STORY_POINTS INT ,                          
		TAGS NVARCHAR (255),
		SUMMARY NVARCHAR (1000),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_CLASSIFICATION (
		REQUEST_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Request Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_STATE (
		REQUEST_STATE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Request State Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_STATUS (
		REQUEST_STATUS_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Request Status Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_PRIORITY (
		REQUEST_PRIORITY_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Request Status Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_SEVERITY (
		REQUEST_SEVERITY_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Request Status Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_RESOLUTION (
		REQUEST_RESOLUTION_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Request Status Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_TYPE (
		REQUEST_TYPE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Request Status Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).REQUIREMENT_CLASSIFICATION (
		REQUIREMENT_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Requirement Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_STATE_HISTORY (
		REQUEST_STATE_HISTORY_ID INT  NOT NULL,
		REQUEST_ID INT  NOT NULL,
		PREV_REQUEST_STATE_ID INT  DEFAULT -1 NOT NULL,
		REQUEST_STATE_ID INT  DEFAULT -1 NOT NULL,
		PREV_REQUEST_STATUS_ID INT  DEFAULT -1 NOT NULL,
		REQUEST_STATUS_ID INT  DEFAULT -1 NOT NULL,
		CHANGE_DATE  DATETIME  DEFAULT GETDATE() NOT NULL,
		DAYS_IN_STATE INT  DEFAULT 0 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_HIERARCHY (
		PARENT_REQUEST_ID INT  NOT NULL,
		CHILD_REQUEST_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).FILE_VERSION (
		FILE_VERSION_ID INT  DEFAULT -1 NOT NULL,
		FILE_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'File Version Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		FILE_ID INT  DEFAULT -1 NOT NULL,
		CREATION_DATE DATETIME NOT NULL,
		NUM_SLOC INT  DEFAULT 0 NOT NULL,
		NUM_SLOC_CHANGED INT  DEFAULT 0 NOT NULL,
		AUTHOR_ID INT  DEFAULT -1 NOT NULL,
		ACTIVITY_ID INT  DEFAULT -1 NOT NULL,
		FILE_STREAM_ID INT  DEFAULT-1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		HASCOMMENT SMALLINT DEFAULT 0 NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).[FILE] (
		FILE_ID INT  NOT NULL,
		FILE_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'File Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		NUM_SLOC INT  DEFAULT 0 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).FILE_BASELINE (
		FILE_BASELINE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'File_Baseline Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).FILE_BASELINE_ACTIVITY_LOOKUP
		(FILE_BASELINE_ID INT  NOT NULL,
		ACTIVITY_ID INT  NOT NULL)
 ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).FILE_STREAM (
		FILE_STREAM_ID INT  NOT NULL,
		FILE_STREAM_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'File_Stream Name Missing' NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CONFIG_EXECUTIONRES_LOOKUP (
		CONFIGURATION_ID INT  NOT NULL,
		EXECUTION_RESULT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITELOG (
		TESTSUITELOG_ID INT  NOT NULL,
		TESTSUITELOG_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Test Suite Log Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		VERDICT NVARCHAR(255),
		TESTSUITE_ID INT  DEFAULT -1 NOT NULL,
		BUILD_ID INT  DEFAULT -1 NOT NULL,
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		TESTPLAN_ID INT  DEFAULT -1 NOT NULL,
		TESTSUITE_EXECRECORD_ID INT  DEFAULT -1 NOT NULL,
		WEIGHT INT ,
		POINTS_PASSED INT ,
		POINTS_FAILED INT ,
		POINTS_BLOCKED INT ,
		POINTS_INCONCLUSIVE INT ,
		POINTS_ATTEMPTED INT ,
		POINTS_PERMFAILED INT ,
		START_DATE DATETIME,
		END_DATE DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITELOG_EXECRESULT_LOOKUP (
		TESTSUITELOG_ID INT  NOT NULL,
		EXECUTION_RESULT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TASK_REQUEST_LOOKUP (
		TASK_ID INT  NOT NULL,
		REQUEST_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_REQUEST_LOOKUP (
		REQUIREMENT_ID INT  NOT NULL,
		REQUEST_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_CUSTOMER_LOOKUP (
		REQUEST_ID INT  NOT NULL,
		CUSTOMER_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_CUSTOMER_LOOKUP (
		REQUIREMENT_ID INT  NOT NULL,
		CUSTOMER_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECRES_REQUEST_LOOKUP (
		REQUEST_ID INT  NOT NULL,
		EXECUTION_RESULT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).RISK (
		RISK_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Risk Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		REQUIREMENT_ID INT  DEFAULT -1 NOT NULL,
		PRIORITY NVARCHAR(255),
		RISK_STATE NVARCHAR(255),
		OCCURED_DATETIME DATETIME,
		IMPACT INT,
		IMPACT_RANK NVARCHAR(255),
		PROBABILITY INT,
		PROBABILITY_RANK NVARCHAR(255),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		RELEASE_ID INT  DEFAULT -1 NOT NULL,
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		TARGET_DATE DATETIME,
		CREATION_DATE DATETIME,
		CLOSE_DATE DATETIME,
		IMPACT_CATEGORY NVARCHAR(255),
		CONSEQUENCE_COST DECIMAL(18,2),
		PROBABILITY_COST DECIMAL(18,2),
		RISK_SCORE DECIMAL(18,2),
		RISK_MANAGEMENT_ACTION NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).RISK_STATE_HISTORY (
		RISK_STATE_HISTORY_ID INT  NOT NULL,
		RISK_ID INT  NOT NULL,
		PREV_RISK_STATE NVARCHAR(255),
		RISK_STATE NVARCHAR(255),
		CHANGE_DATE  DATETIME  DEFAULT GETDATE() NOT NULL,
		DAYS_IN_STATE INT  DEFAULT 0 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).FACTOR (
		FACTOR_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Factor Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		RISK_ID INT  DEFAULT -1 NOT NULL,
		MITIGATION_COST DECIMAL(18 , 2),
		PRIORITY NVARCHAR(255),
		DESCRIPTION	NVARCHAR(255),
		WEIGHT 	INT ,
		PROBABILITY	INT ,
		PROBABILITY_RANK NVARCHAR(255),
		MITIGATION_ACTION NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_BASELINE (
		BASELINE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Project_Baseline Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		FILE_STREAM_ID INT  DEFAULT -1 NOT NULL,
		BASELINE_DATE DATETIME,
		PLANNED_START DATETIME ,
		PLANNED_FINISH DATETIME ,
		PLANNED_WORK INT ,
		BASELINE_WORK_COMPLETED INT ,
		PLANNED_COST DECIMAL(18 , 2),
		BASELINE_COST_COMPLETED DECIMAL(18 , 2),
		PLANNED_DURATION INT,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(80) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJ_BASELINE_BASELINE_LOOKUP (
		BASELINE_ID INT  NOT NULL,
		COMPBASELINE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).COMMENT (
		COMMENT_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		RESPONSE_COMMENT_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		REQUEST_ID INT  DEFAULT -1 NOT NULL,
		TASK_ID INT  DEFAULT -1 NOT NULL,
		ACTIVITY_ID INT  DEFAULT -1 NOT NULL,
		CREATION_DATE DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ACTIVITY_DETAIL (
		ACTIVITY_ID INT  DEFAULT -1 NOT NULL,
		PLANNED_START DATETIME ,
		PLANNED_FINISH DATETIME ,
		BASELINE_START DATETIME ,
		ACTUAL_START DATETIME ,
		BASELINE_FINISH DATETIME ,
		ACTUAL_FINISH DATETIME ,
		START_VARIANCE INT ,
		FINISH_VARIANCE INT ,
		PLANNED_WORK INT ,
		BASELINE_WORK INT ,
		REGULAR_WORK INT ,
		ACTUAL_WORK INT ,
		REMAINING_WORK INT ,
		PLANNED_COST DECIMAL(18 , 2),
		BASELINE_COST DECIMAL(18 , 2),
		ACTUAL_COST DECIMAL(18 , 2),
		REMAINING_COST DECIMAL(18 , 2),
		PLANNED_OVT_WORK DECIMAL(18 , 2),
		ACTUAL_OVT_WORK DECIMAL(18 , 2),
		REMAINING_OVT_WORK DECIMAL(18 , 2),
		ACTUAL_OVT_COST DECIMAL(18 , 2),
		REMAINING_OVT_COST DECIMAL(18 , 2),
		UNITS INT ,
		DELAY INT ,
		ACWP DOUBLE PRECISION,
		BCWP DOUBLE PRECISION,
		BCWS DOUBLE PRECISION,
		EAC DOUBLE PRECISION,
		RESOURCE_TYPE NCHAR(18),
		IS_OVERALLOCATED SMALLINT,
		IS_CONFIRMED SMALLINT,
		PERCENT_COMPLETE DECIMAL(5 , 2),
		PERCENT_WORK_COMPLETE DECIMAL(5 , 2),
		PLANNED_DURATION INT ,
		ACTUAL_DURATION INT 
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECRES_EXECWKITEM_LOOKUP (
		EXECUTION_RESULT_ID INT  NOT NULL,
		EXECWORKITEM_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CONFIG_EXECUTIONWORKITM_LOOKUP (
		CONFIGURATION_ID INT  NOT NULL,
		EXECWORKITEM_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEST_CATEGORY (
		TEST_CATEGORY_ID INT  NOT NULL,
		NAME NVARCHAR (255) DEFAULT 'Test Category Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		TERM NVARCHAR (255),
		VALUE NVARCHAR (255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTPLAN_CATEGORY_LOOKUP (
		TEST_CATEGORY_ID INT  NOT NULL,
		TESTPLAN_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTCASE_CATEGORY_LOOKUP (
		TEST_CATEGORY_ID INT  NOT NULL,
		TESTCASE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITE_TESTCASE_LOOKUP (
		TESTCASE_ID INT  NOT NULL,
		TESTSUITE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITE_TESTSUITELOG_LOOKUP (
		TESTSUITE_ID INT  NOT NULL,
		TESTSUITELOG_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTPLAN_TESTPLAN_HIERARCHY (
		PARENT_TESTPLAN_ID INT  NOT NULL,
		CHILD_TESTPLAN_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTPLAN_TESTCASE_LOOKUP  (
		  TESTPLAN_ID INT  NOT NULL, 
		  TESTCASE_ID INT  NOT NULL)
ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).LAB_RESOURCE (
			LAB_RESOURCE_ID INT  NOT NULL,
			NAME NVARCHAR(255) DEFAULT 'Missing Lab Resource Name' NOT NULL,
			REFERENCE_ID NVARCHAR(50),
			EXTERNAL_ID NVARCHAR(100),
			LAB_RESOURCE_TYPE NVARCHAR(255),
			LAB_RESOURCE_NAME NVARCHAR(255),
			MEMORY INT ,
			IP_ADDRESS NVARCHAR(40),
			PRIMARY_MAC_ADDRESS NCHAR(18),
			ADMINISTRATIVE_STATUS NVARCHAR(255),
			OPERATIONAL_STATUS NVARCHAR(255),
			HOSTNAME NVARCHAR(255),
			FULLY_QUALIFIED_DOMAIN_NAME NVARCHAR(255),
			OS_TYPE NVARCHAR(255),
			OS_LOCALE NVARCHAR(255),
			OS_KERNEL_WIDTH NVARCHAR(255),
			CPU_SPEED INT ,
			CPU_ARCHITECTURE NVARCHAR(255),
			CPU_ARCHITECTURE_WIDTH NVARCHAR(255),
			CPU_MANUFACTURER NVARCHAR(255),
			CPU_TYPE NVARCHAR(255), 
			DISK_SPACE INT ,
			SOFTWARE NVARCHAR(255),
			RESOURCE_GROUP_ID INT  DEFAULT -1 NOT NULL,
			PROJECT_ID INT  DEFAULT -1 NOT NULL,
			URL NVARCHAR(2048),
			EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
			EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
			SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
			REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
			ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).RESOURCE_GROUP (
			RESOURCE_GROUP_ID INT  NOT NULL,
			NAME NVARCHAR(255) DEFAULT 'Missing Resource Group Name' NOT NULL,
			REFERENCE_ID NVARCHAR(50),
			EXTERNAL_ID NVARCHAR(100),
			PROJECT_ID INT  DEFAULT-1 NOT NULL,
			IS_EXPIREABLE NVARCHAR(255),
			START_DATE DATETIME,
			EXPIRATION_DATE DATETIME,
			URL NVARCHAR(2048),
			EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
			EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
			SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
			REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
			ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).RESERVATION (
			RESERVATION_ID INT  NOT NULL,
			NAME NVARCHAR(255) DEFAULT 'Missing Reservation Name' NOT NULL,
			REFERENCE_ID NVARCHAR(50),
			EXTERNAL_ID NVARCHAR(100),
			RESERVED_FOR NVARCHAR(255),
			RESERVED_BY NVARCHAR(255),
			RESERVE_TO DATETIME,
			RESERVE_FROM DATETIME,
			LAB_RESOURCE_ID INT  DEFAULT -1 NOT NULL,
			PROJECT_ID INT  DEFAULT-1 NOT NULL,
			URL NVARCHAR(2048),
			EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
			EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
			SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
			REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
			ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTCASE_CLASSIFICATION (
		TESTCASE_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Testcase Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTPLAN_CLASSIFICATION (
		TESTPLAN_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Testplan Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITE_CLASSIFICATION (
		TESTSUITE_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Testsuite Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITELOG_CLASSIFICATION (
		TESTSUITELOG_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Testsuitelog Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECRESULT_CLASSIFICATION (
		EXECRES_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Execution Result Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECWORKITEM_CLASSIFICATION (
		EXECWORKIT_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Execution Work Item Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CONFIGURATION_CLASSIFICATION (
		CONFIGURATION_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Configuration Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ACTIVITY_STATE_HISTORY (
		ACTIVITY_STATE_HISTORY_ID INT  NOT NULL,
		ACTIVITY_ID INT  NOT NULL,
		PREV_ACTIVITY_STATE NVARCHAR(255),
		ACTIVITY_STATE NVARCHAR(255),
		CHANGE_DATE  DATETIME  DEFAULT GETDATE() NOT NULL,
		DAYS_IN_STATE INT  DEFAULT 0 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_CATEGORY (
		REQUEST_CATEGORY_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Request Category Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

	
CREATE TABLE $(NF_SCHEMA).FILE_CLASSIFICATION (
		FILE_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'File Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).FILE_STREAM_CLASSIFICATION (
		FILE_STREAM_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'File Stream Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TASK_STATE_HISTORY (
		TASK_STATE_HISTORY_ID INT  NOT NULL,
		TASK_ID INT  NOT NULL,
		PREV_TASK_STATE NVARCHAR(255),
		TASK_STATE NVARCHAR(255),
		CHANGE_DATE  DATETIME  DEFAULT GETDATE() NOT NULL,
		DAYS_IN_STATE INT  DEFAULT 0 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY	(
		REQCHANGE_HISTORY_ID INT  NOT NULL,
		REQUEST_CLASS_ID INT  DEFAULT -1 NOT NULL,
		REQUEST_ID INT  DEFAULT -1 NOT NULL,                          
		PREV_TEAM_ID INT  DEFAULT -1 NOT NULL,                           
		PREV_REQUEST_CATEGORY_ID INT  DEFAULT -1 NOT NULL,                  
		PREV_ITERATION_ID INT  DEFAULT -1 NOT NULL,                                              
		PREV_OWNER_ID INT  DEFAULT -1 NOT NULL,  
		CHANGE_DATE DATETIME,
		PREV_REQUEST_TYPE_ID INT DEFAULT -1 NOT NULL,                      
		PREV_REQUEST_STATE_ID INT  DEFAULT -1 NOT NULL,    
		PREV_REQUEST_STATUS_ID INT  DEFAULT -1 NOT NULL,                           
		PREV_REQUEST_PRIORITY_ID INT  DEFAULT -1 NOT NULL,                            
		PREV_REQUEST_SEVERITY_ID INT  DEFAULT -1 NOT NULL,                           
		PREV_COMMENT_COUNT INT ,                         
		PREV_SUBSCRIBER_COUNT INT ,                      
		PREV_TAGS NVARCHAR (255),                                 
		PREV_PLANNED_WORK INT ,                      
		PREV_ACTUAL_WORK INT ,                       
		PREV_STORY_POINTS INT , 
		PREV_SUMMARY NVARCHAR (1000),                         
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).TIMESHEET (
		TIMESHEET_ID INT  NOT NULL,
		TIMESHEET_REPORTING_WEEK DATETIME ,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		ACTIVITY_ID INT  DEFAULT -1 NOT NULL,		
		ADDITIONAL_WORK INT ,		
		BILLABLE_HOURS INT ,		
		NON_BILLABLE_HOURS INT ,
		APPROVER_ID INT  DEFAULT -1 NOT NULL,
		TIMESHEET_STATE NVARCHAR(255),
		PERCENT_COMPLETE DECIMAL(18 , 2),
		LAST_APPROVAL_DATE DATETIME ,
		REGULAR_TIME INT ,
		OVERTIME INT ,
		MONDAY_DATE DATETIME ,
		TUESDAY_DATE DATETIME ,
		WEDNESDAY_DATE DATETIME ,
		THURSDAY_DATE DATETIME ,
		FRIDAY_DATE DATETIME ,
		SATURDAY_DATE DATETIME ,
		SUNDAY_DATE DATETIME ,
		MONDAY_REGULAR_TIME INT  DEFAULT 0,
		TUESDAY_REGULAR_TIME INT  DEFAULT 0,
		WEDNESDAY_REGULAR_TIME INT  DEFAULT 0,
		THURSDAY_REGULAR_TIME INT  DEFAULT 0,
		FRIDAY_REGULAR_TIME INT  DEFAULT 0,
		SATURDAY_REGULAR_TIME INT  DEFAULT 0,
		SUNDAY_REGULAR_TIME INT  DEFAULT 0,
		MONDAY_OVT INT  DEFAULT 0,
		TUESDAY_OVT INT  DEFAULT 0,
		WEDNESDAY_OVT INT  DEFAULT 0,
		THURSDAY_OVT INT  DEFAULT 0,
		FRIDAY_OVT INT  DEFAULT 0,
		SATURDAY_OVT INT  DEFAULT 0,
		SUNDAY_OVT INT  DEFAULT 0,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).PROFILE (
		PROFILE_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Profile Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		RATE DECIMAL(18 , 2),
		CREATION_DATE DATETIME ,
		EXPERIENCE_IN_MONTHS INT ,
		CITY_ID INT  DEFAULT -1 NOT NULL,
		ORGANIZATION_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL		
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).PROFILE_SKILL_LOOKUP (
		PROFILE_ID INT  NOT NULL,
		SKILL_ID INT  NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).PROFILE_COMPETENCY_LOOKUP (
		PROFILE_ID INT  NOT NULL,
		COMPETENCY_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CHARGECODE(
		CHARGECODE_ID INT NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Charge Code Name Missing' NOT NULL,
		PARENT_CHARGECODE_ID INT DEFAULT -1 NOT NULL,
		CHARGECODE_STATE NVARCHAR(255),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TIMECODE(
		TIMECODE_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Charge Code Name Missing' NOT NULL,
		PARENT_TIMECODE_ID INT DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).TIMESHEET_TIMECODE_LOOKUP (
		TIMESHEET_ID INT  NOT NULL,
		TIMECODE_ID INT  NOT NULL
) ON VNF_32K 
GO

---RTC
CREATE TABLE $(NF_SCHEMA).BUILD_COMPILATION_RESULT	( 
		BUILD_COMPRES_ID INT  NOT NULL,                       
		BUILD_ID INT  DEFAULT -1 NOT NULL,               
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,          
		COMPILE_ERROR_COUNT INT ,   
		COMPILE_WARNING_COUNT INT ,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

	                        
CREATE TABLE $(NF_SCHEMA).BUILD_UNIT_RESULT	( 
        BUILD_UNITRES_ID INT  NOT NULL,	      
		BUILD_ID INT  DEFAULT -1 NOT NULL,              
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,           
		UNIT_TEST_COUNT INT ,        
		UNIT_FAILURE_COUNT INT ,    
		UNIT_ERROR_COUNT INT ,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).BUILD_UNIT_EVENT	(                    
		BUILD_UNIT_EVENT_ID INT  NOT NULL,	      
		BUILD_ID INT  DEFAULT -1 NOT NULL,                 
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,                           
		UNIT_EVENT NVARCHAR(255),           
		UNIT_TEST NVARCHAR(255),   
		URL NVARCHAR(2048),          
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

   
CREATE TABLE $(NF_SCHEMA).UNIT_TEST_RESULT (	
		UNIT_TEST_RESULT_ID INT  NOT NULL,              
		PROJECT_ID INT  DEFAULT -1 NOT NULL,               
		TEAM_ID INT  DEFAULT -1 NOT NULL,                 
		BUILD_TYPE NVARCHAR(255),         
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,            
		UNIT_EVENT NVARCHAR(255),        
		UNIT_TEST NVARCHAR(255),           
		UNIT_COUNT INT , 
		URL NVARCHAR(2048),           
		LAST_RUN_DATE DATETIME,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).JOB (
		JOB_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Job Name Missing' NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT-1 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO




CREATE TABLE $(NF_SCHEMA).JOB_RESULT(
		JOB_RESULT_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Job Result Name Missing' NOT NULL,
		STATE NVARCHAR(255),
		VERDICT NVARCHAR(255), 
		START_TIME DATETIME,
		END_TIME DATETIME,
		DURATION INT ,
		LAB_RESOURCE_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		JOB_ID INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSCRIPT(
		TESTSCRIPT_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Test Script Name Missing' NOT NULL,
		LAST_UPDATED DATETIME,
		TESTSCRIPT_STATE NVARCHAR(255),
		TYPE NVARCHAR(255),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PORTFOLIO(
		PORTFOLIO_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Portfolio Name Missing' NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PORTFOLIO_PROG_PROJ_LOOKUP(
		PORTFOLIO_ID INT  NOT NULL,
		PROGRAM_ID INT  NOT NULL,
		PROJECT_ID INT  NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).REQUEST_TESTCASE_LOOKUP (
		REQUEST_ID INT  NOT NULL,
		TESTCASE_ID INT  NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).PROJECT_RESOURCE_LOOKUP (
		PROJECT_ID INT NOT NULL,
		RESOURCE_ID INT NOT NULL
)ON VNF_32K
GO


CREATE TABLE $(NF_SCHEMA).RISK_REQUEST_LOOKUP (
		RISK_ID INT  NOT NULL,
		REQUEST_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITE_CATEGORY_LOOKUP (
		TESTSUITE_ID INT  NOT NULL,
		TEST_CATEGORY_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITE_TESTPLAN_LOOKUP (
		TESTSUITE_ID INT  NOT NULL,
		TESTPLAN_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD (
		TESTSUITE_EXECRECORD_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Test Suite Execution Record Name Missing' NOT NULL,
		PROJECT_ID INT  DEFAULT -1  NOT NULL,
		CREATOR_ID INT  DEFAULT -1  NOT NULL,
		OWNER_ID INT  DEFAULT -1  NOT NULL,
		TESTSUITE_ID INT  DEFAULT -1  NOT NULL,
		TESTPLAN_ID INT  DEFAULT -1  NOT NULL,
		ITERATION_ID INT  DEFAULT -1  NOT NULL,
		CONFIGURATION_ID INT  DEFAULT -1  NOT NULL,
		CURRENT_SUITELOG_ID INT  DEFAULT -1  NOT NULL,
		WEIGHT INT ,
		CREATION_DATE DATETIME,
		LAST_UPDATED DATETIME,
		ISSEQUENTIAL INT ,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECWORKITEM_REQUEST_LOOKUP (
		EXECWORKITEM_ID INT  NOT NULL,
		REQUEST_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECUTION_STEP_RESULT (
		EXECUTION_STEP_RESULT_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Test Suite Execution Step Name Missing' NOT NULL,
		EXECUTION_RESULT_ID INT  DEFAULT -1 NOT NULL,
		STEP_TYPE NVARCHAR(255),
		DESCRIPTION NVARCHAR(255),
		EXPECTED_RESULT NVARCHAR(255),
		ACTUAL_RESULT NVARCHAR(255),
		RESULT NVARCHAR(255),
		START_TIME DATETIME,
		END_TIME DATETIME,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO



CREATE TABLE $(NF_SCHEMA).EXECSTEPRES_REQUEST_LOOKUP (
		EXECUTION_STEP_RESULT_ID INT  NOT NULL,
		REQUEST_ID INT  NOT NULL
) ON VNF_32K 
GO



CREATE TABLE $(NF_SCHEMA).TESTSUITE_ELEMENT (
		TESTSUITE_ELEMENT_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Test Suite Element Name Missing' NOT NULL,
		TESTSUITE_ID INT  DEFAULT -1 NOT NULL,
		TESTCASE_ID INT  DEFAULT -1 NOT NULL,
		CONFIGURATION_ID INT  DEFAULT -1 NOT NULL,
		TESTSCRIPT_ID INT  DEFAULT -1 NOT NULL,
		ELEMENT_INDEX INT,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).REQUIREMENT_LINK_TYPE (
		LINK_TYPE_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Link Type Name Missing' NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		PRED_REQUIREMENT_LINK_LABEL NVARCHAR(255),
		SUCC_REQUIREMENT_LINK_LABEL NVARCHAR(255),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).REQUEST_RELATIONAL_LINK	( 
		REQUEST_RELATION_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Relation Link Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		REQUEST1_ID INT  NOT NULL,
		REQUEST2_ID INT  NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).M_PROJECT (
		MAP_KEY1 INT ,
		MAP_KEY2 NVARCHAR(255),
		TARGET_PROJECT_ID INT  NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).M_PRODUCT (
		MAP_KEY1 INT ,
		MAP_KEY2 NVARCHAR(255),
		TARGET_PRODUCT_ID INT  NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).M_COMPONENT (
		MAP_KEY1 INT ,
		MAP_KEY2 NVARCHAR(255),
		TARGET_COMPONENT_ID INT  NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).M_ITERATION (
		MAP_KEY1 INT ,
		MAP_KEY2 NVARCHAR(255),
		TARGET_ITERATION_ID INT  NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).M_RELEASE (
		MAP_KEY1 INT ,
		MAP_KEY2 NVARCHAR(255),
		TARGET_RELEASE_ID INT  NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).M_RESOURCE (
		MAP_KEY1 INT ,
		MAP_KEY2 NVARCHAR(255),
		TARGET_RESOURCE_ID INT  NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


----


CREATE TABLE $(NF_SCHEMA).TEMP_ITERATION  (
		  NAME NVARCHAR(256) , 
		  SOURCE_ID NVARCHAR(36) )   
 ON VNF_32K 
GO

 

CREATE TABLE $(NF_SCHEMA).TEMP_BUILD  (
		  NAME NVARCHAR(256) , 
		  SOURCE_ID NVARCHAR(36) )   
 ON VNF_32K 
GO

 

CREATE TABLE $(NF_SCHEMA).TEMP_RELEASE  (
		  NAME NVARCHAR(256) , 
		  SOURCE_ID NVARCHAR(36) )   
 ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_PROJECT
(		PROJECTUNIQUEID NVARCHAR(256),
		PROJECTNAME NVARCHAR(256),
		PROJECTDATECREATED DATETIME,
		PROJECTHREF NVARCHAR(2048),
		COMPONENTUNIQUEID NVARCHAR(256),
		STREAMUNIQUEID NVARCHAR(256),
		STREAMNAME NVARCHAR(256),
		STREAMHREF NVARCHAR(2048),
		ACTIVITYUNIQUEID NVARCHAR(256),
		ACTIVITYNAME NVARCHAR(256),
		ACTIVITYOWNER NVARCHAR(256),
		ACTIVITYSTATE NVARCHAR(256),
		ACTIVITYDATECREATED DATETIME,
		ACTIVITYHREF NVARCHAR(2048),
		VERSIONUNIQUEID NVARCHAR(256),
		DATASOURCE_ID NVARCHAR(36)
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_REQUEST_HISTORY
	(
	HISTORY_DBID INT ,
	HISTORY_UUID_DBID NVARCHAR(256),
	HISTORY_ACTION_TIMESTAMP DATETIME,
	DATASOURCE_ID NVARCHAR(36),
	HISTORY_OLD_STATE NVARCHAR(256),
	HISTORY_NEW_STATE NVARCHAR(256),
	DBID INT ,
	DBID_UUID NVARCHAR(256),
	ENTITYDEF_ID INT
	) ON VNF_32K 
GO

	
CREATE TABLE $(NF_SCHEMA).TEMP_TEST_CATEGORY
	(
	CATEGORY_VALUE NVARCHAR(255),
	CATEGORY_TERM NVARCHAR(255),
	DATASOURCE_ID NVARCHAR(36)
	) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_ACTIVITY_HISTORY
	(
	HISTORY_DBID INT ,
	HISTORY_ACTION_TIMESTAMP DATETIME,
	DATASOURCE_ID NVARCHAR(36),
	HISTORY_OLD_STATE NVARCHAR(256),
	HISTORY_NEW_STATE NVARCHAR(256),
	DBID INT 
	) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_TASK_HISTORY
	(
	HISTORY_DBID INT ,
	HISTORY_ACTION_TIMESTAMP DATETIME,
	DATASOURCE_ID NVARCHAR(36),
	HISTORY_OLD_STATE NVARCHAR(256),
	HISTORY_NEW_STATE NVARCHAR(256),
	DBID INT 
	) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_FILEVERSION 
(		CREATEDBY NVARCHAR(256),
		DATECREATED DATETIME,
		VERSIONNUMBER NVARCHAR(256),
		LINESOFCODE INT ,
		BRANCH  NVARCHAR(256),
		UNIQUEID  NVARCHAR(256),
		CHANGESFROMPREDECESSOR INT ,
		FILEELEMENTUNIQUEID NVARCHAR(256),
		FILEELEMENTNAME NVARCHAR(256),
		DATASOURCE_ID NVARCHAR(36)
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_COMPONENT
(		COMPONENTNAME NVARCHAR(256),
		COMPONENTUNIQUEID NVARCHAR(256),
		COMPONENTHREF NVARCHAR(2048),
		FILEELEMENTUNIQUEID NVARCHAR(256),
		BASELINENAME NVARCHAR(256),
		BASELINEUNIQUEID NVARCHAR(256),
		BASELINEHREF NVARCHAR(2048),
		BASELINEACTIVITIESUNIQUEID NVARCHAR(256),
		DATASOURCE_ID NVARCHAR(36)
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).TEMP_BASELINE (
		BASELINE_ID NVARCHAR(256),
		NAME NVARCHAR(256),
		BASELINE_DATE DATETIME,
		PARENT_ID NVARCHAR(256),
		PARENT_TITLE NVARCHAR(256),
		PLANNED_SCHEDULE_ID NVARCHAR(256),
		PLANNED_START DATETIME ,
		PLANNED_FINISH DATETIME ,
		PLANNED_WORK INT ,
		PLANNED_COST DECIMAL(18 , 2),
		PLANNED_DURATION INT ,
		URL NVARCHAR(2048),
		BASELINE_TYPE NVARCHAR(255),
		DATASOURCE_ID NVARCHAR(36),
		ACTUAL_START DATETIME,
		ACTUAL_FINISH DATETIME,
		ACTUAL_WORK INT
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_CALENDAR  (
		  IDREF NCHAR(40) NOT NULL , 
		  ADOPTED_CALENDAR NCHAR(40) , 
		  USER_IDREF NCHAR(40) , 
		  SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		  HOURSPERDAY DECIMAL(5,2) 
)   ON VNF_32K  
GO
CREATE TABLE $(NF_SCHEMA).TEMP_PROJECT_CALENDAR (
		  PROJECT_IDREF NCHAR(40) NOT NULL , 
		  CALENDAR_IDREF NCHAR(40) NOT NULL 
) ON VNF_32K  
GO



CREATE TABLE $(NF_SCHEMA).TEMP_RESOURCE_CALENDAR (
		  RESOURCE_ID INT  NOT NULL , 
		 MINUTES_PER_DAY INT  NOT NULL,
		 SUNDAY_WORKTIME INT ,
		 MONDAY_WORKTIME INT ,
		 TUESDAY_WORKTIME INT ,
		 WEDNESDAY_WORKTIME INT ,
		 THURSDAY_WORKTIME INT ,
		 FRIDAY_WORKTIME INT ,
		 SATURDAY_WORKTIME INT 
) ON VNF_32K  
GO


CREATE TABLE $(NF_SCHEMA).TEMP_CAL_EXCEPTION_RANGE  (
	  FROMDATE DATETIME  , 
	  TODATE DATETIME  , 
	  HOURSBLOCKED DECIMAL(5,2) , 
	  EXCEPTIONTYPE NVARCHAR(255) , 
	  DAYOFWEEK NVARCHAR(255) , 
	  DURATION INT  , 
	  EFFORT INT  , 
	  IDREF NCHAR(40) , 
	  CALENDAR_IDREF NCHAR(40) , 
	  DAYOFMONTH INT  , 
	  MONTHOFYEAR INT ,
	  SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
	  REC_DATETIME DATETIME DEFAULT GETDATE() 
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_RESOURCE_CALENDAR_EXCEP(
		RESOURCE_ID INT  NOT NULL,
		EXCEPTION_DATE DATETIME  NOT NULL,
		EXCEPTION_MINUTES INT  NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(80) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_PROJECT_CALENDAR_EXCEP(
		PROJECT_ID INT  NOT NULL,
		EXCEPTION_DATE DATETIME  NOT NULL,
		EXCEPTION_MINUTES INT  NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(80) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_POOL_HIERARCHY  (
		POOL_ID INT  NOT NULL , 
		LEVEL INT  NOT NULL 
) ON VNF_32K  
GO

CREATE TABLE $(NF_SCHEMA).TEMP_REQUIREMENT(
	    CREATED_ON DATETIME,
		CREATED_BY NVARCHAR (255),
		CREATED_BY_URL NVARCHAR (2048),
		REQUIREMENT_NAME NVARCHAR (255),
		IDENTIFIER NVARCHAR (255),
		LAST_MODIFIED_ON DATETIME,
		COMPONENT NVARCHAR (255),
		DIFFICULTY NVARCHAR (255),
		REQUIREMENT_TYPE NVARCHAR (255),
		ACTUAL_ITERATION NVARCHAR (255),
		CUSTOMER_PRIORITY NVARCHAR (255),
		PLANNED_ITERATION NVARCHAR (255),
		PLATFORM NVARCHAR (255),
		PRIORITY NVARCHAR (255),
		PROJECT_ID NVARCHAR (255),
		PROJECT_NAME NVARCHAR (255),
		PROJECT_URL NVARCHAR (2048),
		STABILITY NVARCHAR (255),
		STATE NVARCHAR (255),
		STATUS NVARCHAR (255),
		URL NVARCHAR (2048),
		DATASOURCE_ID NVARCHAR (255),
		CHILD_ID INT,
		PARENT_ID  INT,
		SOURCE_ID NVARCHAR (255),
		TARGET_ID  INT,
		DIFFICULTY2 NVARCHAR (255),
		DIFFICULTY3 NVARCHAR (255),
		PRIORITY2 NVARCHAR (255),
		STABILITY2 NVARCHAR (255),
		STATUS2 NVARCHAR (255),
		PRIORITY3 NVARCHAR (255),
		STABILITY3 NVARCHAR (255),
		STATUS3 NVARCHAR (255),
		REFERENCE_ID	NVARCHAR(50),
		IMPLEMENTED_BY	NVARCHAR(40),
		REQ_ARTIFACT	NVARCHAR(40),
		INCOMING_LINK	NVARCHAR(40),
		OUTGOING_LINK	NVARCHAR(40),
		ORIGIN	NVARCHAR(255),
		ORIGIN_TYPE  NVARCHAR(255),
		IMPACT	NVARCHAR(255),
		TARGET	NVARCHAR(255)
)ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).TEMP_RESOURCE  (
	ID INT , 
	STATE NVARCHAR(50) , 
	PROJECT NVARCHAR(256) , 
	ROW_ID NVARCHAR(20) , 
	COLUMNID NVARCHAR(20) , 
	VALUE NVARCHAR(20) , 
	DATASOURCE_ID NVARCHAR(40)
)  ON VNF_32K  
GO



CREATE TABLE $(NF_SCHEMA).TEMP_REQUEST (
		REQUEST_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Request Name Missing' NOT NULL,
	REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		BUILD_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_CATEGORY_ID INT  DEFAULT -1 NOT NULL,
		PHASE_ID INT  DEFAULT -1 NOT NULL,
	SEVERITY NVARCHAR(255),
	REQUEST_STATE NVARCHAR(255),
	PRIORITY NVARCHAR(255),
	PLATFORM NVARCHAR(255),
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		RELEASE_ID INT  DEFAULT -1 NOT NULL,
		FIXEDINRELEASE_ID INT  DEFAULT -1 NOT NULL,
		SLOC_CHANGE INT  DEFAULT 0,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		REQUEST_CATEGORY_ID INT  DEFAULT -1 NOT NULL,
		TEAM_ID INT  DEFAULT -1 NOT NULL,
		RESOLVER_ID INT  DEFAULT -1 NOT NULL,
		IS_BLOCKING INT  DEFAULT 0 NOT NULL,
	REQUEST_SOURCE NVARCHAR(255),
	CREATION_DATE DATETIME,
	CLOSED_DATE DATETIME,
	SUBMIT_DATE DATETIME,
	RESOLVED_DATE DATETIME,
	ASSIGNED_DATE DATETIME,
	DUPLICATE_DATE DATETIME,
	ACTIVATE_DATE DATETIME,
	STATUS NVARCHAR(255),
	CUSTOMER_PRIORITY NVARCHAR(255),
	RESOLUTION NVARCHAR(255),
	REQUEST_TYPE NVARCHAR(255),
	PLANNED_WORK INT ,
	ACTUAL_WORK INT ,
	COMMENT_COUNT INT ,                             
	SUBSCRIBER_COUNT INT ,
	STORY_POINTS INT ,                          
	TAGS NVARCHAR (255),
	SUMMARY NVARCHAR (1000),
	URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

	
CREATE TABLE $(NF_SCHEMA).TEMP_TIMESHEET (
	TIMESHEET_DATE	DATETIME,
	ACTUAL_WORK INT ,
	ITEM_ID	NVARCHAR(255),
	TIMECODE NVARCHAR(36),
	DATASOURCE_ID NVARCHAR(36)
) ON VNF_32K 
GO



CREATE TABLE $(NF_SCHEMA).TEMP_TIMESHEET_REQUEST_LOOKUP (
	TIMESHEET_ID	NVARCHAR(36),
	REQUEST_ID	NVARCHAR(36),
	DATASOURCE_ID NVARCHAR(36)
) ON VNF_32K 
GO

	
CREATE TABLE $(NF_SCHEMA).TEMP_TIMEGRID_HEAD (
	COLUMN_ID NVARCHAR(10),
	PROJECT_ID NVARCHAR(40),
	CELL_ID NVARCHAR(40),
	SHEET INT ,
	TIMESCALE NVARCHAR(10),
	DATASOURCE_ID NVARCHAR(36),
	YEAR INT ,
	QUARTER INT ,
  MONTH INT 
) ON VNF_32K 
GO

	
CREATE TABLE $(NF_SCHEMA).TEMP_FP_PROJECT (
		PROJECT_ID NVARCHAR(256),
		TITLE NVARCHAR(256),
		PROJECT_STATE NVARCHAR(256),
		TARGET_START_DATE DATETIME,
		TARGET_END_DATE DATETIME,
		DELIVERY_DATE DATETIME,
		PRIORITY DOUBLE PRECISION,
		URL NVARCHAR(2048),
		MD5_URL NVARCHAR(32),
		CREATOR NVARCHAR(256),
		CREATOR_HREF NVARCHAR(32),
		ACTUAL_START_DATE DATETIME,
		BUDGETED_BENEFIT BIGINT,
		BUDGETED_EXPENDITURE BIGINT,
		PLANNED_BENEFIT BIGINT,
		PLANNED_EXPENDITURE BIGINT,
		ACTUAL_BENEFIT BIGINT,
		ACTUAL_EXPENDITURE BIGINT,
		ACTUAL_END_DATE DATETIME,
		PLANNED_START_DATE DATETIME,
		PLANNED_END_DATE DATETIME,
		NPV BIGINT,
		IRR DOUBLE PRECISION,
		FEASIBILITY BIGINT,
		TYPE NVARCHAR(256),
		ACTUALMANHOURS DOUBLE PRECISION,
		PLANNEDMANHOURS DOUBLE PRECISION,
		AH_COLUMN NVARCHAR(256),
		A_TIMESCALE NVARCHAR(256),
		A_SHEET BIGINT,
		AE_ROW BIGINT,
		AH_CELL NVARCHAR(256),
		AE_COLUMN NVARCHAR(256),
		AE_CELL NVARCHAR(256),
		AB_COLUMN NVARCHAR(256),
		AB_ROW BIGINT,
		AB_CELL NVARCHAR(256),
		BH_COLUMN NVARCHAR(256),
		BH_CELL NVARCHAR(256),
		B_SHEET BIGINT,
		B_TIMESCALE NVARCHAR(256),
		BE_ROW BIGINT,
		BE_COLUMN NVARCHAR(256),
		BE_CELL NVARCHAR(256),
		BB_COLUMN NVARCHAR(256),
		BB_CELL NVARCHAR(256),
		BB_ROW BIGINT,
		PH_COLUMN NVARCHAR(256),
		PH_CELL NVARCHAR(256),
		P_SHEET BIGINT,
		P_TIMESCALE NVARCHAR(256),
		PE_ROW BIGINT,
		PE_CELL NVARCHAR(256),
		PE_COLUMN NVARCHAR(256),
		PB_COLUMN NVARCHAR(256),
		PB_CELL NVARCHAR(256),
		PB_ROW BIGINT,
		DATASOURCE_ID NVARCHAR(256)
) ON VNF_32K 
GO

CREATE TABLE $(NF_SCHEMA).TEMP_REVISION_HISTORY (
	VERSION_ID NCHAR(40) NOT NULL,
	REQ_UNIQUEID NCHAR(40) NOT NULL,
	REVISION_NUMBER NVARCHAR(50) DEFAULT '0' NOT NULL,
	USER_ID NCHAR(40) DEFAULT '-1' NOT NULL,
	CHANGE_DATE DATETIME  DEFAULT GETDATE() NOT NULL,
	SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL
) ON VNF_32K 
GO

-- INDEXES

CREATE INDEX ACTI_IDX3 ON $(NF_SCHEMA).ACTIVITY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX ASETR_IDX3 ON $(NF_SCHEMA).ASSETREGISTRY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX BUILD_IDX3 ON $(NF_SCHEMA).BUILD (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX COMMENT_IDX3 ON $(NF_SCHEMA).COMMENT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX COMPONENT_IDX3 ON $(NF_SCHEMA).COMPONENT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX COMPTEAM_IDX3 ON $(NF_SCHEMA).TEAM (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX CONFIG_IDX3 ON $(NF_SCHEMA).CONFIGURATION (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX CONFIGATT_IDX3 ON $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX EXECWKI_TSTC_IDX3 ON $(NF_SCHEMA).EXECUTION_WORKITEM (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX CURRENCY_IDX3 ON $(NF_SCHEMA).CURRENCY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX CUSTOMER_IDX3 ON $(NF_SCHEMA).CUSTOMER (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX FACTOR_IDX3 ON $(NF_SCHEMA).FACTOR (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX FILE_IDX3 ON $(NF_SCHEMA).[FILE] (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX FILESTR_IDX3 ON $(NF_SCHEMA).FILE_STREAM (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX FILEVER_IDX3 ON $(NF_SCHEMA).FILE_VERSION (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX ITERATION_IDX3 ON $(NF_SCHEMA).ITERATION (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX POOL_IDX3 ON $(NF_SCHEMA).POOL (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PRODUCT_IDX3 ON $(NF_SCHEMA).PRODUCT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PROJECT_IDX3 ON $(NF_SCHEMA).PROJECT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PROJBASE_IDX3 ON $(NF_SCHEMA).PROJECT_BASELINE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PROJCAT_IDX3 ON $(NF_SCHEMA).PROJECT_CATEGORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PHASE_IDX3 ON $(NF_SCHEMA).PHASE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PROJROLE_IDX3 ON $(NF_SCHEMA).PROJECT_ROLE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PROJTYPE_IDX3 ON $(NF_SCHEMA).PROJECT_TYPE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PROJWRKCFG_IDX3 ON $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX RELEASE_IDX3 ON $(NF_SCHEMA).RELEASE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX3 ON $(NF_SCHEMA).REQUEST (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX REQSTH_IDX3 ON $(NF_SCHEMA).REQUEST_STATE_HISTORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX REQUI_IDX3 ON $(NF_SCHEMA).REQUIREMENT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX RESOURCE_IDX3 ON $(NF_SCHEMA).RESOURCE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX RISK_IDX3 ON $(NF_SCHEMA).RISK (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX RISKSTH_IDX3 ON $(NF_SCHEMA).RISK_STATE_HISTORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TESTSUITELOG_IDX3 ON $(NF_SCHEMA).TESTSUITELOG (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TASK_IDX3 ON $(NF_SCHEMA).TASK (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TASKCAT_IDX3 ON $(NF_SCHEMA).TASK_CATEGORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TESTCASE_IDX3 ON $(NF_SCHEMA).TESTCASE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX EXECRES_IDX3 ON $(NF_SCHEMA).EXECUTION_RESULT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TESTPLAN_IDX3 ON $(NF_SCHEMA).TESTPLAN (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TESTSUITE_IDX3 ON $(NF_SCHEMA).TESTSUITE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TESTTYPE_IDX3 ON $(NF_SCHEMA).TESTTYPE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX LABRES_IDX3 ON $(NF_SCHEMA).LAB_RESOURCE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX RESGRP_IDX3 ON $(NF_SCHEMA).RESOURCE_GROUP (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX RESERV_IDX3 ON $(NF_SCHEMA).RESERVATION (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX ACTSTH_IDX3 ON $(NF_SCHEMA).ACTIVITY_STATE_HISTORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TSKSTH_IDX3 ON $(NF_SCHEMA).TASK_STATE_HISTORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX JOB_IDX3 ON $(NF_SCHEMA).JOB (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX JOBRES_IDX3 ON $(NF_SCHEMA).JOB_RESULT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TESTSCRIPT_IDX3 ON $(NF_SCHEMA).TESTSCRIPT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TSTSELE_IDX3 ON $(NF_SCHEMA).TESTSUITE_ELEMENT (EXTERNAL_KEY2)  ON VNF_IDX  
GO
CREATE INDEX REQLINKTP_IDX3 ON $(NF_SCHEMA).REQUIREMENT_LINK_TYPE (EXTERNAL_KEY2)  ON VNF_IDX	
GO
CREATE INDEX REQRELT_IDX3 ON $(NF_SCHEMA).REQUEST_RELATIONAL_LINK (EXTERNAL_KEY2)  ON VNF_IDX
GO

 
CREATE INDEX ACTI_IDX4 ON $(NF_SCHEMA).ACTIVITY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ASETR_IDX4 ON $(NF_SCHEMA).ASSETREGISTRY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX BUILD_IDX4 ON $(NF_SCHEMA).BUILD (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX COMMENT_IDX4 ON $(NF_SCHEMA).COMMENT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX COMPONENT_IDX4 ON $(NF_SCHEMA).COMPONENT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX COMPTEAM_IDX4 ON $(NF_SCHEMA).TEAM (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CONFIG_IDX4 ON $(NF_SCHEMA).CONFIGURATION (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CONFIGATT_IDX4 ON $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX EXECWKI_TSTC_IDX4 ON $(NF_SCHEMA).EXECUTION_WORKITEM (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CURRENCY_IDX4 ON $(NF_SCHEMA).CURRENCY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CUSTOMER_IDX4 ON $(NF_SCHEMA).CUSTOMER (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FACTOR_IDX4 ON $(NF_SCHEMA).FACTOR (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FILE_IDX4 ON $(NF_SCHEMA).[FILE] (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FILESTR_IDX4 ON $(NF_SCHEMA).FILE_STREAM (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FILEVER_IDX4 ON $(NF_SCHEMA).FILE_VERSION (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ITERATION_IDX4 ON $(NF_SCHEMA).ITERATION (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX POOL_IDX4 ON $(NF_SCHEMA).POOL (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PRODUCT_IDX4 ON $(NF_SCHEMA).PRODUCT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJECT_IDX4 ON $(NF_SCHEMA).PROJECT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJBASE_IDX4 ON $(NF_SCHEMA).PROJECT_BASELINE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJCAT_IDX4 ON $(NF_SCHEMA).PROJECT_CATEGORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PHASE_IDX4 ON $(NF_SCHEMA).PHASE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJROLE_IDX4 ON $(NF_SCHEMA).PROJECT_ROLE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJTYPE_IDX4 ON $(NF_SCHEMA).PROJECT_TYPE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJWRKCFG_IDX4 ON $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RELEASE_IDX4 ON $(NF_SCHEMA).RELEASE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX4 ON $(NF_SCHEMA).REQUEST (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQSTH_IDX4 ON $(NF_SCHEMA).REQUEST_STATE_HISTORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQUI_IDX4 ON $(NF_SCHEMA).REQUIREMENT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RESOURCE_IDX4 ON $(NF_SCHEMA).RESOURCE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RISK_IDX4 ON $(NF_SCHEMA).RISK (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RISKSTH_IDX4 ON $(NF_SCHEMA).RISK_STATE_HISTORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTSUITELOG_IDX4 ON $(NF_SCHEMA).TESTSUITELOG (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TASK_IDX4 ON $(NF_SCHEMA).TASK (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TASKCAT_IDX4 ON $(NF_SCHEMA).TASK_CATEGORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTCASE_IDX4 ON $(NF_SCHEMA).TESTCASE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX EXECRES_IDX4 ON $(NF_SCHEMA).EXECUTION_RESULT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTPLAN_IDX4 ON $(NF_SCHEMA).TESTPLAN (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTSUITE_IDX4 ON $(NF_SCHEMA).TESTSUITE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTTYPE_IDX4 ON $(NF_SCHEMA).TESTTYPE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX LABRES_IDX4 ON $(NF_SCHEMA).LAB_RESOURCE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RESGRP_IDX4 ON $(NF_SCHEMA).RESOURCE_GROUP (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RESERV_IDX4 ON $(NF_SCHEMA).RESERVATION (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ACTSTH_IDX4 ON $(NF_SCHEMA).ACTIVITY_STATE_HISTORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TSKSTH_IDX4 ON $(NF_SCHEMA).TASK_STATE_HISTORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX JOB_IDX4 ON $(NF_SCHEMA).JOB (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX JOBRES_IDX4 ON $(NF_SCHEMA).JOB_RESULT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTSCRIPT_IDX4 ON $(NF_SCHEMA).TESTSCRIPT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TSTSELE_IDX4 ON $(NF_SCHEMA).TESTSUITE_ELEMENT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX  
GO
CREATE INDEX REQLINKTP_IDX4 ON $(NF_SCHEMA).REQUIREMENT_LINK_TYPE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX	
GO
CREATE INDEX REQRELT_IDX4 ON $(NF_SCHEMA).REQUEST_RELATIONAL_LINK (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO


CREATE INDEX ACTI_IDX5 ON $(NF_SCHEMA).ACTIVITY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ASETR_IDX5 ON $(NF_SCHEMA).ASSETREGISTRY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX BUILD_IDX5 ON $(NF_SCHEMA).BUILD (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX COMMENT_IDX5 ON $(NF_SCHEMA).COMMENT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX COMPONENT_IDX5 ON $(NF_SCHEMA).COMPONENT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX COMPTEAM_IDX5 ON $(NF_SCHEMA).TEAM (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CONFIG_IDX5 ON $(NF_SCHEMA).CONFIGURATION (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CONFIGATT_IDX5 ON $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX EXECWKI_TSTC_IDX5 ON $(NF_SCHEMA).EXECUTION_WORKITEM (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CURRENCY_IDX5 ON $(NF_SCHEMA).CURRENCY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CUSTOMER_IDX5 ON $(NF_SCHEMA).CUSTOMER (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FACTOR_IDX5 ON $(NF_SCHEMA).FACTOR (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FILE_IDX5 ON $(NF_SCHEMA).[FILE] (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FILESTR_IDX5 ON $(NF_SCHEMA).FILE_STREAM (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FILEVER_IDX5 ON $(NF_SCHEMA).FILE_VERSION (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ITERATION_IDX5 ON $(NF_SCHEMA).ITERATION (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX POOL_IDX5 ON $(NF_SCHEMA).POOL (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PRODUCT_IDX5 ON $(NF_SCHEMA).PRODUCT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJECT_IDX5 ON $(NF_SCHEMA).PROJECT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJBASE_IDX5 ON $(NF_SCHEMA).PROJECT_BASELINE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJCAT_IDX5 ON $(NF_SCHEMA).PROJECT_CATEGORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PHASE_IDX5 ON $(NF_SCHEMA).PHASE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJROLE_IDX5 ON $(NF_SCHEMA).PROJECT_ROLE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJTYPE_IDX5 ON $(NF_SCHEMA).PROJECT_TYPE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJWRKCFG_IDX5 ON $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RELEASE_IDX5 ON $(NF_SCHEMA).RELEASE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX5 ON $(NF_SCHEMA).REQUEST (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQSTH_IDX5 ON $(NF_SCHEMA).REQUEST_STATE_HISTORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQUI_IDX5 ON $(NF_SCHEMA).REQUIREMENT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RESOURCE_IDX5 ON $(NF_SCHEMA).RESOURCE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RISK_IDX5 ON $(NF_SCHEMA).RISK (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RISKSTH_IDX5 ON $(NF_SCHEMA).RISK_STATE_HISTORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTSUITELOG_IDX5 ON $(NF_SCHEMA).TESTSUITELOG (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TASK_IDX5 ON $(NF_SCHEMA).TASK (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TASKCAT_IDX5 ON $(NF_SCHEMA).TASK_CATEGORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTCASE_IDX5 ON $(NF_SCHEMA).TESTCASE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX EXECRES_IDX5 ON $(NF_SCHEMA).EXECUTION_RESULT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTPLAN_IDX5 ON $(NF_SCHEMA).TESTPLAN (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTSUITE_IDX5 ON $(NF_SCHEMA).TESTSUITE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTTYPE_IDX5 ON $(NF_SCHEMA).TESTTYPE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX LABRES_IDX5 ON $(NF_SCHEMA).LAB_RESOURCE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RESGRP_IDX5 ON $(NF_SCHEMA).RESOURCE_GROUP (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RESERV_IDX5 ON $(NF_SCHEMA).RESERVATION (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ACTSTH_IDX5 ON $(NF_SCHEMA).ACTIVITY_STATE_HISTORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TSKSTH_IDX5 ON $(NF_SCHEMA).TASK_STATE_HISTORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX JOB_IDX5 ON $(NF_SCHEMA).JOB (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX JOBRES_IDX5 ON $(NF_SCHEMA).JOB_RESULT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTSCRIPT_IDX5 ON $(NF_SCHEMA).TESTSCRIPT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TSTSELE_IDX5 ON $(NF_SCHEMA).TESTSUITE_ELEMENT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX  
GO
CREATE INDEX REQLINKTP_IDX5 ON $(NF_SCHEMA).REQUIREMENT_LINK_TYPE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX	
GO
CREATE INDEX REQRELT_IDX5 ON $(NF_SCHEMA).REQUEST_RELATIONAL_LINK (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO


CREATE INDEX REQLINKTP_IDX6 ON $(NF_SCHEMA).REQUIREMENT_LINK_TYPE (ISSOFTDELETED)  ON VNF_IDX	
GO
CREATE INDEX REQUEST_IDX6 ON $(NF_SCHEMA).REQUEST (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX7 ON $(NF_SCHEMA).REQUEST (REQUEST_CLASS_ID ,REQUEST_ID ,EXTERNAL_KEY1 ,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX15 ON $(NF_SCHEMA).REQUEST (REQUEST_CLASS_ID ,REQUEST_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX8 ON $(NF_SCHEMA).REQUEST (REQUEST_ID ,EXTERNAL_KEY1 ,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX9 ON $(NF_SCHEMA).REQUEST (BUILD_ID ,REQUEST_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX10 ON $(NF_SCHEMA).REQUEST (REQUEST_CLASS_ID ,PROJECT_ID ,COMPONENT_ID ,OWNER_ID ,REQUEST_ID ,ITERATION_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX11 ON $(NF_SCHEMA).REQUEST (REQUEST_SOURCE)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX12 ON $(NF_SCHEMA).REQUEST (REQUEST_TYPE_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX13 ON $(NF_SCHEMA).REQUEST (REQUEST_STATUS_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX14 ON $(NF_SCHEMA).REQUEST (COMPONENT_ID ,IS_BLOCKING ,REQUEST_ID)  ON VNF_IDX
GO
CREATE INDEX REQUI_IDX6 ON $(NF_SCHEMA).REQUIREMENT (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQUI_IDX7 ON $(NF_SCHEMA).REQUIREMENT (SOURCE_ID ,ISSOFTDELETED ,REQUIREMENT_ID )  ON VNF_IDX
GO
CREATE INDEX REQUI_IDX8 ON $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_CLASS_ID ,PROJECT_ID,COMPONENT_ID ,PLANNED_ITERATION_ID ,RELEASE_ID ,REQUIREMENT_ID ,OWNER_ID)  ON VNF_IDX
GO
CREATE INDEX FILEVER_IDX6 ON $(NF_SCHEMA).FILE_VERSION (FILE_ID ,FILE_VERSION_ID ,ACTIVITY_ID ,FILE_STREAM_ID)  ON VNF_IDX
GO
CREATE INDEX TASK_IDX6 ON $(NF_SCHEMA).TASK (ITERATION_ID)  ON VNF_IDX
GO
CREATE INDEX TASK_IDX7 ON $(NF_SCHEMA).TASK (TASK_TYPE)  ON VNF_IDX
GO
CREATE INDEX TMPHISREQ_IDX1 ON $(NF_SCHEMA).TEMP_REQUEST_HISTORY (DBID ,DATASOURCE_ID ,HISTORY_ACTION_TIMESTAMP)  ON VNF_IDX
GO
CREATE INDEX TMPHISREQ_IDX2 ON $(NF_SCHEMA).REQUEST_STATE_HISTORY (DAYS_IN_STATE ,REQUEST_ID)  ON VNF_IDX
GO
CREATE INDEX TMPHISREQ_IDX3 ON $(NF_SCHEMA).TEMP_REQUEST_HISTORY (HISTORY_OLD_STATE ,HISTORY_DBID ,HISTORY_NEW_STATE ,DBID ,DATASOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FBASELNACT_IDX1 ON $(NF_SCHEMA).FILE_BASELINE_ACTIVITY_LOOKUP (ACTIVITY_ID)  ON VNF_IDX
GO
CREATE INDEX TMPHISREQ_IDX4 ON $(NF_SCHEMA).TEMP_REQUEST_HISTORY (HISTORY_NEW_STATE ,HISTORY_OLD_STATE ,DBID ,DATASOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TMPHISREQ_IDX5 ON $(NF_SCHEMA).REQUEST_CHANGE_HISTORY (REQUEST_ID ,CHANGE_DATE)  ON VNF_IDX
GO
CREATE INDEX ACTI_IDX6 ON $(NF_SCHEMA).ACTIVITY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX ACTI_IDX7 ON $(NF_SCHEMA).ACTIVITY (OWNER_ID ,ACTIVITY_ID ,ACTIVITY_CLASS_ID ,TASK_ID)  ON VNF_IDX
GO
CREATE INDEX ACTI_IDX8 ON $(NF_SCHEMA).ACTIVITY (ACTIVITY_CLASS_ID ,OWNER_ID ,ACTIVITY_ID)  ON VNF_IDX
GO
CREATE INDEX ACTI_IDX9 ON $(NF_SCHEMA).ACTIVITY (SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX EXECWKI_IDX6 ON $(NF_SCHEMA).EXECUTION_WORKITEM (SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJECT_IDX6 ON $(NF_SCHEMA).PROJECT (ISSOFTDELETED )  ON VNF_IDX
GO
CREATE INDEX BUILD_IDX6 ON $(NF_SCHEMA).BUILD (ISSOFTDELETED )  ON VNF_IDX
GO
CREATE INDEX TESTSCRIPT_IDX6 ON $(NF_SCHEMA).TESTSCRIPT (ISSOFTDELETED )  ON VNF_IDX
GO

CREATE INDEX CITY_IDX3 ON $(NF_SCHEMA).CITY (EXTERNAL_KEY2) ON VNF_IDX
GO
CREATE INDEX CITY_IDX4 ON $(NF_SCHEMA).CITY (EXTERNAL_KEY1,SOURCE_ID) ON VNF_IDX
GO  
CREATE INDEX CITY_IDX5 ON $(NF_SCHEMA).CITY (EXTERNAL_KEY2,SOURCE_ID) ON VNF_IDX
GO 
         
CREATE INDEX COMPETENCY_IDX3 ON $(NF_SCHEMA).COMPETENCY (EXTERNAL_KEY2) ON VNF_IDX
GO          
CREATE INDEX COMPETENCY_IDX4 ON $(NF_SCHEMA).COMPETENCY (EXTERNAL_KEY1,SOURCE_ID) ON VNF_IDX
GO
CREATE INDEX COMPETENCY_IDX5 ON $(NF_SCHEMA).COMPETENCY (EXTERNAL_KEY2,SOURCE_ID) ON VNF_IDX
GO
         
CREATE INDEX COUNTRY_IDX3 ON $(NF_SCHEMA).COUNTRY (EXTERNAL_KEY2) ON VNF_IDX
GO          
CREATE INDEX COUNTRY_IDX4 ON $(NF_SCHEMA).COUNTRY (EXTERNAL_KEY1,SOURCE_ID) ON VNF_IDX
GO
CREATE INDEX COUNTRY_IDX5 ON $(NF_SCHEMA).COUNTRY (EXTERNAL_KEY2,SOURCE_ID) ON VNF_IDX
GO
        
CREATE INDEX ITERBASELINE_IDX3 ON $(NF_SCHEMA).ITERATION_BASELINE (EXTERNAL_KEY2) ON VNF_IDX
GO          
CREATE INDEX ITERBASELINE_IDX4 ON $(NF_SCHEMA).ITERATION_BASELINE (EXTERNAL_KEY1,SOURCE_ID) ON VNF_IDX
GO
CREATE INDEX ITERBASELINE_IDX5 ON $(NF_SCHEMA).ITERATION_BASELINE (EXTERNAL_KEY2,SOURCE_ID) ON VNF_IDX
GO
         
CREATE INDEX OPERTERRI_IDX3 ON $(NF_SCHEMA).OPERATING_TERRITORY (EXTERNAL_KEY2) ON VNF_IDX
GO          
CREATE INDEX OPERTERRI_IDX4 ON $(NF_SCHEMA).OPERATING_TERRITORY (EXTERNAL_KEY1,SOURCE_ID) ON VNF_IDX
GO
CREATE INDEX OPERTERRI_IDX5 ON $(NF_SCHEMA).OPERATING_TERRITORY (EXTERNAL_KEY2,SOURCE_ID) ON VNF_IDX
GO
         
CREATE INDEX PROGRAM_IDX3 ON $(NF_SCHEMA).PROGRAM (EXTERNAL_KEY2) ON VNF_IDX
GO          
CREATE INDEX PROGRAM_IDX4 ON $(NF_SCHEMA).PROGRAM (EXTERNAL_KEY1,SOURCE_ID) ON VNF_IDX
GO
CREATE INDEX PROGRAM_IDX5 ON $(NF_SCHEMA).PROGRAM (EXTERNAL_KEY2,SOURCE_ID) ON VNF_IDX
GO
         
CREATE INDEX PROJALLOC_IDX3 ON $(NF_SCHEMA).PROJECT_ALLOCATION (EXTERNAL_KEY2) ON VNF_IDX
GO          
CREATE INDEX PROJALLOC_IDX4 ON $(NF_SCHEMA).PROJECT_ALLOCATION (EXTERNAL_KEY1,SOURCE_ID) ON VNF_IDX
GO
CREATE INDEX PROJALLOC_IDX5 ON $(NF_SCHEMA).PROJECT_ALLOCATION (EXTERNAL_KEY2,SOURCE_ID) ON VNF_IDX
GO
        
CREATE INDEX PROVSTATE_IDX3 ON $(NF_SCHEMA).PROVINCE_STATE (EXTERNAL_KEY2) ON VNF_IDX
GO          
CREATE INDEX PROVSTATE_IDX4 ON $(NF_SCHEMA).PROVINCE_STATE (EXTERNAL_KEY1,SOURCE_ID) ON VNF_IDX
GO
CREATE INDEX PROVSTATE_IDX5 ON $(NF_SCHEMA).PROVINCE_STATE (EXTERNAL_KEY2,SOURCE_ID) ON VNF_IDX
GO
        
CREATE INDEX SKILL_IDX3 ON $(NF_SCHEMA).SKILL (EXTERNAL_KEY2) ON VNF_IDX
GO          
CREATE INDEX SKILL_IDX4 ON $(NF_SCHEMA).SKILL (EXTERNAL_KEY1,SOURCE_ID) ON VNF_IDX
GO
CREATE INDEX SKILL_IDX5 ON $(NF_SCHEMA).SKILL (EXTERNAL_KEY2,SOURCE_ID) ON VNF_IDX
GO
         
CREATE INDEX TASK_BASE_IDX3 ON $(NF_SCHEMA).TASK_BASELINE (EXTERNAL_KEY2) ON VNF_IDX
GO          
CREATE INDEX TASK_BASE_IDX4 ON $(NF_SCHEMA).TASK_BASELINE (EXTERNAL_KEY1,SOURCE_ID) ON VNF_IDX
GO
CREATE INDEX TASK_BASE_IDX5 ON $(NF_SCHEMA).TASK_BASELINE (EXTERNAL_KEY2,SOURCE_ID) ON VNF_IDX
GO

CREATE INDEX CHARGECODE_IDX3 ON $(NF_SCHEMA).CHARGECODE (EXTERNAL_KEY2) ON VNF_IDX
GO
CREATE INDEX CHARGECODE_IDX4 ON $(NF_SCHEMA).CHARGECODE (EXTERNAL_KEY1,SOURCE_ID) ON VNF_IDX
GO
CREATE INDEX CHARGECODE_IDX5 ON $(NF_SCHEMA).CHARGECODE (EXTERNAL_KEY2,SOURCE_ID) ON VNF_IDX
GO
         
CREATE INDEX REQUI_COLLECT_IDX3 ON $(NF_SCHEMA).REQUIREMENT_COLLECTION (EXTERNAL_KEY2)  ON VNF_IDX
GO   
CREATE INDEX REQUI_COLLECT_IDX4 ON $(NF_SCHEMA).REQUIREMENT_COLLECTION (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQUI_COLLECT_IDX5 ON $(NF_SCHEMA).REQUIREMENT_COLLECTION (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX PORTFOLIO_IDX3 ON $(NF_SCHEMA).PORTFOLIO (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PORTFOLIO_IDX4 ON $(NF_SCHEMA).PORTFOLIO (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PORTFOLIO_IDX5 ON $(NF_SCHEMA).PORTFOLIO (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX BLD_CRESULT_IDX3 ON $(NF_SCHEMA).BUILD_COMPILATION_RESULT (EXTERNAL_KEY2)  ON VNF_IDX   
GO       
CREATE INDEX BLD_CRESULT_IDX4 ON $(NF_SCHEMA).BUILD_COMPILATION_RESULT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX BLD_CRESULT_IDX5 ON $(NF_SCHEMA).BUILD_COMPILATION_RESULT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX BLD_URESULT_IDX3 ON $(NF_SCHEMA).BUILD_UNIT_RESULT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX BLD_URESULT_IDX4 ON $(NF_SCHEMA).BUILD_UNIT_RESULT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX BLD_URESULT_IDX5 ON $(NF_SCHEMA).BUILD_UNIT_RESULT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX BLD_UEVENT_IDX3 ON $(NF_SCHEMA).BUILD_UNIT_EVENT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX BLD_UEVENT_IDX4 ON $(NF_SCHEMA).BUILD_UNIT_EVENT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX BLD_UEVENT_IDX5 ON $(NF_SCHEMA).BUILD_UNIT_EVENT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX UNT_TSTRES_IDX3 ON $(NF_SCHEMA).UNIT_TEST_RESULT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX UNT_TSTRES_IDX4 ON $(NF_SCHEMA).UNIT_TEST_RESULT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX UNT_TSTRES_IDX5 ON $(NF_SCHEMA).UNIT_TEST_RESULT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX FBASELINE_IDX3 ON $(NF_SCHEMA).FILE_BASELINE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX FBASELINE_IDX4 ON $(NF_SCHEMA).FILE_BASELINE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FBASELINE_IDX5 ON $(NF_SCHEMA).FILE_BASELINE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX PROFILE_IDX3 ON $(NF_SCHEMA).PROFILE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PROFILE_IDX4 ON $(NF_SCHEMA).PROFILE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROFILE_IDX5 ON $(NF_SCHEMA).PROFILE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX REQCAT_IDX3 ON $(NF_SCHEMA).REQUEST_CATEGORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX REQCAT_IDX4 ON $(NF_SCHEMA).REQUEST_CATEGORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQCAT_IDX5 ON $(NF_SCHEMA).REQUEST_CATEGORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX REQCGNGH_IDX3 ON $(NF_SCHEMA).REQUEST_CHANGE_HISTORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX REQCGNGH_IDX4 ON $(NF_SCHEMA).REQUEST_CHANGE_HISTORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQCGNGH_IDX5 ON $(NF_SCHEMA).REQUEST_CHANGE_HISTORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX REQREV_IDX3 ON $(NF_SCHEMA).REQUIREMENT_REVISION_HISTORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX REQREV_IDX4 ON $(NF_SCHEMA).REQUIREMENT_REVISION_HISTORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQREV_IDX5 ON $(NF_SCHEMA).REQUIREMENT_REVISION_HISTORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX TSTCAT_IDX3 ON $(NF_SCHEMA).TEST_CATEGORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TSTCAT_IDX4 ON $(NF_SCHEMA).TEST_CATEGORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TSTCAT_IDX5 ON $(NF_SCHEMA).TEST_CATEGORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX TIMECODE_IDX3 ON $(NF_SCHEMA).TIMECODE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TIMECODE_IDX4 ON $(NF_SCHEMA).TIMECODE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TIMECODE_IDX5 ON $(NF_SCHEMA).TIMECODE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX TIMESHEET_IDX3 ON $(NF_SCHEMA).TIMESHEET (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TIMESHEET_IDX4 ON $(NF_SCHEMA).TIMESHEET (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TIMESHEET_IDX5 ON $(NF_SCHEMA).TIMESHEET (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX ORGANIZATION_IDX3 ON $(NF_SCHEMA).ORGANIZATION (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX ORGANIZATION_IDX4 ON $(NF_SCHEMA).ORGANIZATION (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ORGANIZATION_IDX5 ON $(NF_SCHEMA).ORGANIZATION (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX SUITEEXECREC_IDX3 ON $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD (EXTERNAL_KEY2)  ON VNF_IDX  
GO
CREATE INDEX SUITEEXECREC_IDX4 ON $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX  
GO
CREATE INDEX SUITEEXECREC_IDX5 ON $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX  
GO
CREATE INDEX EXECSTPRES_IDX3 ON $(NF_SCHEMA).EXECUTION_STEP_RESULT (EXTERNAL_KEY2)  ON VNF_IDX  
GO
CREATE INDEX EXECSTPRES_IDX4 ON $(NF_SCHEMA).EXECUTION_STEP_RESULT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX  
GO
CREATE INDEX EXECSTPRES_IDX5 ON $(NF_SCHEMA).EXECUTION_STEP_RESULT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX  
GO

CREATE INDEX TMPHISREQ_IDX6 ON $(NF_SCHEMA).TEMP_REQUEST_HISTORY (HISTORY_UUID_DBID,DATASOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX UNT_TSTRES_IDX6 ON $(NF_SCHEMA).UNIT_TEST_RESULT (PROJECT_ID,TEAM_ID,BUILD_TYPE,COMPONENT_ID)  ON VNF_IDX
GO
CREATE INDEX TSTCAT_IDX6 ON $(NF_SCHEMA).TEST_CATEGORY (TERM,VALUE,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQSTH_IDX6 ON $(NF_SCHEMA).REQUEST_STATE_HISTORY (REQUEST_ID,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX COMPONENT_IDX6 ON $(NF_SCHEMA).COMPONENT (NAME)  ON VNF_IDX
GO
CREATE INDEX CUSTOMER_IDX6 ON $(NF_SCHEMA).CUSTOMER (SOURCE_ID,COMPANY_NAME,NAME)  ON VNF_IDX
GO
CREATE INDEX PRODUCT_IDX6 ON $(NF_SCHEMA).PRODUCT (SOURCE_ID,NAME)  ON VNF_IDX
GO
CREATE INDEX RELEASE_IDX6 ON $(NF_SCHEMA).RELEASE (SOURCE_ID,NAME)  ON VNF_IDX
GO
CREATE INDEX ITERATION_IDX6 ON $(NF_SCHEMA).ITERATION (SOURCE_ID,NAME)  ON VNF_IDX
GO
CREATE INDEX BUILD_IDX7 ON $(NF_SCHEMA).BUILD (SOURCE_ID,NAME)  ON VNF_IDX
GO
CREATE INDEX COMPONENT_IDX7 ON $(NF_SCHEMA).COMPONENT (SOURCE_ID,NAME)  ON VNF_IDX
GO
CREATE  INDEX TMP_RPJ_CAL_EXC_IDX1 ON $(NF_SCHEMA).TEMP_PROJECT_CALENDAR_EXCEP (EXCEPTION_DATE, EXTERNAL_KEY2, SOURCE_ID)  ON VNF_IDX
GO
CREATE  INDEX TMP_RSC_CAL_EXC_IDX1 ON $(NF_SCHEMA).TEMP_RESOURCE_CALENDAR_EXCEP (EXCEPTION_DATE, EXTERNAL_KEY2, SOURCE_ID)  ON VNF_IDX
GO


CREATE INDEX TMP_ACTIHIS_IDX ON $(NF_SCHEMA).TEMP_ACTIVITY_HISTORY (HISTORY_DBID,DATASOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX TMP_CALENDAR_IDX ON $(NF_SCHEMA).TEMP_CALENDAR (IDREF,SOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX TMP_CALERAN_IDX ON $(NF_SCHEMA).TEMP_CAL_EXCEPTION_RANGE (IDREF,SOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX TMP_COMPNT_IDX ON $(NF_SCHEMA).TEMP_COMPONENT (BASELINEACTIVITIESUNIQUEID,COMPONENTUNIQUEID,BASELINEUNIQUEID,FILEELEMENTUNIQUEID)  ON VNF_IDX 
GO
CREATE INDEX TMP_FILEVER_IDX ON $(NF_SCHEMA).TEMP_FILEVERSION (UNIQUEID)  ON VNF_IDX 
GO
CREATE INDEX TMP_PROJ_IDX ON $(NF_SCHEMA).TEMP_PROJECT (VERSIONUNIQUEID,ACTIVITYUNIQUEID,PROJECTUNIQUEID,STREAMUNIQUEID)  ON VNF_IDX 
GO
CREATE INDEX TMP_PROJCAL_IDX ON $(NF_SCHEMA).TEMP_PROJECT_CALENDAR (PROJECT_IDREF)  ON VNF_IDX 
GO
CREATE INDEX TMP_REQHIS_IDX ON $(NF_SCHEMA).TEMP_REQUEST_HISTORY (HISTORY_DBID,DATASOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX TMP_REQUI_IDX ON $(NF_SCHEMA).TEMP_REQUIREMENT (IDENTIFIER,DATASOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX TMP_RESCAL_IDX ON $(NF_SCHEMA).TEMP_RESOURCE_CALENDAR (RESOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX TMP_TASKHIS_IDX ON $(NF_SCHEMA).TEMP_TASK_HISTORY (HISTORY_DBID,DATASOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX TMP_CATEG_IDX ON $(NF_SCHEMA).TEMP_TEST_CATEGORY ( DATASOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX TMP_BSLINE_IDX ON $(NF_SCHEMA).TEMP_BASELINE (BASELINE_ID, PARENT_ID, DATASOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX TMP_RSC_IDX ON $(NF_SCHEMA).TEMP_RESOURCE (ID, ROW_ID, COLUMNID, DATASOURCE_ID)  ON VNF_IDX 
GO
CREATE INDEX ACTI_IDX2 ON $(NF_SCHEMA).ACTIVITY (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX ASETR_IDX2 ON $(NF_SCHEMA).ASSETREGISTRY (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX BUILD_IDX2 ON $(NF_SCHEMA).BUILD (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX CHARGECODE_IDX2 ON $(NF_SCHEMA).CHARGECODE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX CITY_IDX2 ON $(NF_SCHEMA).CITY (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX COMMENT_IDX2 ON $(NF_SCHEMA).COMMENT (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX COMPETENCY_IDX2 ON $(NF_SCHEMA).COMPETENCY (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX COMPONENT_IDX2 ON $(NF_SCHEMA).COMPONENT (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX CONFIG_IDX2 ON $(NF_SCHEMA).CONFIGURATION (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX CONFIGATT_IDX2 ON $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX COUNTRY_IDX2 ON $(NF_SCHEMA).COUNTRY (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX CURRENCY_IDX2 ON $(NF_SCHEMA).CURRENCY (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX CUSTOMER_IDX2 ON $(NF_SCHEMA).CUSTOMER (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX EXECRES_IDX2 ON $(NF_SCHEMA).EXECUTION_RESULT (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX EXECSTPRES_IDX2 ON $(NF_SCHEMA).EXECUTION_STEP_RESULT (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX EXECWKI_IDX2 ON $(NF_SCHEMA).EXECUTION_WORKITEM (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX FACTOR_IDX2 ON $(NF_SCHEMA).FACTOR (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX FILE_IDX2 ON $(NF_SCHEMA).[FILE] (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX FBASELINE_IDX2 ON $(NF_SCHEMA).FILE_BASELINE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX FILESTR_IDX2 ON $(NF_SCHEMA).FILE_STREAM (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX FILEVER_IDX2 ON $(NF_SCHEMA).FILE_VERSION (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX ITERATION_IDX2 ON $(NF_SCHEMA).ITERATION (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX ITERBASELINE_IDX2 ON $(NF_SCHEMA).ITERATION_BASELINE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX JOB_IDX2 ON $(NF_SCHEMA).JOB (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX JOBRES_IDX2 ON $(NF_SCHEMA).JOB_RESULT (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX LABRES_IDX2 ON $(NF_SCHEMA).LAB_RESOURCE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX OPERTERRI_IDX2 ON $(NF_SCHEMA).OPERATING_TERRITORY (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX ORGANIZATION_IDX2 ON $(NF_SCHEMA).ORGANIZATION (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX PHASE_IDX2 ON $(NF_SCHEMA).PHASE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX POOL_IDX2 ON $(NF_SCHEMA).POOL (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX PORTFOLIO_IDX2 ON $(NF_SCHEMA).PORTFOLIO (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX PRODUCT_IDX2 ON $(NF_SCHEMA).PRODUCT (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX PROFILE_IDX2 ON $(NF_SCHEMA).PROFILE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX PROGRAM_IDX2 ON $(NF_SCHEMA).PROGRAM (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX PROJECT_IDX2 ON $(NF_SCHEMA).PROJECT (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX PROJALLOC_IDX2 ON $(NF_SCHEMA).PROJECT_ALLOCATION (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX PROJBASE_IDX2 ON $(NF_SCHEMA).PROJECT_BASELINE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX PROJCAT_IDX2 ON $(NF_SCHEMA).PROJECT_CATEGORY (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX PROJROLE_IDX2 ON $(NF_SCHEMA).PROJECT_ROLE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX PROJTYPE_IDX2 ON $(NF_SCHEMA).PROJECT_TYPE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX PROJWRKCFG_IDX2 ON $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX PROVSTATE_IDX2 ON $(NF_SCHEMA).PROVINCE_STATE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX RELEASE_IDX2 ON $(NF_SCHEMA).RELEASE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX REQUEST_IDX2 ON $(NF_SCHEMA).REQUEST (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX REQCAT_IDX2 ON $(NF_SCHEMA).REQUEST_CATEGORY (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX REQUI_IDX2 ON $(NF_SCHEMA).REQUIREMENT (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX REQUI_COLLECT_IDX2 ON $(NF_SCHEMA).REQUIREMENT_COLLECTION (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX RESERV_IDX2 ON $(NF_SCHEMA).RESERVATION (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX RESOURCE_IDX2 ON $(NF_SCHEMA).RESOURCE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX RESGRP_IDX2 ON $(NF_SCHEMA).RESOURCE_GROUP (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX RISK_IDX2 ON $(NF_SCHEMA).RISK (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX SKILL_IDX2 ON $(NF_SCHEMA).SKILL (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX TASK_IDX2 ON $(NF_SCHEMA).TASK (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX TASK_BASE_IDX2 ON $(NF_SCHEMA).TASK_BASELINE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX TASKCAT_IDX2 ON $(NF_SCHEMA).TASK_CATEGORY (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX COMPTEAM_IDX2 ON $(NF_SCHEMA).TEAM (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX TESTCASE_IDX2 ON $(NF_SCHEMA).TESTCASE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX TESTPLAN_IDX2 ON $(NF_SCHEMA).TESTPLAN (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX TESTSCRIPT_IDX2 ON $(NF_SCHEMA).TESTSCRIPT (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX TESTSUITE_IDX2 ON $(NF_SCHEMA).TESTSUITE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX TESTSUITELOG_IDX2 ON $(NF_SCHEMA).TESTSUITELOG (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX SUITEEXECREC_IDX2 ON $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX TESTTYPE_IDX2 ON $(NF_SCHEMA).TESTTYPE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX TSTCAT_IDX2 ON $(NF_SCHEMA).TEST_CATEGORY (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX TIMECODE_IDX2 ON $(NF_SCHEMA).TIMECODE (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX TIMESHEET_IDX2 ON $(NF_SCHEMA).TIMESHEET (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX TSTSELE_IDX2 ON $(NF_SCHEMA).TESTSUITE_ELEMENT (EXTERNAL_ID)  ON VNF_IDX  
GO
CREATE INDEX EXECRES_IDX6 ON $(NF_SCHEMA).EXECUTION_RESULT  (ISSOFTDELETED ASC,EXECUTION_RESULT_ID ASC,ITERATION_ID ASC,PROJECT_ID ASC,EXECRES_CLASS_ID ASC,VERDICT ASC,TESTCASE_ID ASC) ON VNF_IDX 
GO
CREATE INDEX TESTPLAN_IDX6 ON $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID ASC,ASSETREGISTRY_ID ) ON VNF_IDX
GO
CREATE INDEX TESTCASE_IDX6 ON $(NF_SCHEMA).TESTCASE  (TESTPLAN_ID ASC,TESTCASE_ID ASC) ON VNF_IDX
GO	
CREATE INDEX EXECWKI_IDX7 ON $(NF_SCHEMA).EXECUTION_WORKITEM  (EXECWORKITEM_ID ASC,TESTPLAN_ID ) ON VNF_IDX
GO		
CREATE INDEX EXWKIITER_IDX1 ON $(NF_SCHEMA).EXECWORKITEM_ITERATION_LOOKUP (EXECWORKITEM_ID ASC,ITERATION_ID DESC) ON VNF_IDX
GO

CREATE INDEX REQLINKTP_IDX7 ON $(NF_SCHEMA).REQUIREMENT_LINK_TYPE (EXTERNAL_ID)  ON VNF_IDX	
GO
CREATE INDEX TMP_REQUEST_IDX3 ON $(NF_SCHEMA).TEMP_REQUEST (EXTERNAL_KEY2)  ON VNF_IDX 
GO
CREATE INDEX TMP_REQUEST_IDX4 ON $(NF_SCHEMA).TEMP_REQUEST (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TMP_REQUEST_IDX5 ON $(NF_SCHEMA).TEMP_REQUEST (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TMP_TGHEAD ON $(NF_SCHEMA).TEMP_TIMEGRID_HEAD (COLUMN_ID,PROJECT_ID,SHEET)  ON VNF_IDX
GO
CREATE INDEX TMP_FP_PRJ ON $(NF_SCHEMA).TEMP_FP_PROJECT (MD5_URL)  ON VNF_IDX 
GO
CREATE INDEX TSKSTH_IDX6 ON $(NF_SCHEMA).TASK_STATE_HISTORY(TASK_ID)  ON VNF_IDX
GO
CREATE INDEX TASK_IDX8 ON $(NF_SCHEMA).TASK(PROJECT_ID, TASK_ID)  ON VNF_IDX
GO
CREATE INDEX ACTI_IDX10 ON $(NF_SCHEMA).ACTIVITY(ISSOFTDELETED, OWNER_ID, TASK_ID, ACTIVITY_ID)  ON VNF_IDX
GO
CREATE INDEX REQSTH_IDX7 ON $(NF_SCHEMA).REQUEST_STATE_HISTORY(REQUEST_ID, REQUEST_STATE_ID)  ON VNF_IDX
GO
CREATE INDEX ACTSTH_IDX6 ON $(NF_SCHEMA).ACTIVITY_STATE_HISTORY(ACTIVITY_ID, CHANGE_DATE)  ON VNF_IDX
GO
CREATE INDEX BLD_CRESULT_IDX6 ON $(NF_SCHEMA).BUILD_COMPILATION_RESULT (BUILD_ID,COMPONENT_ID)  ON  VNF_IDX 
GO
CREATE INDEX BLD_UEVENT_IDX6 ON $(NF_SCHEMA).BUILD_UNIT_EVENT (BUILD_ID,COMPONENT_ID,UNIT_TEST)  ON  VNF_IDX 
GO
CREATE INDEX BLD_URESULT_IDX6 ON $(NF_SCHEMA).BUILD_UNIT_RESULT (BUILD_ID,COMPONENT_ID)  ON  VNF_IDX 
GO

CREATE INDEX ACTSTH_IDX7 ON $(NF_SCHEMA).ACTIVITY_STATE_HISTORY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX ASETR_IDX6 ON $(NF_SCHEMA).ASSETREGISTRY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX BLD_CRESULT_IDX7 ON $(NF_SCHEMA).BUILD_COMPILATION_RESULT (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX BLD_UEVENT_IDX7 ON $(NF_SCHEMA).BUILD_UNIT_EVENT (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX BLD_URESULT_IDX7 ON $(NF_SCHEMA).BUILD_UNIT_RESULT (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX CHARGECODE_IDX6 ON $(NF_SCHEMA).CHARGECODE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX CITY_IDX6 ON $(NF_SCHEMA).CITY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX COMMENT_IDX6 ON $(NF_SCHEMA).COMMENT (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX COMPETENCY_IDX6 ON $(NF_SCHEMA).COMPETENCY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX COMPONENT_IDX8 ON $(NF_SCHEMA).COMPONENT (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX CONFIG_IDX6 ON $(NF_SCHEMA).CONFIGURATION (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX CONFIGATT_IDX6 ON $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX COUNTRY_IDX6 ON $(NF_SCHEMA).COUNTRY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX CURRENCY_IDX6 ON $(NF_SCHEMA).CURRENCY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX CUSTOMER_IDX7 ON $(NF_SCHEMA).CUSTOMER (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX EXECRES_IDX7 ON $(NF_SCHEMA).EXECUTION_RESULT (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX EXECSTPRES_IDX6 ON $(NF_SCHEMA).EXECUTION_STEP_RESULT (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX EXECWKI_IDX8 ON $(NF_SCHEMA).EXECUTION_WORKITEM (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX FACTOR_IDX6 ON $(NF_SCHEMA).FACTOR (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX FILE_IDX6 ON $(NF_SCHEMA).[FILE] (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX FBASELINE_IDX6 ON $(NF_SCHEMA).FILE_BASELINE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX FILESTR_IDX6 ON $(NF_SCHEMA).FILE_STREAM (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX FILEVER_IDX7 ON $(NF_SCHEMA).FILE_VERSION (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX ITERATION_IDX7 ON $(NF_SCHEMA).ITERATION (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX ITERBASELINE_IDX6 ON $(NF_SCHEMA).ITERATION_BASELINE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX JOB_IDX6 ON $(NF_SCHEMA).JOB (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX JOBRES_IDX6 ON $(NF_SCHEMA).JOB_RESULT (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX LABRES_IDX6 ON $(NF_SCHEMA).LAB_RESOURCE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX OPERTERRI_IDX6 ON $(NF_SCHEMA).OPERATING_TERRITORY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX ORGANIZATION_IDX6 ON $(NF_SCHEMA).ORGANIZATION (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PHASE_IDX6 ON $(NF_SCHEMA).PHASE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX POOL_IDX6 ON $(NF_SCHEMA).POOL (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PORTFOLIO_IDX6 ON $(NF_SCHEMA).PORTFOLIO (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PRODUCT_IDX7 ON $(NF_SCHEMA).PRODUCT (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROFILE_IDX6 ON $(NF_SCHEMA).PROFILE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROGRAM_IDX6 ON $(NF_SCHEMA).PROGRAM (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROJALLOC_IDX6 ON $(NF_SCHEMA).PROJECT_ALLOCATION (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROJBASE_IDX6 ON $(NF_SCHEMA).PROJECT_BASELINE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROJCAT_IDX6 ON $(NF_SCHEMA).PROJECT_CATEGORY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROJROLE_IDX6 ON $(NF_SCHEMA).PROJECT_ROLE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROJTYPE_IDX6 ON $(NF_SCHEMA).PROJECT_TYPE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROJWRKCFG_IDX6 ON $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROVSTATE_IDX6 ON $(NF_SCHEMA).PROVINCE_STATE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX RELEASE_IDX7 ON $(NF_SCHEMA).RELEASE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQCAT_IDX6 ON $(NF_SCHEMA).REQUEST_CATEGORY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQCGNGH_IDX6 ON $(NF_SCHEMA).REQUEST_CHANGE_HISTORY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQP_IDX1 ON $(NF_SCHEMA).REQUEST_PRIORITY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQRELT_IDX6 ON $(NF_SCHEMA).REQUEST_RELATIONAL_LINK (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQR_IDX1 ON $(NF_SCHEMA).REQUEST_RESOLUTION (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQS_IDX1 ON $(NF_SCHEMA).REQUEST_SEVERITY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQSTE_IDX1 ON $(NF_SCHEMA).REQUEST_STATE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQSTH_IDX8 ON $(NF_SCHEMA).REQUEST_STATE_HISTORY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQSTS_IDX1 ON $(NF_SCHEMA).REQUEST_STATUS (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQT_IDX1 ON $(NF_SCHEMA).REQUEST_TYPE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQUI_COLLECT_IDX6 ON $(NF_SCHEMA).REQUIREMENT_COLLECTION (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQREV_IDX6 ON $(NF_SCHEMA).REQUIREMENT_REVISION_HISTORY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX RESERV_IDX6 ON $(NF_SCHEMA).RESERVATION (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX RESOURCE_IDX6 ON $(NF_SCHEMA).RESOURCE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX RESGRP_IDX6 ON $(NF_SCHEMA).RESOURCE_GROUP (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX RISK_IDX6 ON $(NF_SCHEMA).RISK (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX RISKSTH_IDX6 ON $(NF_SCHEMA).RISK_STATE_HISTORY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX SKILL_IDX6 ON $(NF_SCHEMA).SKILL (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TASK_IDX9 ON $(NF_SCHEMA).TASK (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TASK_BASE_IDX6 ON $(NF_SCHEMA).TASK_BASELINE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TASKCAT_IDX6 ON $(NF_SCHEMA).TASK_CATEGORY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TSKSTH_IDX7 ON $(NF_SCHEMA).TASK_STATE_HISTORY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX COMPTEAM_IDX6 ON $(NF_SCHEMA).TEAM (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TEAR_IDX1 ON $(NF_SCHEMA).TEAM_ROLE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TESTCASE_IDX7 ON $(NF_SCHEMA).TESTCASE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TESTPLAN_IDX7 ON $(NF_SCHEMA).TESTPLAN (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TESTSUITE_IDX6 ON $(NF_SCHEMA).TESTSUITE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TESTSUITELOG_IDX6 ON $(NF_SCHEMA).TESTSUITELOG (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TSTSELE_IDX6 ON $(NF_SCHEMA).TESTSUITE_ELEMENT (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX SUITEEXECREC_IDX6 ON $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TESTTYPE_IDX6 ON $(NF_SCHEMA).TESTTYPE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TSTCAT_IDX7 ON $(NF_SCHEMA).TEST_CATEGORY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TIMECODE_IDX6 ON $(NF_SCHEMA).TIMECODE (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TIMESHEET_IDX6 ON $(NF_SCHEMA).TIMESHEET (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX UNT_TSTRES_IDX7 ON $(NF_SCHEMA).UNIT_TEST_RESULT (ISSOFTDELETED)  ON VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CUSTOMER ADD CONSTRAINT CUSTOMER_PK PRIMARY KEY (CUSTOMER_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY_CLASSIFICATION ADD CONSTRAINT ACTIVITYCL_PK PRIMARY KEY (ACTIVITY_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_PK PRIMARY KEY (ACTIVITY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_ACTIVITY_LOOKUP ADD CONSTRAINT REQACT_PK PRIMARY KEY (REQUEST_ID,ACTIVITY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).COMPONENT ADD CONSTRAINT COMPONENT_PK PRIMARY KEY (COMPONENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_COMPONENT_LOOKUP ADD CONSTRAINT PRJCOMP_PK PRIMARY KEY (PROJECT_ID,COMPONENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).COMPONENT_CLASSIFICATION ADD CONSTRAINT COMPCLS_PK PRIMARY KEY (COMPONENT_CLASS_ID) ON  VNF_IDX
GO
	
ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_PK PRIMARY KEY (BUILD_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_PK PRIMARY KEY (REQUIREMENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_COLLECTION ADD CONSTRAINT REQUI_COLLECT_PK PRIMARY KEY (REQUIREMENT_COLLECTION_ID)  ON VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUICOL_REQUIREMENT_LOOKUP ADD CONSTRAINT REQUICOLLECT_PK PRIMARY KEY (REQUIREMENT_COLLECTION_ID, REQUIREMENT_ID)  ON VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUICOL_TESTPLAN_LOOKUP ADD CONSTRAINT REQUICOL_TESTP_PK PRIMARY KEY (REQUIREMENT_COLLECTION_ID, TESTPLAN_ID)  ON VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REVISION_HISTORY ADD CONSTRAINT REQREV_PK PRIMARY KEY (REQUIREMENT_REVISION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE ADD CONSTRAINT TESTSUITE_PK PRIMARY KEY (TESTSUITE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_PK PRIMARY KEY (EXECUTION_RESULT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CURRENCY ADD CONSTRAINT CURRENCY_PK PRIMARY KEY (CURRENCY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).POOL ADD CONSTRAINT POOL_PK PRIMARY KEY (POOL_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE ADD CONSTRAINT RESOURCE_PK PRIMARY KEY (RESOURCE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).SKILL ADD CONSTRAINT SKILL_PK PRIMARY KEY(SKILL_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE_SKILL_LOOKUP ADD CONSTRAINT RESSKILL_PK PRIMARY KEY(RESOURCE_ID, SKILL_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).COMPETENCY ADD CONSTRAINT COMPETENCY_PK PRIMARY KEY(COMPETENCY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE_COMPETENCY_LOOKUP ADD CONSTRAINT RESCOMPETENCY_PK PRIMARY KEY(RESOURCE_ID, COMPETENCY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_STATE_HISTORY ADD CONSTRAINT REQUESTSTATEHIS_PK PRIMARY KEY (REQUEST_STATE_HISTORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CLASSIFICATION ADD CONSTRAINT REQ_CATEGORY_PK PRIMARY KEY (REQUEST_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_CLASSIFICATION ADD CONSTRAINT REQUI_CATG_PK PRIMARY KEY (REQUIREMENT_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK_CATEGORY ADD CONSTRAINT TASK_CATEGORY_PK PRIMARY KEY (TASK_CATEGORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PRODUCT ADD CONSTRAINT PRODUCT_PK PRIMARY KEY (PRODUCT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ASSETREGISTRY ADD CONSTRAINT ASSETREGISTRY_PK PRIMARY KEY (ASSETREGISTRY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ITERATION ADD CONSTRAINT ITERATION_PK PRIMARY KEY (ITERATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ITERATION_BASELINE ADD CONSTRAINT ITERBASELINE_PK PRIMARY KEY (BASELINE_ID,ITERATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RELEASE ADD CONSTRAINT RELEASE_PK PRIMARY KEY (RELEASE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_CLASSIFICATION ADD CONSTRAINT PROJECTCL_PK PRIMARY KEY (PROJECT_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT ADD CONSTRAINT PROJECT_PK PRIMARY KEY (PROJECT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK_BASELINE ADD CONSTRAINT TASKBL_PK PRIMARY KEY (BASELINE_ID,TASK_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK_CLASSIFICATION ADD CONSTRAINT TASKCL_PK PRIMARY KEY (TASK_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK ADD CONSTRAINT TASK_PK PRIMARY KEY (TASK_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_HIERARCHY ADD CONSTRAINT PROJECTHIER_PK PRIMARY KEY (PARENT_PROJECT_ID, CHILD_PROJECT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_DETAIL ADD CONSTRAINT PROJECTDT_PK PRIMARY KEY (PROJECT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_TYPE ADD CONSTRAINT PRJTYPE_PK PRIMARY KEY (PROJECT_TYPE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_WORKCONFIGURATION ADD CONSTRAINT PRJWKCFG_PK PRIMARY KEY (PROJECT_WKCFG_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_CATEGORY ADD CONSTRAINT PRJCAT_PK PRIMARY KEY (PROJECT_CATEGORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PHASE ADD CONSTRAINT PRJPHASE_PK PRIMARY KEY (PHASE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_ROLE ADD CONSTRAINT PRJROLE_PK PRIMARY KEY (PROJECT_ROLE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_ROLE_MEMBER_LOOKUP ADD CONSTRAINT PRJROLELK_PK PRIMARY KEY (PROJECT_ROLE_ID, RESOURCE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TEAM ADD CONSTRAINT CMPTEAM_PK PRIMARY KEY (TEAM_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK_DETAIL ADD CONSTRAINT TASKDT_PK PRIMARY KEY (TASK_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK_REQUIREMENT_LOOKUP ADD CONSTRAINT TSKREQ_PK PRIMARY KEY (TASK_ID, REQUIREMENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CONFIGURATION ADD CONSTRAINT CONFIGURATION_PK PRIMARY KEY (CONFIGURATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE ADD CONSTRAINT CFG_ATTRIBUTE_PK PRIMARY KEY (CONFIGURATION_ATTRIBUTE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE_LOOKUP ADD CONSTRAINT CFGATTR_ATTR_PK PRIMARY KEY (CONFIGURATION_ATTRIBUTE_ID, CONFIGURATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_ITERATION_LOOKUP ADD CONSTRAINT TSTITER_PK PRIMARY KEY (TESTSUITE_ID, ITERATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN ADD CONSTRAINT TESTPLAN_PK PRIMARY KEY (TESTPLAN_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_ITERATION_LOOKUP ADD CONSTRAINT TSPLNITER_PK PRIMARY KEY (TESTPLAN_ID, ITERATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTTYPE ADD CONSTRAINT TESTTYPE_PK PRIMARY KEY (TESTTYPE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE ADD CONSTRAINT TESTCASE_PK PRIMARY KEY (TESTCASE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_ITERATION_LOOKUP ADD CONSTRAINT TESTCITER_PK PRIMARY KEY (TESTCASE_ID, ITERATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTCASE_LOOKUP ADD CONSTRAINT REQTEST_PK PRIMARY KEY (REQUIREMENT_ID, TESTCASE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTPLAN_LOOKUP ADD CONSTRAINT REQTESTP_PK PRIMARY KEY (REQUIREMENT_ID, TESTPLAN_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTSUITE_LOOKUP ADD CONSTRAINT REQTESTS_PK PRIMARY KEY (REQUIREMENT_ID, TESTSUITE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REQUIREMENT_LOOKUP ADD CONSTRAINT REQTREQ_PK PRIMARY KEY (REQUIREMENT_ID, CREQUIREMENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_HIERARCHY ADD CONSTRAINT REQHIER_PK PRIMARY KEY (PRED_REQUIREMENT_ID, SUCC_REQUIREMENT_ID, LINK_TYPE_ID) ON  VNF_IDX  
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_LINK ADD CONSTRAINT REQULINK_PK PRIMARY KEY (PRED_REQUEST_ID, SUCC_REQUEST_ID) ON  VNF_IDX
GO
ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_PK PRIMARY KEY (EXECWORKITEM_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_ITERATION_LOOKUP ADD CONSTRAINT EXWKIITER_PK PRIMARY KEY (EXECWORKITEM_ID, ITERATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_EXECWRKITEM_LOOKUP ADD CONSTRAINT REQEXWKI_PK PRIMARY KEY (REQUIREMENT_ID, EXECWORKITEM_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_TESTSUITE_LOOKUP ADD CONSTRAINT EXWKITSU_PK PRIMARY KEY (EXECWORKITEM_ID, TESTSUITE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_PK PRIMARY KEY (REQUEST_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_HIERARCHY ADD CONSTRAINT REQUHIST_PK PRIMARY KEY (PARENT_REQUEST_ID, CHILD_REQUEST_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).FILE_VERSION ADD CONSTRAINT FLVERSION_PK PRIMARY KEY (FILE_VERSION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).[FILE] ADD CONSTRAINT FILE_PK PRIMARY KEY (FILE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).FILE_BASELINE ADD CONSTRAINT FBASELINE_PK PRIMARY KEY (FILE_BASELINE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).FILE_BASELINE_ACTIVITY_LOOKUP ADD CONSTRAINT FBACT_PK PRIMARY KEY (FILE_BASELINE_ID,ACTIVITY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).FILE_STREAM ADD CONSTRAINT FSTREAM_PK PRIMARY KEY (FILE_STREAM_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CONFIG_EXECUTIONRES_LOOKUP ADD CONSTRAINT EXWKISLG_PK PRIMARY KEY (CONFIGURATION_ID, EXECUTION_RESULT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_PK PRIMARY KEY (TESTSUITELOG_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG_EXECRESULT_LOOKUP ADD CONSTRAINT STESEXECR_PK PRIMARY KEY (TESTSUITELOG_ID, EXECUTION_RESULT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK_REQUEST_LOOKUP ADD CONSTRAINT TSKISS_PK PRIMARY KEY (TASK_ID, REQUEST_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REQUEST_LOOKUP ADD CONSTRAINT REQIREQ_PK PRIMARY KEY (REQUIREMENT_ID, REQUEST_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CUSTOMER_LOOKUP ADD CONSTRAINT REQUCULK_PK PRIMARY KEY (REQUEST_ID, CUSTOMER_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_CUSTOMER_LOOKUP ADD CONSTRAINT REQUICLK_PK PRIMARY KEY (REQUIREMENT_ID, CUSTOMER_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECRES_REQUEST_LOOKUP ADD CONSTRAINT EXECRGREQ_PK PRIMARY KEY (REQUEST_ID, EXECUTION_RESULT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RISK ADD CONSTRAINT RISK_PK PRIMARY KEY (RISK_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RISK_STATE_HISTORY ADD CONSTRAINT RISKSTATEHIS_PK PRIMARY KEY (RISK_STATE_HISTORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).FACTOR ADD CONSTRAINT FACTOR_PK PRIMARY KEY (FACTOR_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_BASELINE ADD CONSTRAINT PRJBASELINE_PK PRIMARY KEY (BASELINE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJ_BASELINE_BASELINE_LOOKUP ADD CONSTRAINT PRJBSLTOBSL_PK PRIMARY KEY (BASELINE_ID, COMPBASELINE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).COMMENT ADD CONSTRAINT COMMENT_PK PRIMARY KEY (COMMENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY_DETAIL ADD CONSTRAINT ACTIVITY_DETAIL_PK PRIMARY KEY (ACTIVITY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_WORKCONFIG_HIERARCHY ADD CONSTRAINT PRJWCFGH_PK PRIMARY KEY(PARENT_WKCFG_ID,CHILD_WKCFG_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TEST_CATEGORY ADD CONSTRAINT TSTCAT_PK PRIMARY KEY (TEST_CATEGORY_ID) 	ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECRES_EXECWKITEM_LOOKUP ADD CONSTRAINT EXECRESWK_PK PRIMARY KEY (EXECUTION_RESULT_ID,EXECWORKITEM_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CONFIG_EXECUTIONWORKITM_LOOKUP  ADD CONSTRAINT CFGEXECWK_PK PRIMARY KEY (CONFIGURATION_ID,EXECWORKITEM_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_CATEGORY_LOOKUP ADD CONSTRAINT TPLNCAT_PK PRIMARY KEY (TEST_CATEGORY_ID,TESTPLAN_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_CATEGORY_LOOKUP ADD CONSTRAINT TCASECAT_PK PRIMARY KEY (TEST_CATEGORY_ID,TESTCASE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTCASE_LOOKUP ADD CONSTRAINT TSUTCASE_PK PRIMARY KEY (TESTCASE_ID,TESTSUITE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTSUITELOG_LOOKUP ADD CONSTRAINT TSUTSULG_PK PRIMARY KEY (TESTSUITE_ID,TESTSUITELOG_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_TESTPLAN_HIERARCHY ADD CONSTRAINT TPLNPC_PK PRIMARY KEY (PARENT_TESTPLAN_ID,CHILD_TESTPLAN_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_TESTCASE_LOOKUP ADD CONSTRAINT TPLNTC_PK PRIMARY KEY (TESTPLAN_ID,TESTCASE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).LAB_RESOURCE ADD CONSTRAINT LABRES_PK PRIMARY KEY (LAB_RESOURCE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE_GROUP ADD CONSTRAINT RESGRP_PK PRIMARY KEY (RESOURCE_GROUP_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RESERVATION ADD CONSTRAINT RESERV_PK PRIMARY KEY (RESERVATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_CLASSIFICATION ADD CONSTRAINT TCCLASS_PK PRIMARY KEY (TESTCASE_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_CLASSIFICATION ADD CONSTRAINT TPLCLASS_PK PRIMARY KEY (TESTPLAN_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_CLASSIFICATION ADD CONSTRAINT TSUCLASS_PK PRIMARY KEY (TESTSUITE_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG_CLASSIFICATION ADD CONSTRAINT  TSLCLASS_PK PRIMARY KEY (TESTSUITELOG_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECRESULT_CLASSIFICATION ADD CONSTRAINT EXRESCLASS_PK PRIMARY KEY (EXECRES_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_CLASSIFICATION ADD CONSTRAINT EXEWKITCLASS_PK PRIMARY KEY (EXECWORKIT_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CONFIGURATION_CLASSIFICATION ADD CONSTRAINT CONFIGCLASS_PK PRIMARY KEY (CONFIGURATION_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY_STATE_HISTORY ADD CONSTRAINT ACTSTH_PK PRIMARY KEY (ACTIVITY_STATE_HISTORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK_STATE_HISTORY ADD CONSTRAINT TSKSTH_PK PRIMARY KEY (TASK_STATE_HISTORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CATEGORY ADD CONSTRAINT REQCAT_PK PRIMARY KEY (REQUEST_CATEGORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).FILE_CLASSIFICATION ADD CONSTRAINT FILECLS_PK PRIMARY KEY (FILE_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).FILE_STREAM_CLASSIFICATION ADD CONSTRAINT FILESTRMCLS_PK PRIMARY KEY (FILE_STREAM_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_PK PRIMARY KEY (REQCHANGE_HISTORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).BUILD_CLASSIFICATION  ADD CONSTRAINT BLDCLS_PK PRIMARY KEY (BUILD_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).BUILD_COMPILATION_RESULT ADD CONSTRAINT BLDCMPRES_PK PRIMARY KEY (BUILD_COMPRES_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).BUILD_UNIT_RESULT ADD CONSTRAINT BLDJUNRES_PK PRIMARY KEY (BUILD_UNITRES_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).BUILD_UNIT_EVENT ADD CONSTRAINT BLDJUNEVT_PK PRIMARY KEY (BUILD_UNIT_EVENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).UNIT_TEST_RESULT ADD CONSTRAINT BLDJUNTST_PK PRIMARY KEY (UNIT_TEST_RESULT_ID) 	ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).JOB ADD CONSTRAINT JOB_PK PRIMARY KEY (JOB_ID) 	ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).JOB_RESULT ADD CONSTRAINT JOBRES_PK PRIMARY KEY (JOB_RESULT_ID) 	ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSCRIPT ADD CONSTRAINT TESTSCRIPT_PK PRIMARY KEY (TESTSCRIPT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_TESTSCRIPT_LOOKUP ADD CONSTRAINT TESTCSCRIPT_PK PRIMARY KEY (TESTCASE_ID,TESTSCRIPT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ITERATION_DETAIL ADD CONSTRAINT ITERDET_PK PRIMARY KEY (ITERATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROGRAM ADD CONSTRAINT PROGRAM_PK PRIMARY KEY (PROGRAM_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROGRAM_DETAIL ADD CONSTRAINT PROGRAMDT_PK PRIMARY KEY (PROGRAM_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_ALLOCATION ADD CONSTRAINT PROJALLO_PK PRIMARY KEY (PROJECT_ALLOCATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TIMESHEET ADD CONSTRAINT TIMESHEET_PK PRIMARY KEY(TIMESHEET_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROFILE ADD CONSTRAINT PROFILE_PK PRIMARY KEY(PROFILE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROFILE_SKILL_LOOKUP ADD CONSTRAINT PROSKILL_PK PRIMARY KEY(PROFILE_ID, SKILL_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROFILE_COMPETENCY_LOOKUP ADD CONSTRAINT PROCOMPETENCY_PK PRIMARY KEY	(PROFILE_ID, COMPETENCY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CHARGECODE ADD CONSTRAINT CHARGECODE_PK PRIMARY KEY (CHARGECODE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TIMECODE ADD CONSTRAINT TIMECODE_PK PRIMARY KEY (TIMECODE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TIMESHEET_TIMECODE_LOOKUP ADD CONSTRAINT TSTC_PK PRIMARY KEY(TIMESHEET_ID, TIMECODE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).OPERATING_TERRITORY ADD CONSTRAINT OPTERRITORY_PK PRIMARY KEY (TERRITORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).COUNTRY ADD CONSTRAINT COUNTRY_PK PRIMARY KEY (COUNTRY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROVINCE_STATE ADD CONSTRAINT PROVSTATE_PK PRIMARY KEY (PROVINCE_STATE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CITY ADD CONSTRAINT CITY_PK PRIMARY KEY (CITY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ORGANIZATION ADD CONSTRAINT ORGANIZATION_PK PRIMARY KEY (ORGANIZATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PORTFOLIO ADD CONSTRAINT PORTFOLIO_PK PRIMARY KEY (PORTFOLIO_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PORTFOLIO_PROG_PROJ_LOOKUP ADD CONSTRAINT PORPROGPROJ_PK PRIMARY KEY (PORTFOLIO_ID,PROGRAM_ID,PROJECT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_TESTCASE_LOOKUP ADD CONSTRAINT REQUTCASE_PK PRIMARY KEY (REQUEST_ID, TESTCASE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_STATE ADD CONSTRAINT REQUTST_PK PRIMARY KEY (REQUEST_STATE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_STATUS ADD CONSTRAINT REQUTSTUS_PK PRIMARY KEY (REQUEST_STATUS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TEAM_ROLE ADD CONSTRAINT TEAMRL_PK PRIMARY KEY (TEAM_ROLE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_PRIORITY ADD CONSTRAINT REQUTPR_PK PRIMARY KEY (REQUEST_PRIORITY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_SEVERITY ADD CONSTRAINT REQUTSV_PK PRIMARY KEY (REQUEST_SEVERITY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_RESOLUTION ADD CONSTRAINT REQUTRES_PK PRIMARY KEY (REQUEST_RESOLUTION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_TYPE ADD CONSTRAINT REQUTTYP_PK PRIMARY KEY (REQUEST_TYPE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_RESOURCE_LOOKUP ADD CONSTRAINT PRJRESLK_PK PRIMARY KEY (PROJECT_ID,RESOURCE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RISK_REQUEST_LOOKUP ADD CONSTRAINT RSKREQLK_PK PRIMARY KEY (RISK_ID,REQUEST_ID) ON  VNF_IDX  
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_CATEGORY_LOOKUP ADD CONSTRAINT TSTSUITECATLK_PK PRIMARY KEY (TESTSUITE_ID,TEST_CATEGORY_ID) ON  VNF_IDX  
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTPLAN_LOOKUP ADD CONSTRAINT TSTSUITETPLNLK_PK PRIMARY KEY (TESTSUITE_ID,TESTPLAN_ID) ON  VNF_IDX  
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD ADD CONSTRAINT TSEXECREC_PK PRIMARY KEY (TESTSUITE_EXECRECORD_ID) ON  VNF_IDX  
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_REQUEST_LOOKUP ADD CONSTRAINT EXWKITREQUE_PK PRIMARY KEY (EXECWORKITEM_ID, REQUEST_ID) ON  VNF_IDX  
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_STEP_RESULT ADD CONSTRAINT EXECSTEP_PK PRIMARY KEY (EXECUTION_STEP_RESULT_ID) ON  VNF_IDX  
GO

ALTER TABLE $(NF_SCHEMA).EXECSTEPRES_REQUEST_LOOKUP ADD CONSTRAINT EXCSTRSREQUELK_PK PRIMARY KEY (EXECUTION_STEP_RESULT_ID,REQUEST_ID) ON  VNF_IDX  
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_ELEMENT ADD CONSTRAINT TSTSUITELE_PK PRIMARY KEY (TESTSUITE_ELEMENT_ID) ON  VNF_IDX  
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_LINK_TYPE ADD CONSTRAINT REQLINKTP_PK PRIMARY KEY (LINK_TYPE_ID) ON  VNF_IDX	
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_RELATIONAL_LINK ADD CONSTRAINT REQRELT_PK PRIMARY KEY (REQUEST_RELATION_ID)  ON  VNF_IDX
GO

-- FOREIGN KEY CONSTRAINTS

ALTER TABLE $(NF_SCHEMA).ACTIVITY_DETAIL ADD CONSTRAINT ACTDET_FK1 FOREIGN KEY (ACTIVITY_ID) 
REFERENCES $(NF_SCHEMA).ACTIVITY (ACTIVITY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK1 FOREIGN KEY (TASK_ID)
REFERENCES $(NF_SCHEMA).TASK (TASK_ID)
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK2 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK3 FOREIGN KEY (FAILED_BUILD)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK4 FOREIGN KEY (VALIDATION_BUILD)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK5 FOREIGN KEY (NOTEST_BUILD)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK6 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK7 FOREIGN KEY (ACTIVITY_CLASS_ID)
REFERENCES $(NF_SCHEMA).ACTIVITY_CLASSIFICATION (ACTIVITY_CLASS_ID)	
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK8 FOREIGN KEY (FILE_STREAM_ID)
REFERENCES $(NF_SCHEMA).FILE_STREAM (FILE_STREAM_ID)	
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK9 FOREIGN KEY(PROFILE_ID)
REFERENCES $(NF_SCHEMA).PROFILE (PROFILE_ID)
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK10 FOREIGN KEY(CHARGECODE_ID)
REFERENCES $(NF_SCHEMA).CHARGECODE (CHARGECODE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_ACTIVITY_LOOKUP ADD CONSTRAINT REQACT_FK1 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).REQUEST_ACTIVITY_LOOKUP ADD CONSTRAINT REQACT_FK2 FOREIGN KEY (ACTIVITY_ID)
REFERENCES $(NF_SCHEMA).ACTIVITY (ACTIVITY_ID)	
GO

ALTER TABLE $(NF_SCHEMA).COMPONENT ADD CONSTRAINT COMPONENT_FK1 FOREIGN KEY (PRODUCT_ID)
REFERENCES $(NF_SCHEMA).PRODUCT (PRODUCT_ID)
GO

ALTER TABLE $(NF_SCHEMA).COMPONENT ADD CONSTRAINT COMPONENT_FK3 FOREIGN KEY (COMPONENT_CLASS_ID)
REFERENCES $(NF_SCHEMA).COMPONENT_CLASSIFICATION(COMPONENT_CLASS_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).PROJECT_COMPONENT_LOOKUP ADD CONSTRAINT PRJCOMP_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).PROJECT_COMPONENT_LOOKUP ADD CONSTRAINT PRJCOMP_FK2 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)	
GO

ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK2 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK3 FOREIGN KEY (BASELINE_ID)
REFERENCES $(NF_SCHEMA).PROJECT_BASELINE (BASELINE_ID)
GO

ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK4 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK5 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK6 FOREIGN KEY (PROJECT_TYPE_ID)
REFERENCES $(NF_SCHEMA).PROJECT_TYPE (PROJECT_TYPE_ID)
GO

ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK7 FOREIGN KEY (BUILD_CLASS_ID)
REFERENCES $(NF_SCHEMA).BUILD_CLASSIFICATION (BUILD_CLASS_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK8 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK9 FOREIGN KEY (TEAM_ID)
REFERENCES $(NF_SCHEMA).TEAM (TEAM_ID)	 	
GO
		
ALTER TABLE $(NF_SCHEMA).PROJECT_DETAIL ADD CONSTRAINT PROJECT_DETAIL_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK1 FOREIGN KEY (PLANNED_ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK2 FOREIGN KEY (ACTUAL_ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK3 FOREIGN KEY (RELEASE_ID)
REFERENCES $(NF_SCHEMA).RELEASE (RELEASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK4 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK5 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK7 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK8 FOREIGN KEY (REQUIREMENT_CLASS_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT_CLASSIFICATION (REQUIREMENT_CLASS_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_COLLECTION ADD CONSTRAINT REQUI_COLLECT_FK1 FOREIGN KEY (RELEASE_ID)
	REFERENCES $(NF_SCHEMA).RELEASE (RELEASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_COLLECTION ADD CONSTRAINT REQUI_COLLECT_FK2 FOREIGN KEY (PROJECT_ID)
	REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).REQUIREMENT_COLLECTION ADD CONSTRAINT REQUI_COLLECT_FK3 FOREIGN KEY (PLANNED_ITERATION_ID)
	REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_COLLECTION ADD CONSTRAINT REQUI_COLLECT_FK4 FOREIGN KEY (ACTUAL_ITERATION_ID)
	REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUICOL_REQUIREMENT_LOOKUP ADD CONSTRAINT REQUICOLLECT_FK1 FOREIGN KEY (REQUIREMENT_COLLECTION_ID)
	REFERENCES $(NF_SCHEMA).REQUIREMENT_COLLECTION (REQUIREMENT_COLLECTION_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUICOL_REQUIREMENT_LOOKUP ADD CONSTRAINT REQUICOLLECT_FK2 FOREIGN KEY (REQUIREMENT_ID)
	REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUICOL_TESTPLAN_LOOKUP ADD CONSTRAINT REQUICOL_TESTP_FK1 FOREIGN KEY (REQUIREMENT_COLLECTION_ID)
	REFERENCES $(NF_SCHEMA).REQUIREMENT_COLLECTION (REQUIREMENT_COLLECTION_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUICOL_TESTPLAN_LOOKUP ADD CONSTRAINT REQUICOL_TESTP_FK2 FOREIGN KEY (TESTPLAN_ID)
	REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REVISION_HISTORY ADD CONSTRAINT REQREV_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REVISION_HISTORY ADD CONSTRAINT REQREV_FK2 FOREIGN KEY (RESOURCE_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)	
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE ADD CONSTRAINT RESOURCE_FK1 FOREIGN KEY (POOL_ID)
REFERENCES $(NF_SCHEMA).POOL (POOL_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).RESOURCE ADD CONSTRAINT RESOURCE_FK2 FOREIGN KEY (CITY_ID)
REFERENCES $(NF_SCHEMA).CITY (CITY_ID)
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE ADD CONSTRAINT RESOURCE_FK3 FOREIGN KEY (ORGANIZATION_ID)
REFERENCES $(NF_SCHEMA).ORGANIZATION (ORGANIZATION_ID)	
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE_SKILL_LOOKUP ADD CONSTRAINT RESSKILL_FK1 FOREIGN KEY (RESOURCE_ID)
REFERENCES $(NF_SCHEMA).RESOURCE(RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE_SKILL_LOOKUP ADD CONSTRAINT RESSKILL_FK FOREIGN KEY(SKILL_ID)
REFERENCES $(NF_SCHEMA).SKILL(SKILL_ID)
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE_COMPETENCY_LOOKUP ADD CONSTRAINT RESCOMPETENCY_FK1 FOREIGN KEY (RESOURCE_ID)
REFERENCES $(NF_SCHEMA).RESOURCE(RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE_COMPETENCY_LOOKUP ADD CONSTRAINT RESCOMPETENCY_FK FOREIGN KEY(COMPETENCY_ID)
REFERENCES $(NF_SCHEMA).COMPETENCY(COMPETENCY_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE ADD CONSTRAINT TESTSUITE_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE ADD CONSTRAINT TESTSUITE_FK2 FOREIGN KEY (CONFIGURATION_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION (CONFIGURATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE ADD CONSTRAINT TESTSUITE_FK3 FOREIGN KEY (ASSETREGISTRY_ID)
REFERENCES $(NF_SCHEMA).ASSETREGISTRY (ASSETREGISTRY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE ADD CONSTRAINT TESTSUITE_FK4 FOREIGN KEY (TESTSUITE_CLASS_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE_CLASSIFICATION (TESTSUITE_CLASS_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE ADD CONSTRAINT TESTSUITE_FK5 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)		
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE ADD CONSTRAINT TESTSUITE_FK6 FOREIGN KEY (CREATOR_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK2 FOREIGN KEY (BUILD_ID)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK3 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK4 FOREIGN KEY (TESTTYPE_ID)
REFERENCES $(NF_SCHEMA).TESTTYPE (TESTTYPE_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK5 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK6 FOREIGN KEY (EXECRES_CLASS_ID)
REFERENCES $(NF_SCHEMA).EXECRESULT_CLASSIFICATION (EXECRES_CLASS_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK7 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK8 FOREIGN KEY (TESTSCRIPT_ID)
REFERENCES $(NF_SCHEMA).TESTSCRIPT (TESTSCRIPT_ID)		
GO
	
ALTER TABLE $(NF_SCHEMA).ITERATION ADD CONSTRAINT ITERATION_FK1 FOREIGN KEY (ASSETREGISTRY_ID)
REFERENCES $(NF_SCHEMA).ASSETREGISTRY (ASSETREGISTRY_ID)
GO
				
ALTER TABLE $(NF_SCHEMA).ITERATION ADD CONSTRAINT ITERATION_FK4 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).ITERATION_DETAIL ADD CONSTRAINT ITERDET_FK1 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)		
GO

ALTER TABLE $(NF_SCHEMA).ITERATION_BASELINE ADD CONSTRAINT ITERBASELINE_FK2 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).ITERATION_BASELINE ADD CONSTRAINT ITERBASELINE_FK3 FOREIGN KEY (BASELINE_ID)
REFERENCES $(NF_SCHEMA).PROJECT_BASELINE (BASELINE_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).RELEASE ADD CONSTRAINT RELEASE_FK1 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).RELEASE ADD CONSTRAINT RELEASE_FK2 FOREIGN KEY (PRODUCT_ID)
REFERENCES $(NF_SCHEMA).PRODUCT (PRODUCT_ID)
GO

ALTER TABLE $(NF_SCHEMA).RELEASE ADD CONSTRAINT RELEASE_FK3 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO

ALTER TABLE $(NF_SCHEMA).PROJECT ADD CONSTRAINT PROJECT_FK1 FOREIGN KEY (PROJECT_MANAGER)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT ADD CONSTRAINT PROJECT_FK2 FOREIGN KEY (PROJECT_CATEGORY_ID)
REFERENCES $(NF_SCHEMA).PROJECT_CATEGORY (PROJECT_CATEGORY_ID)	
GO

ALTER TABLE $(NF_SCHEMA).PROJECT ADD CONSTRAINT PROJECT_FK3 FOREIGN KEY (PROJECT_CLASS_ID)
REFERENCES $(NF_SCHEMA).PROJECT_CLASSIFICATION (PROJECT_CLASS_ID)	
GO

ALTER TABLE $(NF_SCHEMA).PROJECT ADD CONSTRAINT PROJECT_FK4 FOREIGN KEY(PROGRAM_ID)
REFERENCES $(NF_SCHEMA).PROGRAM(PROGRAM_ID)
GO

ALTER TABLE $(NF_SCHEMA).TASK ADD CONSTRAINT TASK_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TASK ADD CONSTRAINT TASK_FK2 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO

ALTER TABLE $(NF_SCHEMA).TASK ADD CONSTRAINT TASK_FK3 FOREIGN KEY (TASK_CATEGORY_ID)
REFERENCES $(NF_SCHEMA).TASK_CATEGORY (TASK_CATEGORY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TASK ADD CONSTRAINT TASK_FK4 FOREIGN KEY (TASK_CLASS_ID)
REFERENCES $(NF_SCHEMA).TASK_CLASSIFICATION (TASK_CLASS_ID)	
GO

ALTER TABLE $(NF_SCHEMA).TASK ADD CONSTRAINT TASK_FK5 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).TASK_BASELINE ADD CONSTRAINT TASKBL_FK1 FOREIGN KEY (TASK_ID)
REFERENCES $(NF_SCHEMA).TASK (TASK_ID)
GO

ALTER TABLE $(NF_SCHEMA).TASK_BASELINE ADD CONSTRAINT TASKBL_FK2 FOREIGN KEY (BASELINE_ID)
REFERENCES $(NF_SCHEMA).PROJECT_BASELINE (BASELINE_ID)	
GO

ALTER TABLE $(NF_SCHEMA).TASK_DETAIL ADD CONSTRAINT TASK_DETAIL_FK1 FOREIGN KEY (TASK_ID)
REFERENCES $(NF_SCHEMA).TASK (TASK_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).PROJECT_HIERARCHY ADD CONSTRAINT PROJECTHIER_FK1 FOREIGN KEY (PARENT_PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_HIERARCHY ADD CONSTRAINT PROJECTHIER_FK2 FOREIGN KEY (CHILD_PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_DETAIL ADD CONSTRAINT PROJECTDT_FK1 FOREIGN KEY (CURRENCY_ID)
REFERENCES $(NF_SCHEMA).CURRENCY (CURRENCY_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_TYPE ADD CONSTRAINT PRJTYPE_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_WORKCONFIGURATION ADD CONSTRAINT PRJWKCFG_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_WORKCONFIGURATION ADD CONSTRAINT PRJWKCFG_FK2 FOREIGN KEY (PROJECT_TYPE_ID)
REFERENCES $(NF_SCHEMA).PROJECT_TYPE (PROJECT_TYPE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_CATEGORY ADD CONSTRAINT PRJCAT_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PHASE ADD CONSTRAINT PRJPHASE_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_ROLE ADD CONSTRAINT PRJROLE_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_ROLE ADD CONSTRAINT PRJROLE_FK2 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_ROLE_MEMBER_LOOKUP ADD CONSTRAINT PRJROLELK_FK1 FOREIGN KEY (PROJECT_ROLE_ID)
REFERENCES $(NF_SCHEMA).PROJECT_ROLE (PROJECT_ROLE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_ROLE_MEMBER_LOOKUP ADD CONSTRAINT PRJROLELK_FK2 FOREIGN KEY (RESOURCE_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TASK_REQUIREMENT_LOOKUP ADD CONSTRAINT TSKREQ_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).TASK_REQUIREMENT_LOOKUP ADD CONSTRAINT TSKREQ_FK2 FOREIGN KEY (TASK_ID)
REFERENCES $(NF_SCHEMA).TASK (TASK_ID)
GO

ALTER TABLE $(NF_SCHEMA).CONFIGURATION ADD CONSTRAINT CONFIGURATION_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).CONFIGURATION ADD CONSTRAINT CONFIGURATION_FK2 FOREIGN KEY (CONFIGURATION_CLASS_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION_CLASSIFICATION (CONFIGURATION_CLASS_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).CONFIGURATION ADD CONSTRAINT CONFIGURATION_FK3 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO

ALTER TABLE $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE_LOOKUP ADD CONSTRAINT CFGATTR_ATTR_FK1 FOREIGN KEY (CONFIGURATION_ATTRIBUTE_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE (CONFIGURATION_ATTRIBUTE_ID)
GO

ALTER TABLE $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE_LOOKUP ADD CONSTRAINT CFGATTR_ATTR_FK2 FOREIGN KEY (CONFIGURATION_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION (CONFIGURATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_ITERATION_LOOKUP ADD CONSTRAINT TSTITER_FK1 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_ITERATION_LOOKUP ADD CONSTRAINT TSTITER_FK2 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN ADD CONSTRAINT TESTPLAN_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN ADD CONSTRAINT TESTPLAN_FK2 FOREIGN KEY (ASSETREGISTRY_ID)
REFERENCES $(NF_SCHEMA).ASSETREGISTRY (ASSETREGISTRY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTPLAN ADD CONSTRAINT TESTPLAN_FK3 FOREIGN KEY (TESTPLAN_CLASS_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN_CLASSIFICATION  (TESTPLAN_CLASS_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).TESTPLAN ADD CONSTRAINT TESTPLAN_FK4 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO
			
ALTER TABLE $(NF_SCHEMA).TESTPLAN_ITERATION_LOOKUP ADD CONSTRAINT TSPLNITER_FK1 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_ITERATION_LOOKUP ADD CONSTRAINT TSPLNITER_FK2 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE ADD CONSTRAINT TESTCASE_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE ADD CONSTRAINT TESTCASE_FK2 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTCASE ADD CONSTRAINT TESTCASE_FK3 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO
			
ALTER TABLE $(NF_SCHEMA).TESTCASE ADD CONSTRAINT TESTCASE_FK4 FOREIGN KEY (TESTCASE_CLASS_ID)
REFERENCES $(NF_SCHEMA).TESTCASE_CLASSIFICATION (TESTCASE_CLASS_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTCASE ADD CONSTRAINT TESTCASE_FK5 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)			
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_TESTSCRIPT_LOOKUP ADD CONSTRAINT TESTCSCRIPT_FK1 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_TESTSCRIPT_LOOKUP ADD CONSTRAINT TESTCSCRIPT_FK2 FOREIGN KEY (TESTSCRIPT_ID)
REFERENCES $(NF_SCHEMA).TESTSCRIPT (TESTSCRIPT_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).TESTCASE_ITERATION_LOOKUP ADD CONSTRAINT TESTCITER_FK1 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_ITERATION_LOOKUP ADD CONSTRAINT TESTCITER_FK2 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTCASE_LOOKUP ADD CONSTRAINT REQTEST_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTCASE_LOOKUP ADD CONSTRAINT REQTEST_FK2 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTPLAN_LOOKUP ADD CONSTRAINT REQTESTP_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTPLAN_LOOKUP ADD CONSTRAINT REQTESTP_FK2 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTSUITE_LOOKUP ADD CONSTRAINT REQTESTS_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTSUITE_LOOKUP ADD CONSTRAINT REQTESTS_FK2 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REQUIREMENT_LOOKUP ADD CONSTRAINT REQTREQ_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REQUIREMENT_LOOKUP ADD CONSTRAINT REQTREQ_FK2 FOREIGN KEY (CREQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).REQUIREMENT_HIERARCHY ADD CONSTRAINT REQHIER_FK1 FOREIGN KEY (PRED_REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_HIERARCHY ADD CONSTRAINT REQHIER_FK2 FOREIGN KEY (SUCC_REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).REQUIREMENT_HIERARCHY ADD CONSTRAINT REQHIER_FK3 FOREIGN KEY (LINK_TYPE_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT_LINK_TYPE (LINK_TYPE_ID)	
GO
		
ALTER TABLE $(NF_SCHEMA).REQUEST_LINK ADD CONSTRAINT REQULINK_FK1 FOREIGN KEY (PRED_REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_LINK ADD CONSTRAINT REQULINK_FK2 FOREIGN KEY (SUCC_REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK1 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK2 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK3 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK4 FOREIGN KEY (TESTTYPE_ID)
REFERENCES $(NF_SCHEMA).TESTTYPE (TESTTYPE_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK5 FOREIGN KEY (CONFIGURATION_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION (CONFIGURATION_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK7 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK9 FOREIGN KEY (EXECWORKIT_CLASS_ID)
REFERENCES $(NF_SCHEMA).EXECWORKITEM_CLASSIFICATION (EXECWORKIT_CLASS_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK10 FOREIGN KEY (TESTSCRIPT_ID)
REFERENCES $(NF_SCHEMA).TESTSCRIPT (TESTSCRIPT_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_ITERATION_LOOKUP ADD CONSTRAINT EXWKIITER_FK1 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_ITERATION_LOOKUP ADD CONSTRAINT EXECWKITER_FK2 FOREIGN KEY (EXECWORKITEM_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_WORKITEM (EXECWORKITEM_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_EXECWRKITEM_LOOKUP ADD CONSTRAINT REQEXWKI_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_EXECWRKITEM_LOOKUP ADD CONSTRAINT REQEXECWK_FK2 FOREIGN KEY (EXECWORKITEM_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_WORKITEM (EXECWORKITEM_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_TESTSUITE_LOOKUP ADD CONSTRAINT EXWKITSU_FK1 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_TESTSUITE_LOOKUP ADD CONSTRAINT EXECWKTSU_FK2 FOREIGN KEY (EXECWORKITEM_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_WORKITEM (EXECWORKITEM_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK10 FOREIGN KEY (BUILD_ID)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK11 FOREIGN KEY (PROJECT_CATEGORY_ID)
REFERENCES $(NF_SCHEMA).PROJECT_CATEGORY (PROJECT_CATEGORY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK12 FOREIGN KEY (TEAM_ID)
REFERENCES $(NF_SCHEMA).TEAM (TEAM_ID)	
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK13 FOREIGN KEY (PHASE_ID)
REFERENCES $(NF_SCHEMA).PHASE (PHASE_ID)	
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK2 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK3 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK5 FOREIGN KEY (RELEASE_ID)
REFERENCES $(NF_SCHEMA).RELEASE (RELEASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK6 FOREIGN KEY (FIXEDINRELEASE_ID)
REFERENCES $(NF_SCHEMA).RELEASE (RELEASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK7 FOREIGN KEY (REQUEST_CLASS_ID)
REFERENCES $(NF_SCHEMA).REQUEST_CLASSIFICATION (REQUEST_CLASS_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK8 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK9 FOREIGN KEY (RESOLVER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK14 FOREIGN KEY (REQUEST_STATE_ID)
REFERENCES $(NF_SCHEMA).REQUEST_STATE (REQUEST_STATE_ID)	
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK15 FOREIGN KEY (REQUEST_STATUS_ID)
REFERENCES $(NF_SCHEMA).REQUEST_STATUS (REQUEST_STATUS_ID)		
GO
		
ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK16 FOREIGN KEY (REQUEST_RESOLUTION_ID)
REFERENCES $(NF_SCHEMA).REQUEST_RESOLUTION (REQUEST_RESOLUTION_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK17 FOREIGN KEY (REQUEST_SEVERITY_ID)
REFERENCES $(NF_SCHEMA).REQUEST_SEVERITY (REQUEST_SEVERITY_ID)	
GO
			
ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK18 FOREIGN KEY (REQUEST_PRIORITY_ID)
REFERENCES $(NF_SCHEMA).REQUEST_PRIORITY (REQUEST_PRIORITY_ID)		
GO
	
ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK19 FOREIGN KEY (REQUEST_TYPE_ID)
REFERENCES $(NF_SCHEMA).REQUEST_TYPE (REQUEST_TYPE_ID)	
GO
		
ALTER TABLE $(NF_SCHEMA).REQUEST_HIERARCHY ADD CONSTRAINT REQUHIST_FK1 FOREIGN KEY (PARENT_REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_HIERARCHY ADD CONSTRAINT REQUHIST_FK2 FOREIGN KEY (CHILD_REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).[FILE] ADD CONSTRAINT FILE_FK1 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).[FILE] ADD CONSTRAINT FILE_FK2 FOREIGN KEY (FILE_CLASS_ID)
REFERENCES $(NF_SCHEMA).FILE_CLASSIFICATION (FILE_CLASS_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_VERSION ADD CONSTRAINT FILE_VERSION_FK1 FOREIGN KEY (FILE_ID)
REFERENCES $(NF_SCHEMA).[FILE] (FILE_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_VERSION ADD CONSTRAINT FILE_VERSION_FK2 FOREIGN KEY (AUTHOR_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_VERSION ADD CONSTRAINT FILE_VERSION_FK3 FOREIGN KEY (ACTIVITY_ID)
REFERENCES $(NF_SCHEMA).ACTIVITY (ACTIVITY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_VERSION ADD CONSTRAINT FILE_VERSION_FK4 FOREIGN KEY (FILE_STREAM_ID)
REFERENCES $(NF_SCHEMA).FILE_STREAM (FILE_STREAM_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_VERSION ADD CONSTRAINT FILE_FK5 FOREIGN KEY (FILE_CLASS_ID)
REFERENCES $(NF_SCHEMA).FILE_CLASSIFICATION (FILE_CLASS_ID)						
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_BASELINE ADD CONSTRAINT FBASE_FK1 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_BASELINE_ACTIVITY_LOOKUP ADD CONSTRAINT FBACT_FK1 FOREIGN KEY (FILE_BASELINE_ID)
REFERENCES $(NF_SCHEMA).FILE_BASELINE(FILE_BASELINE_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_BASELINE_ACTIVITY_LOOKUP ADD CONSTRAINT FBACT_FK2 FOREIGN KEY (ACTIVITY_ID)
REFERENCES $(NF_SCHEMA).ACTIVITY (ACTIVITY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_STREAM ADD CONSTRAINT FSTREAM_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).FILE_STREAM ADD CONSTRAINT FSTREAM_FK2 FOREIGN KEY (FILE_STREAM_CLASS_ID)
REFERENCES $(NF_SCHEMA).FILE_STREAM_CLASSIFICATION (FILE_STREAM_CLASS_ID)		
GO

ALTER TABLE $(NF_SCHEMA).CONFIG_EXECUTIONRES_LOOKUP ADD CONSTRAINT CFGEXECRES_FK1 FOREIGN KEY (CONFIGURATION_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION (CONFIGURATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).CONFIG_EXECUTIONRES_LOOKUP ADD CONSTRAINT CFGEXECRES_FK2 FOREIGN KEY (EXECUTION_RESULT_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_RESULT (EXECUTION_RESULT_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_FK1 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_FK2 FOREIGN KEY (BUILD_ID)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_FK3 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_FK4 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)	
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG ADD CONSTRAINT  TESTSUITELOG_FK5 FOREIGN KEY (TESTSUITELOG_CLASS_ID)
REFERENCES $(NF_SCHEMA).TESTSUITELOG_CLASSIFICATION (TESTSUITELOG_CLASS_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG ADD CONSTRAINT  TESTSUITELOG_FK6 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)	
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG ADD CONSTRAINT  TESTSUITELOG_FK7 FOREIGN KEY (TESTSUITE_EXECRECORD_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD (TESTSUITE_EXECRECORD_ID)		
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG_EXECRESULT_LOOKUP ADD CONSTRAINT STESEXECR_FK1 FOREIGN KEY (TESTSUITELOG_ID)
REFERENCES $(NF_SCHEMA).TESTSUITELOG (TESTSUITELOG_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG_EXECRESULT_LOOKUP ADD CONSTRAINT STESEXECR_FK2 FOREIGN KEY (EXECUTION_RESULT_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_RESULT (EXECUTION_RESULT_ID)
GO

ALTER TABLE $(NF_SCHEMA).TASK_REQUEST_LOOKUP ADD CONSTRAINT TSKISSU_FK1 FOREIGN KEY (TASK_ID)
REFERENCES $(NF_SCHEMA).TASK (TASK_ID)
GO

ALTER TABLE $(NF_SCHEMA).TASK_REQUEST_LOOKUP ADD CONSTRAINT TSKISSU_FK2 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REQUEST_LOOKUP ADD CONSTRAINT REQIREQ_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REQUEST_LOOKUP ADD CONSTRAINT REQREQ_FK2 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CUSTOMER_LOOKUP ADD CONSTRAINT REQUCULK_FK1 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_STATE_HISTORY ADD CONSTRAINT REQSTATEHIST_FK1 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID) 
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_STATE_HISTORY ADD CONSTRAINT REQSTATEHIST_FK2 FOREIGN KEY (PREV_REQUEST_STATE_ID)
REFERENCES $(NF_SCHEMA).REQUEST_STATE (REQUEST_STATE_ID) 	
GO
	
ALTER TABLE $(NF_SCHEMA).REQUEST_STATE_HISTORY ADD CONSTRAINT REQSTATEHIST_FK3 FOREIGN KEY (REQUEST_STATE_ID)
REFERENCES $(NF_SCHEMA).REQUEST_STATE (REQUEST_STATE_ID) 	
GO
	
ALTER TABLE $(NF_SCHEMA).REQUEST_STATE_HISTORY ADD CONSTRAINT REQSTATEHIST_FK4 FOREIGN KEY (PREV_REQUEST_STATUS_ID)
REFERENCES $(NF_SCHEMA).REQUEST_STATUS (REQUEST_STATUS_ID) 	
GO
	
ALTER TABLE $(NF_SCHEMA).REQUEST_STATE_HISTORY ADD CONSTRAINT REQSTATEHIST_FK5 FOREIGN KEY (REQUEST_STATUS_ID)
REFERENCES $(NF_SCHEMA).REQUEST_STATUS (REQUEST_STATUS_ID) 	
GO
ALTER TABLE $(NF_SCHEMA).REQUEST_CUSTOMER_LOOKUP ADD CONSTRAINT REQUCULK_FK2 FOREIGN KEY (CUSTOMER_ID)
REFERENCES $(NF_SCHEMA).CUSTOMER (CUSTOMER_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_CUSTOMER_LOOKUP ADD CONSTRAINT REQUICLK_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_CUSTOMER_LOOKUP ADD CONSTRAINT REQUICLK_FK2 FOREIGN KEY (CUSTOMER_ID)
REFERENCES $(NF_SCHEMA).CUSTOMER (CUSTOMER_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECRES_REQUEST_LOOKUP ADD CONSTRAINT EXECRESREQ_FK1 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECRES_REQUEST_LOOKUP ADD CONSTRAINT EXECRESREQ_FK2 FOREIGN KEY (EXECUTION_RESULT_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_RESULT (EXECUTION_RESULT_ID)
GO

ALTER TABLE $(NF_SCHEMA).RISK ADD CONSTRAINT RISK_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).RISK ADD CONSTRAINT RISK_FK2 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).RISK ADD CONSTRAINT RISK_FK3 FOREIGN KEY (RELEASE_ID)
REFERENCES $(NF_SCHEMA).RELEASE (RELEASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).RISK ADD CONSTRAINT RISK_FK4 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).RISK ADD CONSTRAINT RISK_FK5 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).RISK_STATE_HISTORY ADD CONSTRAINT RISKSTATEHIST_FK1 FOREIGN KEY (RISK_ID)
REFERENCES $(NF_SCHEMA).RISK (RISK_ID)
GO

ALTER TABLE $(NF_SCHEMA).FACTOR ADD CONSTRAINT FACTOR_FK1 FOREIGN KEY (RISK_ID)
REFERENCES $(NF_SCHEMA).RISK (RISK_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_BASELINE ADD CONSTRAINT PRJBASELINE_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_BASELINE ADD CONSTRAINT PRJBASELINE_FK2 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_BASELINE ADD CONSTRAINT PRJBASELINE_FK3 FOREIGN KEY (FILE_STREAM_ID)
REFERENCES $(NF_SCHEMA).FILE_STREAM (FILE_STREAM_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJ_BASELINE_BASELINE_LOOKUP ADD CONSTRAINT PRJBSLTOBSL_FK1 FOREIGN KEY (BASELINE_ID)
REFERENCES $(NF_SCHEMA).PROJECT_BASELINE (BASELINE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJ_BASELINE_BASELINE_LOOKUP ADD CONSTRAINT PRJBSLTOBSL_FK2 FOREIGN KEY (COMPBASELINE_ID)
REFERENCES $(NF_SCHEMA).PROJECT_BASELINE (BASELINE_ID)
GO

ALTER TABLE $(NF_SCHEMA).COMMENT ADD CONSTRAINT COMMENT_FK1 FOREIGN KEY (RESPONSE_COMMENT_ID)
REFERENCES $(NF_SCHEMA).COMMENT (COMMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).COMMENT ADD CONSTRAINT COMMENT_FK2 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).COMMENT ADD CONSTRAINT COMMENT_FK3 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).COMMENT ADD CONSTRAINT COMMENT_FK4 FOREIGN KEY (TASK_ID)
REFERENCES $(NF_SCHEMA).TASK (TASK_ID)
GO

ALTER TABLE $(NF_SCHEMA).COMMENT ADD CONSTRAINT COMMENT_FK5 FOREIGN KEY (ACTIVITY_ID)
REFERENCES $(NF_SCHEMA).ACTIVITY (ACTIVITY_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_WORKCONFIG_HIERARCHY ADD CONSTRAINT PRJWCFGH_FK1 FOREIGN KEY(PARENT_WKCFG_ID)
REFERENCES $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (PROJECT_WKCFG_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_WORKCONFIG_HIERARCHY ADD CONSTRAINT PRJWCFGH_FK2 FOREIGN KEY(CHILD_WKCFG_ID)
REFERENCES $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (PROJECT_WKCFG_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECRES_EXECWKITEM_LOOKUP ADD CONSTRAINT EXECRESWK_FK1 FOREIGN KEY (EXECUTION_RESULT_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_RESULT (EXECUTION_RESULT_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECRES_EXECWKITEM_LOOKUP ADD CONSTRAINT EXECRESWK_FK2 FOREIGN KEY (EXECWORKITEM_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_WORKITEM (EXECWORKITEM_ID)
GO

ALTER TABLE $(NF_SCHEMA).CONFIG_EXECUTIONWORKITM_LOOKUP  ADD CONSTRAINT CFGEXECWK_FK1 FOREIGN KEY (CONFIGURATION_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION (CONFIGURATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).CONFIG_EXECUTIONWORKITM_LOOKUP  ADD CONSTRAINT CFGEXECWK_FK2 FOREIGN KEY (EXECWORKITEM_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_WORKITEM (EXECWORKITEM_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).TESTPLAN_CATEGORY_LOOKUP ADD CONSTRAINT TPLNCAT_FK1 FOREIGN KEY (TEST_CATEGORY_ID)
REFERENCES $(NF_SCHEMA).TEST_CATEGORY (TEST_CATEGORY_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_CATEGORY_LOOKUP ADD CONSTRAINT TPLNCAT_FK2 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_CATEGORY_LOOKUP ADD CONSTRAINT TCASECAT_FK1 FOREIGN KEY (TEST_CATEGORY_ID)
REFERENCES $(NF_SCHEMA).TEST_CATEGORY (TEST_CATEGORY_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_CATEGORY_LOOKUP ADD CONSTRAINT TCASECAT_FK2 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTCASE_LOOKUP ADD CONSTRAINT TSUTCASE_FK1 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTCASE_LOOKUP ADD CONSTRAINT TSUTCASE_FK2 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)		
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTSUITELOG_LOOKUP ADD CONSTRAINT TSUTSULG_FK1 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTSUITELOG_LOOKUP ADD CONSTRAINT TSUTSULG_FK2 FOREIGN KEY (TESTSUITELOG_ID)
REFERENCES $(NF_SCHEMA).TESTSUITELOG (TESTSUITELOG_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_TESTPLAN_HIERARCHY ADD CONSTRAINT TPLNPC_FK1 FOREIGN KEY (PARENT_TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_TESTPLAN_HIERARCHY ADD CONSTRAINT TPLNPC_FK2 FOREIGN KEY (CHILD_TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_TESTCASE_LOOKUP ADD CONSTRAINT TPLNTC_FK1 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN(TESTPLAN_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTPLAN_TESTCASE_LOOKUP ADD CONSTRAINT TPLNTC_FK2 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)	
GO

ALTER TABLE $(NF_SCHEMA).LAB_RESOURCE ADD CONSTRAINT LABRES_FK1 FOREIGN KEY (RESOURCE_GROUP_ID)
REFERENCES $(NF_SCHEMA).RESOURCE_GROUP (RESOURCE_GROUP_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).LAB_RESOURCE ADD CONSTRAINT LABRES_FK2 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE_GROUP ADD CONSTRAINT RESGRP_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).RESERVATION ADD CONSTRAINT RESERV_FK1 FOREIGN KEY (LAB_RESOURCE_ID)
REFERENCES $(NF_SCHEMA).LAB_RESOURCE (LAB_RESOURCE_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).RESERVATION ADD CONSTRAINT RESERV_FK2 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).ACTIVITY_STATE_HISTORY ADD CONSTRAINT ACTSTH_FK1 FOREIGN KEY (ACTIVITY_ID)
REFERENCES $(NF_SCHEMA).ACTIVITY (ACTIVITY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TASK_STATE_HISTORY ADD CONSTRAINT TSKSTH_FK1 FOREIGN KEY (TASK_ID)
REFERENCES $(NF_SCHEMA).TASK (TASK_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK1 FOREIGN KEY (REQUEST_CLASS_ID)
REFERENCES $(NF_SCHEMA).REQUEST_CLASSIFICATION (REQUEST_CLASS_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK2 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)                          
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK3 FOREIGN KEY (PREV_TEAM_ID)
REFERENCES $(NF_SCHEMA).TEAM (TEAM_ID)    
GO
                       
ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK4 FOREIGN KEY (PREV_REQUEST_CATEGORY_ID)
REFERENCES $(NF_SCHEMA).REQUEST_CATEGORY (REQUEST_CATEGORY_ID)  
GO
              
ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK5 FOREIGN KEY (PREV_ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)     
GO
                                       
ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK6 FOREIGN KEY (PREV_OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK7 FOREIGN KEY (PREV_REQUEST_STATE_ID)
REFERENCES $(NF_SCHEMA).REQUEST_STATE (REQUEST_STATE_ID)		
GO
		
ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK8 FOREIGN KEY (PREV_REQUEST_STATUS_ID)
REFERENCES $(NF_SCHEMA).REQUEST_STATUS (REQUEST_STATUS_ID)		
GO
		
ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK9 FOREIGN KEY (PREV_REQUEST_PRIORITY_ID)
REFERENCES $(NF_SCHEMA).REQUEST_PRIORITY (REQUEST_PRIORITY_ID)	
GO
		
ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK10 FOREIGN KEY (PREV_REQUEST_SEVERITY_ID)
REFERENCES $(NF_SCHEMA).REQUEST_SEVERITY (REQUEST_SEVERITY_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK11 FOREIGN KEY (PREV_REQUEST_TYPE_ID)
REFERENCES $(NF_SCHEMA).REQUEST_TYPE (REQUEST_TYPE_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).BUILD_COMPILATION_RESULT ADD CONSTRAINT BLDCMPRES_FK1 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).BUILD_COMPILATION_RESULT ADD CONSTRAINT BLDCMPRES_FK2 FOREIGN KEY (BUILD_ID)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).BUILD_UNIT_RESULT ADD CONSTRAINT BLDJUNRES_FK1 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).BUILD_UNIT_RESULT ADD CONSTRAINT BLDJUNRES_FK2 FOREIGN KEY (BUILD_ID)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).BUILD_UNIT_EVENT ADD CONSTRAINT BLDJUNEVT_FK1 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).BUILD_UNIT_EVENT ADD CONSTRAINT BLDJUNEVT_FK2 FOREIGN KEY (BUILD_ID)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO
				
ALTER TABLE $(NF_SCHEMA).UNIT_TEST_RESULT ADD CONSTRAINT BLDJUNTST_FK1 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).UNIT_TEST_RESULT ADD CONSTRAINT BLDJUNTST_FK2 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).UNIT_TEST_RESULT ADD CONSTRAINT BLDJUNTST_FK3 FOREIGN KEY (TEAM_ID)
REFERENCES $(NF_SCHEMA).TEAM(TEAM_ID)
GO

ALTER TABLE $(NF_SCHEMA).JOB ADD CONSTRAINT JOB_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).JOB ADD CONSTRAINT JOB_FK2 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)		
GO
		
ALTER TABLE $(NF_SCHEMA).JOB_RESULT ADD CONSTRAINT JOBRES_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)		
GO
		
ALTER TABLE $(NF_SCHEMA).JOB_RESULT ADD CONSTRAINT JOBRES_FK2 FOREIGN KEY (JOB_ID)
REFERENCES $(NF_SCHEMA).JOB (JOB_ID)	
GO
		
ALTER TABLE $(NF_SCHEMA).JOB_RESULT ADD CONSTRAINT JOBRES_FK3 FOREIGN KEY (LAB_RESOURCE_ID)
REFERENCES $(NF_SCHEMA).LAB_RESOURCE (LAB_RESOURCE_ID)		
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSCRIPT ADD CONSTRAINT TESTSCRIPT_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE(RESOURCE_ID)	
GO
		
ALTER TABLE $(NF_SCHEMA).PROGRAM ADD CONSTRAINT PROGRAM_FK1 FOREIGN KEY (PROGRAM_MANAGER)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROGRAM_DETAIL ADD CONSTRAINT PROGRAM_DETAIL_FK1 FOREIGN KEY (PROGRAM_ID)
REFERENCES $(NF_SCHEMA).PROGRAM (PROGRAM_ID)
GO
			
ALTER TABLE $(NF_SCHEMA).PROJECT_ALLOCATION ADD CONSTRAINT PROJALLO_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO


ALTER TABLE $(NF_SCHEMA).PROJECT_ALLOCATION ADD CONSTRAINT PROJALLO_FK2 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO
			
ALTER TABLE $(NF_SCHEMA).PROJECT_ALLOCATION ADD CONSTRAINT PROJALLO_FK3 FOREIGN KEY (PROFILE_ID)
REFERENCES $(NF_SCHEMA).PROFILE (PROFILE_ID)			
GO
		
ALTER TABLE $(NF_SCHEMA).TIMESHEET ADD CONSTRAINT TIMESHEET_FK1 FOREIGN KEY (ACTIVITY_ID)
REFERENCES $(NF_SCHEMA).ACTIVITY (ACTIVITY_ID)
GO

ALTER TABLE $(NF_SCHEMA).TIMESHEET ADD CONSTRAINT TIMESHEET_FK2 FOREIGN KEY (APPROVER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE(RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROFILE ADD CONSTRAINT PROFILE_FK1 FOREIGN KEY(CITY_ID) 
REFERENCES $(NF_SCHEMA).CITY(CITY_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROFILE ADD CONSTRAINT PROFILE_FK2 FOREIGN KEY(ORGANIZATION_ID) 
REFERENCES $(NF_SCHEMA).ORGANIZATION (ORGANIZATION_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).PROFILE_SKILL_LOOKUP ADD CONSTRAINT PROSKILL_FK1 FOREIGN KEY(SKILL_ID) 
REFERENCES $(NF_SCHEMA).SKILL(SKILL_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROFILE_SKILL_LOOKUP ADD CONSTRAINT PROSKILL_FK2 FOREIGN KEY(PROFILE_ID)
REFERENCES $(NF_SCHEMA).PROFILE(PROFILE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROFILE_COMPETENCY_LOOKUP ADD CONSTRAINT PROCOMPETENCY_FK1 FOREIGN KEY(COMPETENCY_ID) 
REFERENCES $(NF_SCHEMA).COMPETENCY(COMPETENCY_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROFILE_COMPETENCY_LOOKUP ADD CONSTRAINT PROCOMPETENCY_FK2 FOREIGN KEY(PROFILE_ID)
REFERENCES $(NF_SCHEMA).PROFILE(PROFILE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TIMESHEET_TIMECODE_LOOKUP ADD CONSTRAINT TSTC_FK1 FOREIGN KEY (TIMESHEET_ID)
REFERENCES $(NF_SCHEMA).TIMESHEET (TIMESHEET_ID)
GO

ALTER TABLE $(NF_SCHEMA).TIMESHEET_TIMECODE_LOOKUP ADD CONSTRAINT TSTC_FK2 FOREIGN KEY(TIMECODE_ID)
REFERENCES $(NF_SCHEMA).TIMECODE(TIMECODE_ID)
GO
							
ALTER TABLE $(NF_SCHEMA).COUNTRY ADD CONSTRAINT COUNTRY_FK1 FOREIGN KEY (TERRITORY_ID)
REFERENCES $(NF_SCHEMA).OPERATING_TERRITORY (TERRITORY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).PROVINCE_STATE ADD CONSTRAINT PROVSTATE_FK1 FOREIGN KEY (COUNTRY_ID)
REFERENCES $(NF_SCHEMA).COUNTRY (COUNTRY_ID)
GO

ALTER TABLE $(NF_SCHEMA).CITY ADD CONSTRAINT CITY_FK1 FOREIGN KEY (PROVINCE_STATE_ID)
REFERENCES $(NF_SCHEMA).PROVINCE_STATE (PROVINCE_STATE_ID)
GO
								
ALTER TABLE $(NF_SCHEMA).PORTFOLIO_PROG_PROJ_LOOKUP ADD CONSTRAINT PORPROGPROJ_FK1 FOREIGN KEY (PORTFOLIO_ID)
REFERENCES $(NF_SCHEMA).PORTFOLIO (PORTFOLIO_ID)
GO

ALTER TABLE $(NF_SCHEMA).PORTFOLIO_PROG_PROJ_LOOKUP ADD CONSTRAINT PORPROGPROJ_FK2 FOREIGN KEY (PROGRAM_ID)
REFERENCES $(NF_SCHEMA).PROGRAM (PROGRAM_ID)
GO

ALTER TABLE $(NF_SCHEMA).PORTFOLIO_PROG_PROJ_LOOKUP ADD CONSTRAINT PORPROGPROJ_FK3 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_TESTCASE_LOOKUP ADD CONSTRAINT REQUTCASE_FK1 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_TESTCASE_LOOKUP ADD CONSTRAINT REQUTCASE_FK2 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)
GO
								
ALTER TABLE $(NF_SCHEMA).REQUEST_STATE ADD CONSTRAINT REQUTST_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO
								
ALTER TABLE $(NF_SCHEMA).REQUEST_STATUS ADD CONSTRAINT REQUTSTUS_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO
									
ALTER TABLE $(NF_SCHEMA).TEAM ADD CONSTRAINT CMPTEAM_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TEAM_ROLE ADD CONSTRAINT TEAMRL_FK1 FOREIGN KEY (TEAM_ID)
REFERENCES $(NF_SCHEMA).TEAM (TEAM_ID)	
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_RESOURCE_LOOKUP ADD CONSTRAINT PRJRESLK_FK1 FOREIGN KEY (PROJECT_ID)
	REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_RESOURCE_LOOKUP ADD CONSTRAINT PRJRESLK_FK2 FOREIGN KEY (RESOURCE_ID)
	REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)	
GO
									
ALTER TABLE $(NF_SCHEMA).RISK_REQUEST_LOOKUP ADD CONSTRAINT RSKREQLK_FK1 FOREIGN KEY (RISK_ID)
REFERENCES $(NF_SCHEMA).RISK (RISK_ID)
GO

ALTER TABLE $(NF_SCHEMA).RISK_REQUEST_LOOKUP ADD CONSTRAINT RSKREQLK_FK2 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_CATEGORY_LOOKUP ADD CONSTRAINT TSTSUITECATLK_FK1 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_CATEGORY_LOOKUP ADD CONSTRAINT TSTSUITECATLK_FK2 FOREIGN KEY (TEST_CATEGORY_ID)
REFERENCES $(NF_SCHEMA).TEST_CATEGORY (TEST_CATEGORY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTPLAN_LOOKUP ADD CONSTRAINT TSTSUITETPLNLK_FK1 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTPLAN_LOOKUP ADD CONSTRAINT TSTSUITETPLNLK_FK2 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)		
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD ADD CONSTRAINT TSEXECREC_FK1 FOREIGN KEY (CREATOR_ID)
REFERENCES $(NF_SCHEMA).RESOURCE(RESOURCE_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD ADD CONSTRAINT TSEXECREC_FK2 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE(RESOURCE_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD ADD CONSTRAINT TSEXECREC_FK3 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD ADD CONSTRAINT TSEXECREC_FK4 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN(TESTPLAN_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD ADD CONSTRAINT TSEXECREC_FK5 FOREIGN KEY (CONFIGURATION_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION (CONFIGURATION_ID)	
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD ADD CONSTRAINT TSEXECREC_FK7 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE_EXECUTION_RECORD ADD CONSTRAINT TSEXECREC_FK8 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)	
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_REQUEST_LOOKUP ADD CONSTRAINT EXWKITREQUE_FK1 FOREIGN KEY (EXECWORKITEM_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_WORKITEM (EXECWORKITEM_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_REQUEST_LOOKUP ADD CONSTRAINT EXWKITREQUE_FK2 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_STEP_RESULT ADD CONSTRAINT EXECSTEP_FK1 FOREIGN KEY (EXECUTION_RESULT_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_RESULT (EXECUTION_RESULT_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).EXECSTEPRES_REQUEST_LOOKUP ADD CONSTRAINT EXCSTRSREQUELK_FK1 FOREIGN KEY (EXECUTION_STEP_RESULT_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_STEP_RESULT (EXECUTION_STEP_RESULT_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECSTEPRES_REQUEST_LOOKUP ADD CONSTRAINT EXCSTRSREQUELK_FK2 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)	
GO
									
ALTER TABLE $(NF_SCHEMA).TESTSUITE_ELEMENT ADD CONSTRAINT TSTSUITELE_FK1 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE_ELEMENT ADD CONSTRAINT TSTSUITELE_FK2 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)		
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE_ELEMENT ADD CONSTRAINT TSTSUITELE_FK3 FOREIGN KEY (CONFIGURATION_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION (CONFIGURATION_ID)		
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE_ELEMENT ADD CONSTRAINT TSTSUITELE_FK4 FOREIGN KEY (TESTSCRIPT_ID)
REFERENCES $(NF_SCHEMA).TESTSCRIPT (TESTSCRIPT_ID)		
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_LINK_TYPE ADD CONSTRAINT REQLINKTP_FK1 FOREIGN KEY (PROJECT_ID)
	REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_RELATIONAL_LINK ADD CONSTRAINT REQRELT_FK1 FOREIGN KEY (REQUEST1_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_RELATIONAL_LINK ADD CONSTRAINT REQRELT_FK2 FOREIGN KEY (REQUEST2_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO	
										
--LOOKUP HIERARCHY TRIGGERS
   
CREATE TRIGGER TRG_REQCUSTD
    ON $(NF_SCHEMA).REQUEST

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUEST_CUSTOMER_LOOKUP  WHERE  REQUEST_ID IN 
  (SELECT  REQUEST_ID FROM INSERTED )
 END
GO
    
CREATE TRIGGER TRG_REQREQUI
    ON $(NF_SCHEMA).REQUEST

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUIREMENT_REQUEST_LOOKUP  WHERE  REQUEST_ID IN 
  (SELECT  REQUEST_ID FROM INSERTED )
 END
GO
    
CREATE TRIGGER TRG_REQTASK
    ON $(NF_SCHEMA).REQUEST

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TASK_REQUEST_LOOKUP  WHERE  REQUEST_ID IN 
  (SELECT  REQUEST_ID FROM INSERTED )
 END
GO
    
CREATE TRIGGER TRG_REQLOG
    ON $(NF_SCHEMA).REQUEST

    FOR UPDATE
AS
DECLARE @cls int
BEGIN 
  SELECT @cls=REQUEST_CLASS_ID FROM REQUEST_CLASSIFICATION WHERE NAME ='RQM WorkItem'
  BEGIN
  		DELETE FROM $(NF_SCHEMA).EXECRES_REQUEST_LOOKUP  WHERE  REQUEST_ID IN 
(SELECT  REQUEST_ID FROM INSERTED ) AND @cls NOT IN (SELECT REQUEST_CLASS_ID FROM INSERTED)
 END
END 
GO
    
CREATE TRIGGER TRG_REQLOG2
    ON $(NF_SCHEMA).EXECUTION_RESULT

    FOR UPDATE
AS
DECLARE @cls int
BEGIN 
  SELECT @cls=EXECRES_CLASS_ID FROM EXECRESULT_CLASSIFICATION WHERE NAME ='RQM Execution Result'
  BEGIN
  	DELETE FROM $(NF_SCHEMA).EXECRES_REQUEST_LOOKUP  WHERE  EXECUTION_RESULT_ID IN (SELECT  EXECUTION_RESULT_ID FROM INSERTED )
  	AND @cls IN (SELECT EXECRES_CLASS_ID FROM INSERTED)
 END
END 
GO

CREATE TRIGGER TRG_REQREQ
    ON $(NF_SCHEMA).REQUEST

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUEST_HIERARCHY  WHERE  PARENT_REQUEST_ID IN 
  (SELECT  PARENT_REQUEST_ID FROM INSERTED )
 END
GO
    

CREATE TRIGGER TRG_EXWKIITDD
    ON $(NF_SCHEMA).EXECUTION_WORKITEM

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).EXECWORKITEM_ITERATION_LOOKUP  WHERE  EXECWORKITEM_ID IN 
  (SELECT  EXECWORKITEM_ID FROM INSERTED )
 END
GO
    
    
CREATE TRIGGER TRG_EXWKITSUD
    ON $(NF_SCHEMA).EXECUTION_WORKITEM

    FOR UPDATE
AS
DECLARE @cls int
BEGIN 
  SELECT @cls=EXECWORKIT_CLASS_ID FROM EXECWORKITEM_CLASSIFICATION WHERE NAME ='RQM Execution Work Item'
  BEGIN
  DELETE FROM $(NF_SCHEMA).EXECWORKITEM_TESTSUITE_LOOKUP  WHERE  EXECWORKITEM_ID IN 
  (SELECT  EXECWORKITEM_ID FROM INSERTED ) AND @cls NOT IN (SELECT EXECWORKIT_CLASS_ID FROM INSERTED)
 END
END 
GO

CREATE TRIGGER TRG_EXWKITSUD2
    ON $(NF_SCHEMA).TESTSUITE

    FOR UPDATE
AS
DECLARE @cls int
BEGIN 
  SELECT @cls=TESTSUITE_CLASS_ID FROM TESTSUITE_CLASSIFICATION WHERE NAME ='RQM Test Suite'
  BEGIN
  DELETE FROM $(NF_SCHEMA).EXECWORKITEM_TESTSUITE_LOOKUP  WHERE  TESTSUITE_ID IN 
  (SELECT  TESTSUITE_ID FROM INSERTED ) AND @cls IN (SELECT TESTSUITE_CLASS_ID FROM INSERTED)
  END
 END
GO

CREATE TRIGGER TRG_CONFATTRD
    ON $(NF_SCHEMA).CONFIGURATION

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE_LOOKUP  WHERE  CONFIGURATION_ID IN 
  (SELECT  CONFIGURATION_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_CONFTLGD
    ON $(NF_SCHEMA).CONFIGURATION

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).CONFIG_EXECUTIONRES_LOOKUP  WHERE  CONFIGURATION_ID IN 
  (SELECT  CONFIGURATION_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_PRJBSLND
    ON $(NF_SCHEMA).PROJECT_BASELINE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).PROJ_BASELINE_BASELINE_LOOKUP  WHERE  BASELINE_ID IN 
  (SELECT  BASELINE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_PRJROLED
    ON $(NF_SCHEMA).PROJECT_ROLE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).PROJECT_ROLE_MEMBER_LOOKUP  WHERE  PROJECT_ROLE_ID IN 
  (SELECT  PROJECT_ROLE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_REQUITSTCD
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUIREMENT_EXECWRKITEM_LOOKUP  WHERE  REQUIREMENT_ID IN 
  (SELECT  REQUIREMENT_ID FROM INSERTED )
 END
GO
    
CREATE TRIGGER TRG_REQICUSTD
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUIREMENT_CUSTOMER_LOOKUP  WHERE  REQUIREMENT_ID IN 
  (SELECT  REQUIREMENT_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_REQIREQUID
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUIREMENT_REQUIREMENT_LOOKUP  WHERE  REQUIREMENT_ID IN 
  (SELECT  REQUIREMENT_ID FROM INSERTED )
 END
GO
        
CREATE TRIGGER TRG_REQITSTCD
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
DECLARE @cls int
BEGIN 
	SELECT @cls=REQUIREMENT_CLASS_ID FROM REQUIREMENT_CLASSIFICATION WHERE NAME='RQM Requirement'
	BEGIN
  DELETE FROM $(NF_SCHEMA).REQUIREMENT_TESTCASE_LOOKUP  WHERE  REQUIREMENT_ID IN 
  (SELECT  REQUIREMENT_ID FROM INSERTED ) AND @cls NOT IN (SELECT REQUIREMENT_CLASS_ID FROM INSERTED)
 END
END 
GO
    
CREATE TRIGGER TRG_REQITSTCD2
    ON $(NF_SCHEMA).TESTCASE

    FOR UPDATE
AS
DECLARE @cls int
BEGIN 
	BEGIN
  DELETE FROM $(NF_SCHEMA).REQUIREMENT_TESTCASE_LOOKUP  WHERE  TESTCASE_ID IN 
  (SELECT  TESTCASE_ID FROM INSERTED ) AND @cls IN (SELECT TESTCASE_CLASS_ID FROM INSERTED)
 END
END 
GO

CREATE TRIGGER TRG_REQITPLND
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
	DECLARE @cls int
BEGIN 
	SELECT @cls=REQUIREMENT_CLASS_ID FROM REQUIREMENT_CLASSIFICATION WHERE NAME='RQM Requirement'
BEGIN
  DELETE FROM $(NF_SCHEMA).REQUIREMENT_TESTPLAN_LOOKUP  WHERE  REQUIREMENT_ID IN 
  (SELECT  REQUIREMENT_ID FROM INSERTED ) AND @cls NOT IN (SELECT REQUIREMENT_CLASS_ID FROM INSERTED)
 END
END 
GO

CREATE TRIGGER TRG_REQITPLND2
    ON $(NF_SCHEMA).TESTPLAN

    FOR UPDATE
AS
	DECLARE @cls int
BEGIN 
	SELECT @cls=TESTPLAN_CLASS_ID FROM TESTPLAN_CLASSIFICATION WHERE NAME='RQM Test Plan'
BEGIN
  DELETE FROM $(NF_SCHEMA).REQUIREMENT_TESTPLAN_LOOKUP  WHERE  TESTPLAN_ID IN 
  (SELECT  TESTPLAN_ID FROM INSERTED ) AND @cls IN (SELECT TESTPLAN_CLASS_ID FROM INSERTED)
 END
END 
GO

CREATE TRIGGER TRG_REQITSUTD
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUIREMENT_TESTSUITE_LOOKUP  WHERE  REQUIREMENT_ID IN 
  (SELECT  REQUIREMENT_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TSLOG
    ON $(NF_SCHEMA).TESTSUITELOG

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTSUITELOG_EXECRESULT_LOOKUP  WHERE  TESTSUITELOG_ID IN 
  (SELECT  TESTSUITELOG_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TSKREQID
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TASK_REQUIREMENT_LOOKUP  WHERE  REQUIREMENT_ID IN 
  (SELECT  REQUIREMENT_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TSCITERD
    ON $(NF_SCHEMA).TESTCASE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTCASE_ITERATION_LOOKUP  WHERE  TESTCASE_ID IN 
  (SELECT  TESTCASE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TPLNITERD
    ON $(NF_SCHEMA).TESTPLAN

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTPLAN_ITERATION_LOOKUP  WHERE  TESTPLAN_ID IN 
  (SELECT  TESTPLAN_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TSUTITERD
    ON $(NF_SCHEMA).TESTSUITE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTSUITE_ITERATION_LOOKUP  WHERE  TESTSUITE_ID IN 
  (SELECT  TESTSUITE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_PRJHIERD
    ON $(NF_SCHEMA).PROJECT

    FOR UPDATE
AS
SET NOCOUNT ON
IF UPDATE(REC_DATETIME)
BEGIN 

  DELETE FROM $(NF_SCHEMA).PROJECT_HIERARCHY  WHERE  PARENT_PROJECT_ID IN 
  (SELECT  PARENT_PROJECT_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_PRJCOMPD
    ON $(NF_SCHEMA).PROJECT

    FOR UPDATE
AS
SET NOCOUNT ON
IF UPDATE(REC_DATETIME)
BEGIN 

  DELETE FROM $(NF_SCHEMA).PROJECT_COMPONENT_LOOKUP  WHERE  PROJECT_ID IN 
  (SELECT  PROJECT_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_FBSACTD
    ON $(NF_SCHEMA).ACTIVITY

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).FILE_BASELINE_ACTIVITY_LOOKUP  WHERE  ACTIVITY_ID IN 
  (SELECT  ACTIVITY_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_REQACTD
    ON $(NF_SCHEMA).REQUEST

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUEST_ACTIVITY_LOOKUP  WHERE  REQUEST_ID IN 
  (SELECT  REQUEST_ID FROM INSERTED )
 END
GO
  
CREATE TRIGGER TRG_EXERESWKIT
    ON $(NF_SCHEMA).EXECUTION_RESULT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).EXECRES_EXECWKITEM_LOOKUP  WHERE  EXECUTION_RESULT_ID IN 
  (SELECT  EXECUTION_RESULT_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_CFGEXECWK
    ON $(NF_SCHEMA).EXECUTION_WORKITEM

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).CONFIG_EXECUTIONWORKITM_LOOKUP  WHERE  EXECWORKITEM_ID IN 
  (SELECT  EXECWORKITEM_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TPLNCAT
    ON $(NF_SCHEMA).TESTPLAN

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTPLAN_CATEGORY_LOOKUP  WHERE  TESTPLAN_ID IN 
  (SELECT  TESTPLAN_ID FROM INSERTED )
 END
GO
    
    
CREATE TRIGGER TRG_TCASECAT
    ON $(NF_SCHEMA).TESTCASE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTCASE_CATEGORY_LOOKUP  WHERE  TESTCASE_ID IN 
  (SELECT  TESTCASE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TSUTCASE
    ON $(NF_SCHEMA).TESTSUITE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTSUITE_TESTCASE_LOOKUP  WHERE  TESTSUITE_ID IN 
  (SELECT  TESTSUITE_ID FROM INSERTED )
 END
GO
   
CREATE TRIGGER TRG_TPLNTCS
    ON $(NF_SCHEMA).TESTPLAN

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTPLAN_TESTCASE_LOOKUP  WHERE  TESTPLAN_ID IN 
  (SELECT  TESTPLAN_ID FROM INSERTED )
 END
GO
            
CREATE TRIGGER TRG_TSCSCRIPT
    ON $(NF_SCHEMA).TESTCASE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTCASE_TESTSCRIPT_LOOKUP  WHERE  TESTCASE_ID IN 
  (SELECT  TESTCASE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_SKILLRES 
    ON $(NF_SCHEMA).RESOURCE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).RESOURCE_SKILL_LOOKUP  WHERE  RESOURCE_ID IN 
  (SELECT  RESOURCE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_COMPRES 
    ON $(NF_SCHEMA).RESOURCE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).RESOURCE_COMPETENCY_LOOKUP  WHERE  RESOURCE_ID IN 
  (SELECT  RESOURCE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_SKILLPRO 
    ON $(NF_SCHEMA).PROFILE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).PROFILE_SKILL_LOOKUP  WHERE  PROFILE_ID IN 
  (SELECT  PROFILE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_COMPPRO 
    ON $(NF_SCHEMA).PROFILE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).PROFILE_COMPETENCY_LOOKUP  WHERE  PROFILE_ID IN 
  (SELECT  PROFILE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TSTC
    ON $(NF_SCHEMA).TIMESHEET

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TIMESHEET_TIMECODE_LOOKUP  WHERE  TIMESHEET_ID IN 
  (SELECT  TIMESHEET_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_REQUICOL
    ON $(NF_SCHEMA).REQUIREMENT_COLLECTION

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUICOL_REQUIREMENT_LOOKUP  WHERE  REQUIREMENT_COLLECTION_ID IN 
  (SELECT  REQUIREMENT_COLLECTION_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_REQUICOLTP
    ON $(NF_SCHEMA).REQUIREMENT_COLLECTION

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUICOL_TESTPLAN_LOOKUP  WHERE  REQUIREMENT_COLLECTION_ID IN 
  (SELECT  REQUIREMENT_COLLECTION_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_PORTPROGPRJ
    ON $(NF_SCHEMA).PORTFOLIO

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).PORTFOLIO_PROG_PROJ_LOOKUP  WHERE  PORTFOLIO_ID IN 
  (SELECT  PORTFOLIO_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_REQUTCASE
    ON $(NF_SCHEMA).TESTCASE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUEST_TESTCASE_LOOKUP  WHERE  TESTCASE_ID IN 
  (SELECT  TESTCASE_ID FROM INSERTED )
 END
GO
          
CREATE TRIGGER TRG_PROJRES
	ON $(NF_SCHEMA).PROJECT
	
	 FOR UPDATE
AS
SET NOCOUNT ON
IF UPDATE(REC_DATETIME)
BEGIN 

  DELETE FROM $(NF_SCHEMA).PROJECT_RESOURCE_LOOKUP WHERE PROJECT_ID IN 
  (SELECT  PROJECT_ID FROM INSERTED )
END  
GO

CREATE TRIGGER TRG_RSKREQUST
    ON $(NF_SCHEMA).RISK

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).RISK_REQUEST_LOOKUP  WHERE  RISK_ID IN 
  (SELECT  RISK_ID FROM INSERTED )
 END
GO
                
CREATE TRIGGER TRG_TSCATLK 
    ON $(NF_SCHEMA).TESTSUITE

    FOR UPDATE
AS
BEGIN    

  DELETE FROM $(NF_SCHEMA).TESTSUITE_CATEGORY_LOOKUP  WHERE  TESTSUITE_ID IN 
  (SELECT  TESTSUITE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TSTPLTLK 
    ON $(NF_SCHEMA).TESTSUITE

    FOR UPDATE
AS
BEGIN    

  DELETE FROM $(NF_SCHEMA).TESTSUITE_TESTPLAN_LOOKUP  WHERE  TESTSUITE_ID IN 
  (SELECT  TESTSUITE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_EWIREQUE 
    ON $(NF_SCHEMA).EXECUTION_WORKITEM

    FOR UPDATE
AS
BEGIN    

  DELETE FROM $(NF_SCHEMA).EXECWORKITEM_REQUEST_LOOKUP  WHERE  EXECWORKITEM_ID IN 
  (SELECT  EXECWORKITEM_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_ESRREQUE 
    ON $(NF_SCHEMA).EXECUTION_STEP_RESULT

    FOR UPDATE
AS
BEGIN    

  DELETE FROM $(NF_SCHEMA).EXECSTEPRES_REQUEST_LOOKUP  WHERE  EXECUTION_STEP_RESULT_ID IN 
  (SELECT  EXECUTION_STEP_RESULT_ID FROM INSERTED )
 END
GO
   
CREATE TRIGGER TRG_REQHIER
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUIREMENT_HIERARCHY  WHERE  PRED_REQUIREMENT_ID IN 
  (SELECT  PRED_REQUIREMENT_ID FROM INSERTED )
 END
GO   
                